/*
 * AnalogPwm.cpp
 *
 * Created: 11/11/2014 11:03:50 AM
 *  Author: Tim
 */ 


#include <standard.h>
#include "AnalogPwmInit.h"
#include "PwmScale.h"


//*********************************************************************

#define ADC_MUX_STEERING	0x00	// ADC0, Vcc ref
#define ADC_MUX_THROTTLE	0x01	// ADC1, Vcc ref
#define ADC_MUX_BRAKE		0x02	// ADC2, Vcc ref

// Enable ADC with clock prescaler 8: 1 MHz / 8 = 128 kHz
#define ADCSRA_INIT			(_BV(ADEN) | _BV(ADPS1) | _BV(ADPS0))
#define DIDR0_INIT			(_BV(ADC2D) | _BV(ADC1D) | _BV(ADC0D))

//*********************************************************************

struct EepromData
{
	PwmScale		pwmThrottle;
	PwmScale		pwmBrake;
	PwmScale		pwmSteering;
	
};

//*********************************************************************
// static data

EepromData		g_Saved;
BYTE			s_portB = inConfig0_MASK | inConfig1_MASK | inConfig2_MASK;

//*********************************************************************

WORD ReadAdc(BYTE bMux)
{
	ADMUX = bMux;	// Select analog input
	_ADSC = 1;		// Start conversion
	while (_ADSC);	// Spin waiting for conversion complete
	return ADC;
}

//*********************************************************************
// Main Program
//*********************************************************************

int main(void)
{
	WORD	wVal;
	int		iSteer;
	int		iThrot;
	int		iAdj;
	WORD	wLeft;
	WORD	wRight;
	BYTE	bPinB;

	// Include initialization code generated AVR I/O Designer
#include "AnalogPwmInit.c"

	// Initialize ADC
	ADCSRA = ADCSRA_INIT;
	// ADCSRB default value is good
	DIDR0 = DIDR0_INIT;
	
	// Copy data from EEPROM
	eeprom_read_block(&g_Saved, 0, sizeof g_Saved);
	
    for(;; s_portB = bPinB)
    {
		bPinB = PINB;
		if (!(bPinB & inConfig0_MASK) || !(bPinB & inConfig1_MASK))
		{
			// In calibration mode
			if (!(bPinB & inConfig0_MASK) && (bPinB & inConfig1_MASK) && (s_portB & inConfig0_MASK))
			{
				// Just entered calibration, set zero
				g_Saved.pwmSteering.m_offset = ReadAdc(ADC_MUX_STEERING);
				g_Saved.pwmThrottle.m_offset = ReadAdc(ADC_MUX_THROTTLE);
				g_Saved.pwmBrake.m_offset = ReadAdc(ADC_MUX_BRAKE);
			}
			else if (!(bPinB & inConfig0_MASK) && !(bPinB & inConfig1_MASK) && (s_portB & inConfig1_MASK))
			{
				// Second stage of calibration
				g_Saved.pwmThrottle.ComputeScale(ReadAdc(ADC_MUX_THROTTLE));
				g_Saved.pwmBrake.ComputeScale(ReadAdc(ADC_MUX_BRAKE));
				g_Saved.pwmSteering.m_scale = ReadAdc(ADC_MUX_STEERING);
			}
			else if ((bPinB & inConfig0_MASK) && !(bPinB & inConfig1_MASK) && !(s_portB & inConfig0_MASK))
			{
				WORD	wMin, wMax, wZero;
				
				// Third and final stage of calibration
				wMin = ReadAdc(ADC_MUX_STEERING);
				wMax = g_Saved.pwmSteering.m_scale;
				if (wMin > wMax)
				{
					wZero = wMin;
					wMin = wMax;
					wMax = wZero;
				}
				wZero = g_Saved.pwmSteering.m_offset;
				wVal = wZero - wMin;
				if (wMax - wZero > wVal)
					wMax = wZero + wVal;
				g_Saved.pwmSteering.ComputeScale(wMax);
				
				// Save final values to EEPROM
				eeprom_write_block(&g_Saved, 0, sizeof g_Saved);
			}
			continue;
		}
		
		// Not in calibration mode
		iSteer = g_Saved.pwmSteering.Scale(ReadAdc(ADC_MUX_STEERING));
		if (inConfig2 == 0)
			iSteer /= 2;
		iThrot = g_Saved.pwmThrottle.Scale(ReadAdc(ADC_MUX_THROTTLE));
		iThrot -= g_Saved.pwmBrake.Scale(ReadAdc(ADC_MUX_BRAKE));
		iAdj = iThrot * (long)iSteer / PWM_PULSE_RANGE;
		iThrot += PWM_ZERO_PULSE;
		if (iSteer > 0)
		{
			wRight = iThrot - iAdj;
			wLeft = iThrot;
		}
		else
		{
			wLeft = iThrot + iAdj;
			wRight = iThrot;
		}
		cntLeft = wLeft;
		cntRight = wRight;
    }
}