#ifndef _AID_ATmega103_DEFINED_

typedef enum
{
	Disabling_Enabled,                  	// Enabled
	Disabling_Disabled,                 	// Disabled
} Disabling_ENUM;

typedef enum
{
	Enabling_Disabled,                  	// Disabled
	Enabling_Enabled,                   	// Enabled
} Enabling_ENUM;

typedef enum
{
	ACIntModeSelect_OutputToggle,       	// Comparator Interrupt on Output Toggle
	ACIntModeSelect_Reserved,           	// Reserved
	ACIntModeSelect_FallingOutputEdge,  	// Comparator Interrupt on Falling Output Edge
	ACIntModeSelect_RisingOutputEdge,   	// Comparator Interrupt on Rising Output Edge
} ACIntModeSelect_ENUM;

typedef enum
{
	SenseB_LowLevel,                    	// Low Level Generates Interrupt
	SenseB_Reserved,                    	// Reserved
	SenseB_FallingEdge,                 	// Falling Edge Generates Interrupt
	SenseB_RisingEdge,                  	// Rising Edge Generates Interrupt
} SenseB_ENUM;

typedef enum
{
	SPIMaster_Slave,                    	// Slave Mode
	SPIMaster_Master,                   	// Master Mode
} SPIMaster_ENUM;

typedef enum
{
	SPIMode_Mode0,                      	// 0 - Leading (Rising) Edge Sample, Trailing (Falling) Edge Setup
	SPIMode_Mode1,                      	// 1 - Leading (Rising) Edge Setup, Trailing (Falling) Edge Sample
	SPIMode_Mode2,                      	// 2 - Leading (Falling) Edge Sample, Trailing (Rising) Edge Setup
	SPIMode_Mode3,                      	// 3 - Leading (Falling) Edge Setup, Trailing (Rising) Edge Sample
} SPIMode_ENUM;

typedef enum
{
	SPIDataOrder_MSBFirst,              	// Most Significant Bit First
	SPIDataOrder_LSBFirst,              	// Least Significant Bit First
} SPIDataOrder_ENUM;

typedef enum
{
	Trigger_Falling,                    	// Falling Edge Trigger
	Trigger_Rising,                     	// Rising Edge Trigger
} Trigger_ENUM;

typedef enum
{
	NumBits_Bits8,                      	// 8 Bits
	NumBits_Bits9,                      	// 9 Bits
} NumBits_ENUM;

//
// AD_CONVERTER variable definitions
//
#define	_MUX0                   ((volatile BYTE_STRUCT*)&ADMUX)->bit0
#define	_MUX1                   ((volatile BYTE_STRUCT*)&ADMUX)->bit1
#define	_MUX2                   ((volatile BYTE_STRUCT*)&ADMUX)->bit2
#define	_ADEN                   ((volatile BYTE_STRUCT*)&ADCSR)->bit7
#define	_ADSC                   ((volatile BYTE_STRUCT*)&ADCSR)->bit6
#define	_ADIF                   ((volatile BYTE_STRUCT*)&ADCSR)->bit4
#define	_ADIE                   ((volatile BYTE_STRUCT*)&ADCSR)->bit3
#define	_ADPS2                  ((volatile BYTE_STRUCT*)&ADCSR)->bit2
#define	_ADPS1                  ((volatile BYTE_STRUCT*)&ADCSR)->bit1
#define	_ADPS0                  ((volatile BYTE_STRUCT*)&ADCSR)->bit0

//
// ANALOG_COMPARATOR variable definitions
//
// Analog Comparator Disable - Disabling_ENUM - [bit ACSR.ACD] Disables the Analog Comparator.
#define	_ACD                    ((volatile BYTE_STRUCT*)&ACSR)->bit7
// Interrupt Enable - Enabling_ENUM - [bit ACSR.ACIE] When enabled and the I-bit in the Status Register is set, the Analog Comparator interrupt is activated.
#define	_ACIE                   ((volatile BYTE_STRUCT*)&ACSR)->bit3
// Interrupt Mode Select - ACIntModeSelect_ENUM - [bit field "ACIS" ACSR.(ACIS0 | ACIS1)] Determine which comparator events trigger the Analog Comparator interrupt.

typedef struct
{
	unsigned char	__ACIS            : 2;
} ACIS_STRUCT;

#define	_ACIS                   ((volatile ACIS_STRUCT*)&ACSR)->__ACIS
// Input Capture Enable - Enabling_ENUM - [bit ACSR.ACIC] Enables the input capture function in Timer/Counter1 to be triggered by the Analog Comparator.
#define	_ACIC                   ((volatile BYTE_STRUCT*)&ACSR)->bit2

// other ANALOG_COMPARATOR bit definitions
#define	_ACO                    ((volatile BYTE_STRUCT*)&ACSR)->bit5
#define	_ACI                    ((volatile BYTE_STRUCT*)&ACSR)->bit4
#define	_ACIS1                  ((volatile BYTE_STRUCT*)&ACSR)->bit1
#define	_ACIS0                  ((volatile BYTE_STRUCT*)&ACSR)->bit0

//
// CPU variable definitions
//
#define	_SRE                    ((volatile BYTE_STRUCT*)&MCUCR)->bit7
#define	_SRW                    ((volatile BYTE_STRUCT*)&MCUCR)->bit6
#define	_SE                     ((volatile BYTE_STRUCT*)&MCUCR)->bit5
#define	_SM1                    ((volatile BYTE_STRUCT*)&MCUCR)->bit4
#define	_SM0                    ((volatile BYTE_STRUCT*)&MCUCR)->bit3
#define	_EXTRF                  ((volatile BYTE_STRUCT*)&MCUSR)->bit1
#define	_PORF                   ((volatile BYTE_STRUCT*)&MCUSR)->bit0
#define	_XDIV0                  ((volatile BYTE_STRUCT*)&XDIV)->bit0
#define	_XDIV1                  ((volatile BYTE_STRUCT*)&XDIV)->bit1
#define	_XDIV2                  ((volatile BYTE_STRUCT*)&XDIV)->bit2
#define	_XDIV3                  ((volatile BYTE_STRUCT*)&XDIV)->bit3
#define	_XDIV4                  ((volatile BYTE_STRUCT*)&XDIV)->bit4
#define	_XDIV5                  ((volatile BYTE_STRUCT*)&XDIV)->bit5
#define	_XDIV6                  ((volatile BYTE_STRUCT*)&XDIV)->bit6
#define	_XDIVEN                 ((volatile BYTE_STRUCT*)&XDIV)->bit7
#define	_RAMPZ0                 ((volatile BYTE_STRUCT*)&RAMPZ)->bit0

//
// EEPROM variable definitions
//
#define	_EERIE                  ((volatile BYTE_STRUCT*)&EECR)->bit3
#define	_EEMWE                  ((volatile BYTE_STRUCT*)&EECR)->bit2
#define	_EEWE                   ((volatile BYTE_STRUCT*)&EECR)->bit1
#define	_EERE                   ((volatile BYTE_STRUCT*)&EECR)->bit0

//
// EXTERNAL_INTERRUPT variable definitions
//
// INT0 Interrupt Enable - Enabling_ENUM - [bit EIMSK.INT0] Enables the interrupt on the INT pin
#define	_INT0                   ((volatile BYTE_STRUCT*)&EIMSK)->bit0
// INT1 Interrupt Enable - Enabling_ENUM - [bit EIMSK.INT1] Enables the interrupt on the INT pin
#define	_INT1                   ((volatile BYTE_STRUCT*)&EIMSK)->bit1
// INT2 Interrupt Enable - Enabling_ENUM - [bit EIMSK.INT2] Enables the interrupt on the INT pin
#define	_INT2                   ((volatile BYTE_STRUCT*)&EIMSK)->bit2
// INT3 Interrupt Enable - Enabling_ENUM - [bit EIMSK.INT3] Enables the interrupt on the INT pin
#define	_INT3                   ((volatile BYTE_STRUCT*)&EIMSK)->bit3
// INT4 Interrupt Enable - Enabling_ENUM - [bit EIMSK.INT4] Enables the interrupt on the INT pin
#define	_INT4                   ((volatile BYTE_STRUCT*)&EIMSK)->bit4
// INT4 Interrupt Sense Control - SenseB_ENUM - [bit field "ISC4" EICR.(ISC40 | ISC41)] Specifies the type of signal that will generate an interrupt

typedef struct
{
	unsigned char	__ISC4            : 2;
} ISC4_STRUCT;

#define	_ISC4                   ((volatile ISC4_STRUCT*)&EICR)->__ISC4
// INT5 Interrupt Enable - Enabling_ENUM - [bit EIMSK.INT5] Enables the interrupt on the INT pin
#define	_INT5                   ((volatile BYTE_STRUCT*)&EIMSK)->bit5
// INT5 Interrupt Sense Control - SenseB_ENUM - [bit field "ISC5" EICR.(ISC50 | ISC51)] Specifies the type of signal that will generate an interrupt

typedef struct
{
	unsigned char	__Reserved        : 2;
	unsigned char	__ISC5            : 2;
} ISC5_STRUCT;

#define	_ISC5                   ((volatile ISC5_STRUCT*)&EICR)->__ISC5
// INT6 Interrupt Enable - Enabling_ENUM - [bit EIMSK.INT6] Enables the interrupt on the INT pin
#define	_INT6                   ((volatile BYTE_STRUCT*)&EIMSK)->bit6
// INT6 Interrupt Sense Control - SenseB_ENUM - [bit field "ISC6" EICR.(ISC60 | ISC61)] Specifies the type of signal that will generate an interrupt

typedef struct
{
	unsigned char	__Reserved        : 4;
	unsigned char	__ISC6            : 2;
} ISC6_STRUCT;

#define	_ISC6                   ((volatile ISC6_STRUCT*)&EICR)->__ISC6
// INT7 Interrupt Enable - Enabling_ENUM - [bit EIMSK.INT7] Enables the interrupt on the INT pin
#define	_INT7                   ((volatile BYTE_STRUCT*)&EIMSK)->bit7
// INT7 Interrupt Sense Control - SenseB_ENUM - [bit field "ISC7" EICR.(ISC70 | ISC71)] Specifies the type of signal that will generate an interrupt

typedef struct
{
	unsigned char	__Reserved        : 6;
	unsigned char	__ISC7            : 2;
} ISC7_STRUCT;

#define	_ISC7                   ((volatile ISC7_STRUCT*)&EICR)->__ISC7

// other EXTERNAL_INTERRUPT bit definitions
#define	_ISC71                  ((volatile BYTE_STRUCT*)&EICR)->bit7
#define	_ISC70                  ((volatile BYTE_STRUCT*)&EICR)->bit6
#define	_ISC61                  ((volatile BYTE_STRUCT*)&EICR)->bit5
#define	_ISC60                  ((volatile BYTE_STRUCT*)&EICR)->bit4
#define	_ISC51                  ((volatile BYTE_STRUCT*)&EICR)->bit3
#define	_ISC50                  ((volatile BYTE_STRUCT*)&EICR)->bit2
#define	_ISC41                  ((volatile BYTE_STRUCT*)&EICR)->bit1
#define	_ISC40                  ((volatile BYTE_STRUCT*)&EICR)->bit0
#define	_INTF7                  ((volatile BYTE_STRUCT*)&EIFR)->bit7
#define	_INTF6                  ((volatile BYTE_STRUCT*)&EIFR)->bit6
#define	_INTF5                  ((volatile BYTE_STRUCT*)&EIFR)->bit5
#define	_INTF4                  ((volatile BYTE_STRUCT*)&EIFR)->bit4

//
// SPI variable definitions
//
// SPI Enable - Enabling_ENUM - [bit SPCR.SPE]
#define	_SPE                    ((volatile BYTE_STRUCT*)&SPCR)->bit6
// Master/Slave Mode - SPIMaster_ENUM - [bit SPCR.MSTR]
#define	_MSTR                   ((volatile BYTE_STRUCT*)&SPCR)->bit4
// Clock Rate Select - SPR_SPR_ENUM - [bit field "SPR" SPCR.(SPR0 | SPR1)] Controls the SCK rate of the device configured as a Master.
typedef enum
{
	SPR_SPR_DIV_4,                      	// clk / 4
	SPR_SPR_DIV_16,                     	// clk / 16
	SPR_SPR_DIV_64,                     	// clk / 64
	SPR_SPR_DIV_128,                    	// clk / 128
} SPR_SPR_ENUM;

typedef struct
{
	unsigned char	__SPR             : 2;
} SPR_STRUCT;

#define	_SPR                    ((volatile SPR_STRUCT*)&SPCR)->__SPR
// SPI Mode - SPIMode_ENUM - [bit field "MODE" SPCR.(CPHA | CPOL)] Sets the relationship between data output change and data input sample, and the synchronous clock (SCK).

typedef struct
{
	unsigned char	__Reserved        : 2;
	unsigned char	__MODE            : 2;
} MODE_STRUCT;

#define	_MODE                   ((volatile MODE_STRUCT*)&SPCR)->__MODE
// Data Order - SPIDataOrder_ENUM - [bit SPCR.DORD] Sets the order in which bits are transmitted.
#define	_DORD                   ((volatile BYTE_STRUCT*)&SPCR)->bit5
// SPI Interrupt Enable - Enabling_ENUM - [bit SPCR.SPIE]
#define	_SPIE                   ((volatile BYTE_STRUCT*)&SPCR)->bit7

// other SPI bit definitions
#define	_SPIF                   ((volatile BYTE_STRUCT*)&SPSR)->bit7
#define	_WCOL                   ((volatile BYTE_STRUCT*)&SPSR)->bit6
#define	_CPOL                   ((volatile BYTE_STRUCT*)&SPCR)->bit3
#define	_CPHA                   ((volatile BYTE_STRUCT*)&SPCR)->bit2
#define	_SPR1                   ((volatile BYTE_STRUCT*)&SPCR)->bit1
#define	_SPR0                   ((volatile BYTE_STRUCT*)&SPCR)->bit0

//
// TIMER_COUNTER_0 variable definitions
//
// Waveform Generation Mode (CTC | PWM) - WGM0_WGM_ENUM - [bit aggregate (TCCR0.PWM0 | TCCR0.CTC0)] Controls how the counter will cycle.
typedef enum
{
	WGM0_WGM_Normal,                    	// Normal
	WGM0_WGM_PWMPhaseCorrect8bit,       	// PWM Phase Correct, 8-bit TOP=0xFF
	WGM0_WGM_CTC_OCR,                   	// Clear Timer on Compare Match TOP=OCRA
	WGM0_WGM_PWMPhaseCorrect8bit2,      	// PWM Phase Correct, 8-bit TOP=0xFF
} WGM0_WGM_ENUM;
#define	_PWM0                   ((volatile BYTE_STRUCT*)&TCCR0)->bit6
#define	_CTC0                   ((volatile BYTE_STRUCT*)&TCCR0)->bit3
inline WGM0_WGM_ENUM get_WGM0(){ return (WGM0_WGM_ENUM)(_PWM0|(_CTC0 << 1)); }
inline void set_WGM0(WGM0_WGM_ENUM v){ _PWM0 = v; _CTC0 = v >> 1; }
// Clock Select - CS0_CS_ENUM - [bit field "CS0" TCCR0.(CS00 | CS01 | CS02)] Selects the clock divisor.
typedef enum
{
	CS0_CS_None,                        	// No clock source (Timer/Counter stopped)
	CS0_CS_DIV_1,                       	// clk (No prescaling)
	CS0_CS_DIV_8,                       	// clk / 8 (From prescaler)
	CS0_CS_DIV_32,                      	// clk / 32 (From prescaler)
	CS0_CS_DIV_64,                      	// clk / 64 (From prescaler)
	CS0_CS_DIV_128,                     	// clk / 128 (From prescaler)
	CS0_CS_DIV_256,                     	// clk / 256 (From prescaler)
	CS0_CS_DIV_1024,                    	// clk / 1024 (From prescaler)
} CS0_CS_ENUM;

typedef struct
{
	unsigned char	__CS0             : 3;
} CS0_STRUCT;

#define	_CS0                    ((volatile CS0_STRUCT*)&TCCR0)->__CS0
// Timer Overflow Interrupt Enable - Enabling_ENUM - [bit TIMSK.TOIE0]
#define	_TOIE0                  ((volatile BYTE_STRUCT*)&TIMSK)->bit0
// Compare Output Mode - _ENUM - [bit field "COMA0" TCCR0.(COM00 | COM01)] Controls the Output Compare pin (OCnA) behavior.

typedef struct
{
	unsigned char	__Reserved        : 4;
	unsigned char	__COMA0           : 2;
} COMA0_STRUCT;

#define	_COMA0                  ((volatile COMA0_STRUCT*)&TCCR0)->__COMA0
// Output Compare Match Interrupt Enable - Enabling_ENUM - [bit TIMSK.OCIE0]
#define	_OCIE0                  ((volatile BYTE_STRUCT*)&TIMSK)->bit1

// other TIMER_COUNTER_0 bit definitions
#define	_COM01                  ((volatile BYTE_STRUCT*)&TCCR0)->bit5
#define	_COM00                  ((volatile BYTE_STRUCT*)&TCCR0)->bit4
#define	_CS02                   ((volatile BYTE_STRUCT*)&TCCR0)->bit2
#define	_CS01                   ((volatile BYTE_STRUCT*)&TCCR0)->bit1
#define	_CS00                   ((volatile BYTE_STRUCT*)&TCCR0)->bit0
#define	_AS0                    ((volatile BYTE_STRUCT*)&ASSR)->bit3
#define	_TCN0UB                 ((volatile BYTE_STRUCT*)&ASSR)->bit2
#define	_OCR0UB                 ((volatile BYTE_STRUCT*)&ASSR)->bit1
#define	_TCR0UB                 ((volatile BYTE_STRUCT*)&ASSR)->bit0
#define	_OCF0                   ((volatile BYTE_STRUCT*)&TIFR)->bit1
#define	_TOV0                   ((volatile BYTE_STRUCT*)&TIFR)->bit0

//
// TIMER_COUNTER_1 variable definitions
//
// Waveform Generation Mode (CTC | PWM) - WGM1_WGM_ENUM - [bit aggregate (TCCR1A.PWM10 | TCCR1A.PWM11 | TCCR1B.CTC1)] Controls how the counter will cycle.
typedef enum
{
	WGM1_WGM_Normal,                    	// Normal
	WGM1_WGM_PWMPhaseCorrect8bit,       	// PWM Phase Correct, 8-bit TOP=0xFF
	WGM1_WGM_PWMPhaseCorrect9bit,       	// PWM Phase Correct, 9-bit TOP=0x1FF
	WGM1_WGM_PWMPhaseCorrect10bit,      	// PWM Phase Correct, 10-bit TOP=0x3FF
	WGM1_WGM_CTC_OCR,                   	// Clear Timer on Compare Match TOP=OCRA
	WGM1_WGM_Reserved,                  	// Reserved
	WGM1_WGM_Reserved2,                 	// Reserved
	WGM1_WGM_Reserved3,                 	// Reserved
} WGM1_WGM_ENUM;
#define	_PWM10                  ((volatile BYTE_STRUCT*)&TCCR1A)->bit0
#define	_PWM11                  ((volatile BYTE_STRUCT*)&TCCR1A)->bit1
#define	_CTC1                   ((volatile BYTE_STRUCT*)&TCCR1B)->bit3
inline WGM1_WGM_ENUM get_WGM1(){ return (WGM1_WGM_ENUM)(_PWM10|(_PWM11 << 1)|(_CTC1 << 2)); }
inline void set_WGM1(WGM1_WGM_ENUM v){ _PWM10 = v; _PWM11 = v >> 1; _CTC1 = v >> 2; }
// Clock Select - CS1_CS_ENUM - [bit field "CS1" TCCR1B.(CS10 | CS11 | CS12)] Selects the clock divisor or the external clock source.
typedef enum
{
	CS1_CS_None,                        	// No clock source (Timer/Counter stopped)
	CS1_CS_DIV_1,                       	// clk (No prescaling)
	CS1_CS_DIV_8,                       	// clk / 8 (From prescaler)
	CS1_CS_DIV_64,                      	// clk / 64 (From prescaler)
	CS1_CS_DIV_256,                     	// clk / 256 (From prescaler)
	CS1_CS_DIV_1024,                    	// clk / 1024 (From prescaler)
	CS1_CS_External_Falling,            	// External clock source, Clock on falling edge
	CS1_CS_External_Rising,             	// External clock source, Clock on rising edge
} CS1_CS_ENUM;

typedef struct
{
	unsigned char	__CS1             : 3;
} CS1_STRUCT;

#define	_CS1                    ((volatile CS1_STRUCT*)&TCCR1B)->__CS1
// Timer Overflow Interrupt Enable - Enabling_ENUM - [bit TIMSK.TOIE1]
#define	_TOIE1                  ((volatile BYTE_STRUCT*)&TIMSK)->bit2
// Input Capture Noise Cancel - Enabling_ENUM - [bit TCCR1B.ICNC1]
#define	_ICNC1                  ((volatile BYTE_STRUCT*)&TCCR1B)->bit7
// Input Capture Edge Select - Trigger_ENUM - [bit TCCR1B.ICES1]
#define	_ICES1                  ((volatile BYTE_STRUCT*)&TCCR1B)->bit6
// Input Capture Interrupt Enable - Enabling_ENUM - [bit TIMSK.TICIE1]
#define	_TICIE1                 ((volatile BYTE_STRUCT*)&TIMSK)->bit5
// Compare Output Mode A - _ENUM - [bit field "COMA1" TCCR1A.(COM1A0 | COM1A1)] Controls the Output Compare pin (OCnA) behavior.

typedef struct
{
	unsigned char	__Reserved        : 6;
	unsigned char	__COMA1           : 2;
} COMA1_STRUCT;

#define	_COMA1                  ((volatile COMA1_STRUCT*)&TCCR1A)->__COMA1
// Output Compare Match Interrupt Enable A - Enabling_ENUM - [bit TIMSK.OCIE1A]
#define	_OCIE1A                 ((volatile BYTE_STRUCT*)&TIMSK)->bit4
// Compare Output Mode B - _ENUM - [bit field "COMB1" TCCR1A.(COM1B0 | COM1B1)] Controls the Output Compare pin (OCnB) behavior.

typedef struct
{
	unsigned char	__Reserved        : 4;
	unsigned char	__COMB1           : 2;
} COMB1_STRUCT;

#define	_COMB1                  ((volatile COMB1_STRUCT*)&TCCR1A)->__COMB1
// Output Compare Match Interrupt Enable B - Enabling_ENUM - [bit TIMSK.OCIE1B]
#define	_OCIE1B                 ((volatile BYTE_STRUCT*)&TIMSK)->bit3

// other TIMER_COUNTER_1 bit definitions
#define	_ICF1                   ((volatile BYTE_STRUCT*)&TIFR)->bit5
#define	_OCF1A                  ((volatile BYTE_STRUCT*)&TIFR)->bit4
#define	_OCF1B                  ((volatile BYTE_STRUCT*)&TIFR)->bit3
#define	_TOV1                   ((volatile BYTE_STRUCT*)&TIFR)->bit2
#define	_COM1A1                 ((volatile BYTE_STRUCT*)&TCCR1A)->bit7
#define	_COM1A0                 ((volatile BYTE_STRUCT*)&TCCR1A)->bit6
#define	_COM1B1                 ((volatile BYTE_STRUCT*)&TCCR1A)->bit5
#define	_COM1B0                 ((volatile BYTE_STRUCT*)&TCCR1A)->bit4
#define	_CS12                   ((volatile BYTE_STRUCT*)&TCCR1B)->bit2
#define	_CS11                   ((volatile BYTE_STRUCT*)&TCCR1B)->bit1
#define	_CS10                   ((volatile BYTE_STRUCT*)&TCCR1B)->bit0

//
// TIMER_COUNTER_2 variable definitions
//
// Waveform Generation Mode (CTC | PWM) - WGM2_WGM_ENUM - [bit aggregate (TCCR2.PWM2 | TCCR2.CTC2)] Controls how the counter will cycle.
typedef enum
{
	WGM2_WGM_Normal,                    	// Normal
	WGM2_WGM_PWMPhaseCorrect8bit,       	// PWM Phase Correct, 8-bit TOP=0xFF
	WGM2_WGM_CTC_OCR,                   	// Clear Timer on Compare Match TOP=OCRA
	WGM2_WGM_PWMPhaseCorrect8bit2,      	// PWM Phase Correct, 8-bit TOP=0xFF
} WGM2_WGM_ENUM;
#define	_PWM2                   ((volatile BYTE_STRUCT*)&TCCR2)->bit6
#define	_CTC2                   ((volatile BYTE_STRUCT*)&TCCR2)->bit3
inline WGM2_WGM_ENUM get_WGM2(){ return (WGM2_WGM_ENUM)(_PWM2|(_CTC2 << 1)); }
inline void set_WGM2(WGM2_WGM_ENUM v){ _PWM2 = v; _CTC2 = v >> 1; }
// Clock Select - CS2_CS_ENUM - [bit field "CS2" TCCR2.(CS20 | CS21 | CS22)] Selects the clock divisor or the external clock source.
typedef enum
{
	CS2_CS_None,                        	// No clock source (Timer/Counter stopped)
	CS2_CS_DIV_1,                       	// clk (No prescaling)
	CS2_CS_DIV_8,                       	// clk / 8 (From prescaler)
	CS2_CS_DIV_64,                      	// clk / 64 (From prescaler)
	CS2_CS_DIV_256,                     	// clk / 256 (From prescaler)
	CS2_CS_DIV_1024,                    	// clk / 1024 (From prescaler)
	CS2_CS_External_Falling,            	// External clock source, Clock on falling edge
	CS2_CS_External_Rising,             	// External clock source, Clock on rising edge
} CS2_CS_ENUM;

typedef struct
{
	unsigned char	__CS2             : 3;
} CS2_STRUCT;

#define	_CS2                    ((volatile CS2_STRUCT*)&TCCR2)->__CS2
// Timer Overflow Interrupt Enable - Enabling_ENUM - [bit TIMSK.TOIE2]
#define	_TOIE2                  ((volatile BYTE_STRUCT*)&TIMSK)->bit6
// Compare Output Mode - _ENUM - [bit field "COMA2" TCCR2.(COM20 | COM21)] Controls the Output Compare pin (OCnA) behavior.

typedef struct
{
	unsigned char	__Reserved        : 4;
	unsigned char	__COMA2           : 2;
} COMA2_STRUCT;

#define	_COMA2                  ((volatile COMA2_STRUCT*)&TCCR2)->__COMA2
// Output Compare Match Interrupt Enable - Enabling_ENUM - [bit TIMSK.OCIE2]
#define	_OCIE2                  ((volatile BYTE_STRUCT*)&TIMSK)->bit7

// other TIMER_COUNTER_2 bit definitions
#define	_OCF2                   ((volatile BYTE_STRUCT*)&TIFR)->bit7
#define	_TOV2                   ((volatile BYTE_STRUCT*)&TIFR)->bit6
#define	_COM21                  ((volatile BYTE_STRUCT*)&TCCR2)->bit5
#define	_COM20                  ((volatile BYTE_STRUCT*)&TCCR2)->bit4
#define	_CS22                   ((volatile BYTE_STRUCT*)&TCCR2)->bit2
#define	_CS21                   ((volatile BYTE_STRUCT*)&TCCR2)->bit1
#define	_CS20                   ((volatile BYTE_STRUCT*)&TCCR2)->bit0

//
// UART variable definitions
//
// Receiver Enable - Enabling_ENUM - [bit UCR.RXEN]
#define	_RXEN                   ((volatile BYTE_STRUCT*)&UCR)->bit4
// Transmitter Enable - Enabling_ENUM - [bit UCR.TXEN]
#define	_TXEN                   ((volatile BYTE_STRUCT*)&UCR)->bit3
// 9 Bit Characters - NumBits_ENUM - [bit UCR.CHR9] Set the number of data bits to 9.
#define	_CHR9                   ((volatile BYTE_STRUCT*)&UCR)->bit2
// RX Complete Interrupt Enable - Enabling_ENUM - [bit UCR.RXCIE]
#define	_RXCIE                  ((volatile BYTE_STRUCT*)&UCR)->bit7
// TX Complete Interrupt Enable - Enabling_ENUM - [bit UCR.TXCIE]
#define	_TXCIE                  ((volatile BYTE_STRUCT*)&UCR)->bit6
// Data Register Empty Interrupt Enable - Enabling_ENUM - [bit UCR.UDRIE] Enable an interrupt when the transmit buffer (UDR) is ready to receive new data.
#define	_UDRIE                  ((volatile BYTE_STRUCT*)&UCR)->bit5

// other UART bit definitions
#define	_RXC                    ((volatile BYTE_STRUCT*)&USR)->bit7
#define	_TXC                    ((volatile BYTE_STRUCT*)&USR)->bit6
#define	_UDRE                   ((volatile BYTE_STRUCT*)&USR)->bit5
#define	_FE                     ((volatile BYTE_STRUCT*)&USR)->bit4
#define	_OR                     ((volatile BYTE_STRUCT*)&USR)->bit3
#define	_RXB8                   ((volatile BYTE_STRUCT*)&UCR)->bit1
#define	_TXB8                   ((volatile BYTE_STRUCT*)&UCR)->bit0

//
// WATCHDOG variable definitions
//
// Prescaler - WDP_WdtPrescale_ENUM - [bit field "WDP" WDTCR.(WDP0 | WDP1 | WDP2)] Sets the watchdog timeout period. Values are typical at 5v.
typedef enum
{
	WDP_WdtPrescale_WDTO_16MS,          	// Typical Time-out 16 ms
	WDP_WdtPrescale_WDTO_32MS,          	// Typical Time-out 32 ms
	WDP_WdtPrescale_WDTO_64MS,          	// Typical Time-out 64 ms
	WDP_WdtPrescale_WDTO_125MS,         	// Typical Time-out 125 ms
	WDP_WdtPrescale_WDTO_250MS,         	// Typical Time-out 250 ms
	WDP_WdtPrescale_WDTO_500MS,         	// Typical Time-out 500 ms
	WDP_WdtPrescale_WDTO_1S,            	// Typical Time-out 1 sec
	WDP_WdtPrescale_WDTO_2S,            	// Typical Time-out 2 sec
} WDP_WdtPrescale_ENUM;

typedef struct
{
	unsigned char	__WDP             : 3;
} WDP_STRUCT;

#define	_WDP                    ((volatile WDP_STRUCT*)&WDTCR)->__WDP
// Enable - Enabling_ENUM - [bit WDTCR.WDE] Enables the watchdog timer.
#define	_WDE                    ((volatile BYTE_STRUCT*)&WDTCR)->bit3

// other WATCHDOG bit definitions
#define	_WDTOE                  ((volatile BYTE_STRUCT*)&WDTCR)->bit4
#define	_WDP2                   ((volatile BYTE_STRUCT*)&WDTCR)->bit2
#define	_WDP1                   ((volatile BYTE_STRUCT*)&WDTCR)->bit1
#define	_WDP0                   ((volatile BYTE_STRUCT*)&WDTCR)->bit0

#define _AID_ATmega103_DEFINED_
#endif /* _AID_ATmega103_DEFINED_ */
