#ifndef _AID_ATmega161_DEFINED_

typedef enum
{
	Disabling_Enabled,                  	// Enabled
	Disabling_Disabled,                 	// Disabled
} Disabling_ENUM;

typedef enum
{
	Enabling_Disabled,                  	// Disabled
	Enabling_Enabled,                   	// Enabled
} Enabling_ENUM;

typedef enum
{
	ACIntModeSelect_OutputToggle,       	// Comparator Interrupt on Output Toggle
	ACIntModeSelect_Reserved,           	// Reserved
	ACIntModeSelect_FallingOutputEdge,  	// Comparator Interrupt on Falling Output Edge
	ACIntModeSelect_RisingOutputEdge,   	// Comparator Interrupt on Rising Output Edge
} ACIntModeSelect_ENUM;

typedef enum
{
	ACBandgapSelect_NoBandgap,          	// Use AIN0 as positive input
	ACBandgapSelect_Bandgap,            	// Use fixed bandgap reference voltage as positive input
} ACBandgapSelect_ENUM;

typedef enum
{
	SenseA_LowLevel,                    	// Low Level Generates Interrupt
	SenseA_AnyChange,                   	// Any Change Generates Interrupt
	SenseA_FallingEdge,                 	// Falling Edge Generates Interrupt
	SenseA_RisingEdge,                  	// Rising Edge Generates Interrupt
} SenseA_ENUM;

typedef enum
{
	SPIMaster_Slave,                    	// Slave Mode
	SPIMaster_Master,                   	// Master Mode
} SPIMaster_ENUM;

typedef enum
{
	SPR_DIV_4,                          	// clk / 4
	SPR_DIV_16,                         	// clk / 16
	SPR_DIV_64,                         	// clk / 64
	SPR_DIV_128,                        	// clk / 128
	SPR_DIV_2,                          	// clk / 2
	SPR_DIV_8,                          	// clk / 8
	SPR_DIV_32,                         	// clk / 32
	SPR_DIV_64b,                        	// clk / 64
} SPR_ENUM;

typedef enum
{
	SPIMode_Mode0,                      	// 0 - Leading (Rising) Edge Sample, Trailing (Falling) Edge Setup
	SPIMode_Mode1,                      	// 1 - Leading (Rising) Edge Setup, Trailing (Falling) Edge Sample
	SPIMode_Mode2,                      	// 2 - Leading (Falling) Edge Sample, Trailing (Rising) Edge Setup
	SPIMode_Mode3,                      	// 3 - Leading (Falling) Edge Setup, Trailing (Rising) Edge Sample
} SPIMode_ENUM;

typedef enum
{
	SPIDataOrder_MSBFirst,              	// Most Significant Bit First
	SPIDataOrder_LSBFirst,              	// Least Significant Bit First
} SPIDataOrder_ENUM;

typedef enum
{
	NumBits_Bits8,                      	// 8 Bits
	NumBits_Bits9,                      	// 9 Bits
} NumBits_ENUM;

//
// ANALOG_COMPARATOR variable definitions
//
// Analog Comparator Disable - Disabling_ENUM - [bit ACSR.ACD] Disables the Analog Comparator.
#define	_ACD                    ((volatile BYTE_STRUCT*)&ACSR)->bit7
// Interrupt Enable - Enabling_ENUM - [bit ACSR.ACIE] When enabled and the I-bit in the Status Register is set, the Analog Comparator interrupt is activated.
#define	_ACIE                   ((volatile BYTE_STRUCT*)&ACSR)->bit3
// Interrupt Mode Select - ACIntModeSelect_ENUM - [bit field "ACIS" ACSR.(ACIS0 | ACIS1)] Determine which comparator events trigger the Analog Comparator interrupt.

typedef struct
{
	unsigned char	__ACIS            : 2;
} ACIS_STRUCT;

#define	_ACIS                   ((volatile ACIS_STRUCT*)&ACSR)->__ACIS
// Input Capture Enable - Enabling_ENUM - [bit ACSR.ACIC] Enables the input capture function in Timer/Counter1 to be triggered by the Analog Comparator.
#define	_ACIC                   ((volatile BYTE_STRUCT*)&ACSR)->bit2
// Bandgap Select - ACBandgapSelect_ENUM - [bit ACSR.AINBG] Selects a bandgap reference voltage as the positive input.
#define	_AINBG                  ((volatile BYTE_STRUCT*)&ACSR)->bit6

// other ANALOG_COMPARATOR bit definitions
#define	_ACO                    ((volatile BYTE_STRUCT*)&ACSR)->bit5
#define	_ACI                    ((volatile BYTE_STRUCT*)&ACSR)->bit4
#define	_ACIS1                  ((volatile BYTE_STRUCT*)&ACSR)->bit1
#define	_ACIS0                  ((volatile BYTE_STRUCT*)&ACSR)->bit0

//
// CPU variable definitions
//
#define	_SRE                    ((volatile BYTE_STRUCT*)&MCUCR)->bit7
#define	_SRW10                  ((volatile BYTE_STRUCT*)&MCUCR)->bit6
#define	_SE                     ((volatile BYTE_STRUCT*)&MCUCR)->bit5
#define	_SM1                    ((volatile BYTE_STRUCT*)&MCUCR)->bit4
#define	_ISC11                  ((volatile BYTE_STRUCT*)&MCUCR)->bit3
#define	_ISC10                  ((volatile BYTE_STRUCT*)&MCUCR)->bit2
#define	_ISC01                  ((volatile BYTE_STRUCT*)&MCUCR)->bit1
#define	_ISC00                  ((volatile BYTE_STRUCT*)&MCUCR)->bit0
#define	_WDRF                   ((volatile BYTE_STRUCT*)&MCUSR)->bit3
#define	_BORF                   ((volatile BYTE_STRUCT*)&MCUSR)->bit2
#define	_EXTRF                  ((volatile BYTE_STRUCT*)&MCUSR)->bit1
#define	_PORF                   ((volatile BYTE_STRUCT*)&MCUSR)->bit0
#define	_SM0                    ((volatile BYTE_STRUCT*)&EMCUCR)->bit7
#define	_SRL2                   ((volatile BYTE_STRUCT*)&EMCUCR)->bit6
#define	_SRL1                   ((volatile BYTE_STRUCT*)&EMCUCR)->bit5
#define	_SRL0                   ((volatile BYTE_STRUCT*)&EMCUCR)->bit4
#define	_SRW01                  ((volatile BYTE_STRUCT*)&EMCUCR)->bit3
#define	_SRW00                  ((volatile BYTE_STRUCT*)&EMCUCR)->bit2
#define	_SRW11                  ((volatile BYTE_STRUCT*)&EMCUCR)->bit1
#define	_ISC2                   ((volatile BYTE_STRUCT*)&EMCUCR)->bit0
#define	_BLBSET                 ((volatile BYTE_STRUCT*)&SPMCR)->bit3
#define	_PGWRT                  ((volatile BYTE_STRUCT*)&SPMCR)->bit2
#define	_PGERS                  ((volatile BYTE_STRUCT*)&SPMCR)->bit1
#define	_SPMEN                  ((volatile BYTE_STRUCT*)&SPMCR)->bit0

//
// EEPROM variable definitions
//
#define	_EERIE                  ((volatile BYTE_STRUCT*)&EECR)->bit3
#define	_EEMWE                  ((volatile BYTE_STRUCT*)&EECR)->bit2
#define	_EEWE                   ((volatile BYTE_STRUCT*)&EECR)->bit1
#define	_EERE                   ((volatile BYTE_STRUCT*)&EECR)->bit0

//
// EXTERNAL_INTERRUPT variable definitions
//
// INT0 Interrupt Enable - Enabling_ENUM - [bit GIMSK.INT0] Enables the interrupt on the INT pin
#define	_INT0                   ((volatile BYTE_STRUCT*)&GIMSK)->bit6
// INT0 Interrupt Sense Control - SenseA_ENUM - [bit field "ISC0" MCUCR.(ISC00 | ISC01)] Specifies the type of signal that will generate an interrupt

typedef struct
{
	unsigned char	__ISC0            : 2;
} ISC0_STRUCT;

#define	_ISC0                   ((volatile ISC0_STRUCT*)&MCUCR)->__ISC0
// INT1 Interrupt Enable - Enabling_ENUM - [bit GIMSK.INT1] Enables the interrupt on the INT pin
#define	_INT1                   ((volatile BYTE_STRUCT*)&GIMSK)->bit7
// INT1 Interrupt Sense Control - SenseA_ENUM - [bit field "ISC1" MCUCR.(ISC10 | ISC11)] Specifies the type of signal that will generate an interrupt

typedef struct
{
	unsigned char	__Reserved        : 2;
	unsigned char	__ISC1            : 2;
} ISC1_STRUCT;

#define	_ISC1                   ((volatile ISC1_STRUCT*)&MCUCR)->__ISC1
// INT2 Interrupt Enable - Enabling_ENUM - [bit GIMSK.INT2] Enables the interrupt on the INT pin
#define	_INT2                   ((volatile BYTE_STRUCT*)&GIMSK)->bit5
// INT2 Interrupt Sense Control - ISC2_SenseA_ENUM - [bit EMCUCR.ISC2] Specifies the type of signal that will generate an interrupt
typedef enum
{
	ISC2_SenseA_FallingEdge,            	// Falling Edge Generates Interrupt
	ISC2_SenseA_RisingEdge,             	// Rising Edge Generates Interrupt
} ISC2_SenseA_ENUM;

// other EXTERNAL_INTERRUPT bit definitions
#define	_INTF1                  ((volatile BYTE_STRUCT*)&GIFR)->bit7
#define	_INTF0                  ((volatile BYTE_STRUCT*)&GIFR)->bit6
#define	_INTF2                  ((volatile BYTE_STRUCT*)&GIFR)->bit5

//
// SPI variable definitions
//
// SPI Enable - Enabling_ENUM - [bit SPCR.SPE]
#define	_SPE                    ((volatile BYTE_STRUCT*)&SPCR)->bit6
// Master/Slave Mode - SPIMaster_ENUM - [bit SPCR.MSTR]
#define	_MSTR                   ((volatile BYTE_STRUCT*)&SPCR)->bit4
// Clock Rate Select - SPR_ENUM - [bit aggregate (SPCR.SPR0 | SPCR.SPR1 | SPSR.SPI2X)] Controls the SCK rate of the device configured as a Master.
#define	_SPR0                   ((volatile BYTE_STRUCT*)&SPCR)->bit0
#define	_SPR1                   ((volatile BYTE_STRUCT*)&SPCR)->bit1
#define	_SPI2X                  ((volatile BYTE_STRUCT*)&SPSR)->bit0
inline SPR_ENUM get_SPR(){ return (SPR_ENUM)(_SPR0|(_SPR1 << 1)|(_SPI2X << 2)); }
inline void set_SPR(SPR_ENUM v){ _SPR0 = v; _SPR1 = v >> 1; _SPI2X = v >> 2; }
// SPI Mode - SPIMode_ENUM - [bit field "MODE" SPCR.(CPHA | CPOL)] Sets the relationship between data output change and data input sample, and the synchronous clock (SCK).

typedef struct
{
	unsigned char	__Reserved        : 2;
	unsigned char	__MODE            : 2;
} MODE_STRUCT;

#define	_MODE                   ((volatile MODE_STRUCT*)&SPCR)->__MODE
// Data Order - SPIDataOrder_ENUM - [bit SPCR.DORD] Sets the order in which bits are transmitted.
#define	_DORD                   ((volatile BYTE_STRUCT*)&SPCR)->bit5
// SPI Interrupt Enable - Enabling_ENUM - [bit SPCR.SPIE]
#define	_SPIE                   ((volatile BYTE_STRUCT*)&SPCR)->bit7

// other SPI bit definitions
#define	_SPIF                   ((volatile BYTE_STRUCT*)&SPSR)->bit7
#define	_WCOL                   ((volatile BYTE_STRUCT*)&SPSR)->bit6
#define	_CPOL                   ((volatile BYTE_STRUCT*)&SPCR)->bit3
#define	_CPHA                   ((volatile BYTE_STRUCT*)&SPCR)->bit2

//
// TIMER_COUNTER_0 variable definitions
//
#define	_FOC0                   ((volatile BYTE_STRUCT*)&TCCR0)->bit7
#define	_WGM00                  ((volatile BYTE_STRUCT*)&TCCR0)->bit6
#define	_COM01                  ((volatile BYTE_STRUCT*)&TCCR0)->bit5
#define	_COM00                  ((volatile BYTE_STRUCT*)&TCCR0)->bit4
#define	_WGM01                  ((volatile BYTE_STRUCT*)&TCCR0)->bit3
#define	_CS02                   ((volatile BYTE_STRUCT*)&TCCR0)->bit2
#define	_CS01                   ((volatile BYTE_STRUCT*)&TCCR0)->bit1
#define	_CS00                   ((volatile BYTE_STRUCT*)&TCCR0)->bit0
#define	_TOIE0                  ((volatile BYTE_STRUCT*)&TIMSK)->bit1
#define	_OCIE0                  ((volatile BYTE_STRUCT*)&TIMSK)->bit0
#define	_TOV0                   ((volatile BYTE_STRUCT*)&TIFR)->bit1
#define	_OCF0                   ((volatile BYTE_STRUCT*)&TIFR)->bit0
#define	_PSR10                  ((volatile BYTE_STRUCT*)&SFIOR)->bit0

//
// TIMER_COUNTER_1 variable definitions
//
#define	_TOIE1                  ((volatile BYTE_STRUCT*)&TIMSK)->bit7
#define	_OCIE1A                 ((volatile BYTE_STRUCT*)&TIMSK)->bit6
#define	_OCIE1B                 ((volatile BYTE_STRUCT*)&TIMSK)->bit5
#define	_TICIE1                 ((volatile BYTE_STRUCT*)&TIMSK)->bit3
#define	_TOV1                   ((volatile BYTE_STRUCT*)&TIFR)->bit7
#define	_OCF1A                  ((volatile BYTE_STRUCT*)&TIFR)->bit6
#define	_OCF1B                  ((volatile BYTE_STRUCT*)&TIFR)->bit5
#define	_ICF1                   ((volatile BYTE_STRUCT*)&TIFR)->bit3
#define	_COM1A1                 ((volatile BYTE_STRUCT*)&TCCR1A)->bit7
#define	_COM1A0                 ((volatile BYTE_STRUCT*)&TCCR1A)->bit6
#define	_COM1B1                 ((volatile BYTE_STRUCT*)&TCCR1A)->bit5
#define	_COM1B0                 ((volatile BYTE_STRUCT*)&TCCR1A)->bit4
#define	_FOC1A                  ((volatile BYTE_STRUCT*)&TCCR1A)->bit3
#define	_FOC1B                  ((volatile BYTE_STRUCT*)&TCCR1A)->bit2
#define	_WGM11                  ((volatile BYTE_STRUCT*)&TCCR1A)->bit1
#define	_WGM10                  ((volatile BYTE_STRUCT*)&TCCR1A)->bit0
#define	_ICNC1                  ((volatile BYTE_STRUCT*)&TCCR1B)->bit7
#define	_ICES1                  ((volatile BYTE_STRUCT*)&TCCR1B)->bit6
#define	_CTC1                   ((volatile BYTE_STRUCT*)&TCCR1B)->bit3
#define	_CS12                   ((volatile BYTE_STRUCT*)&TCCR1B)->bit2
#define	_CS11                   ((volatile BYTE_STRUCT*)&TCCR1B)->bit1
#define	_CS10                   ((volatile BYTE_STRUCT*)&TCCR1B)->bit0

//
// TIMER_COUNTER_2 variable definitions
//
#define	_TOIE2                  ((volatile BYTE_STRUCT*)&TIMSK)->bit4
#define	_OCIE2                  ((volatile BYTE_STRUCT*)&TIMSK)->bit2
#define	_TOV2                   ((volatile BYTE_STRUCT*)&TIFR)->bit4
#define	_OCF2                   ((volatile BYTE_STRUCT*)&TIFR)->bit2
#define	_FOC2                   ((volatile BYTE_STRUCT*)&TCCR2)->bit7
#define	_PWM2                   ((volatile BYTE_STRUCT*)&TCCR2)->bit6
#define	_COM21                  ((volatile BYTE_STRUCT*)&TCCR2)->bit5
#define	_COM20                  ((volatile BYTE_STRUCT*)&TCCR2)->bit4
#define	_CTC2                   ((volatile BYTE_STRUCT*)&TCCR2)->bit3
#define	_CS22                   ((volatile BYTE_STRUCT*)&TCCR2)->bit2
#define	_CS21                   ((volatile BYTE_STRUCT*)&TCCR2)->bit1
#define	_CS20                   ((volatile BYTE_STRUCT*)&TCCR2)->bit0
#define	_AS2                    ((volatile BYTE_STRUCT*)&ASSR)->bit3
#define	_TCN2UB                 ((volatile BYTE_STRUCT*)&ASSR)->bit2
#define	_OCR2UB                 ((volatile BYTE_STRUCT*)&ASSR)->bit1
#define	_TCR2UB                 ((volatile BYTE_STRUCT*)&ASSR)->bit0
#define	_PSR2                   ((volatile BYTE_STRUCT*)&SFIOR)->bit1

//
// USART0 variable definitions
//
// Receiver Enable - Enabling_ENUM - [bit UCSR0B.RXEN0]
#define	_RXEN0                  ((volatile BYTE_STRUCT*)&UCSR0B)->bit4
// Transmitter Enable - Enabling_ENUM - [bit UCSR0B.TXEN0]
#define	_TXEN0                  ((volatile BYTE_STRUCT*)&UCSR0B)->bit3
// 9 Bit Characters - NumBits_ENUM - [bit UCSR0B.CHR90] Set the number of data bits to 9.
#define	_CHR90                  ((volatile BYTE_STRUCT*)&UCSR0B)->bit2
// Double Transmission Speed - Enabling_ENUM - [bit UCSR0A.U2X0]
#define	_U2X0                   ((volatile BYTE_STRUCT*)&UCSR0A)->bit1
// Multi-processor Communication Mode - Enabling_ENUM - [bit UCSR0A.MPCM0]
#define	_MPCM0                  ((volatile BYTE_STRUCT*)&UCSR0A)->bit0
// RX Complete Interrupt Enable - Enabling_ENUM - [bit UCSR0B.RXCIE0]
#define	_RXCIE0                 ((volatile BYTE_STRUCT*)&UCSR0B)->bit7
// TX Complete Interrupt Enable - Enabling_ENUM - [bit UCSR0B.TXCIE0]
#define	_TXCIE0                 ((volatile BYTE_STRUCT*)&UCSR0B)->bit6
// Data Register Empty Interrupt Enable - Enabling_ENUM - [bit UCSR0B.UDRIE0] Enable an interrupt when the transmit buffer (UDR) is ready to receive new data.
#define	_UDRIE0                 ((volatile BYTE_STRUCT*)&UCSR0B)->bit5

// other USART0 bit definitions
#define	_RXC0                   ((volatile BYTE_STRUCT*)&UCSR0A)->bit7
#define	_TXC0                   ((volatile BYTE_STRUCT*)&UCSR0A)->bit6
#define	_UDRE0                  ((volatile BYTE_STRUCT*)&UCSR0A)->bit5
#define	_FE0                    ((volatile BYTE_STRUCT*)&UCSR0A)->bit4
#define	_OR0                    ((volatile BYTE_STRUCT*)&UCSR0A)->bit3
#define	_RXB80                  ((volatile BYTE_STRUCT*)&UCSR0B)->bit1
#define	_TXB80                  ((volatile BYTE_STRUCT*)&UCSR0B)->bit0
#define	_UBRRHI00               ((volatile BYTE_STRUCT*)&UBRRHI)->bit0
#define	_UBRRHI01               ((volatile BYTE_STRUCT*)&UBRRHI)->bit1
#define	_UBRRHI02               ((volatile BYTE_STRUCT*)&UBRRHI)->bit2
#define	_UBRRHI03               ((volatile BYTE_STRUCT*)&UBRRHI)->bit3

//
// USART1 variable definitions
//
// Receiver Enable - Enabling_ENUM - [bit UCSR1B.RXEN1]
#define	_RXEN1                  ((volatile BYTE_STRUCT*)&UCSR1B)->bit4
// Transmitter Enable - Enabling_ENUM - [bit UCSR1B.TXEN1]
#define	_TXEN1                  ((volatile BYTE_STRUCT*)&UCSR1B)->bit3
// 9 Bit Characters - NumBits_ENUM - [bit UCSR1B.CHR91] Set the number of data bits to 9.
#define	_CHR91                  ((volatile BYTE_STRUCT*)&UCSR1B)->bit2
// Double Transmission Speed - Enabling_ENUM - [bit UCSR1A.U2X1]
#define	_U2X1                   ((volatile BYTE_STRUCT*)&UCSR1A)->bit1
// Multi-processor Communication Mode - Enabling_ENUM - [bit UCSR1A.MPCM1]
#define	_MPCM1                  ((volatile BYTE_STRUCT*)&UCSR1A)->bit0
// RX Complete Interrupt Enable - Enabling_ENUM - [bit UCSR1B.RXCIE1]
#define	_RXCIE1                 ((volatile BYTE_STRUCT*)&UCSR1B)->bit7
// TX Complete Interrupt Enable - Enabling_ENUM - [bit UCSR1B.TXCIE1]
#define	_TXCIE1                 ((volatile BYTE_STRUCT*)&UCSR1B)->bit6
// Data Register Empty Interrupt Enable - Enabling_ENUM - [bit UCSR1B.UDRIE1] Enable an interrupt when the transmit buffer (UDR) is ready to receive new data.
#define	_UDRIE1                 ((volatile BYTE_STRUCT*)&UCSR1B)->bit5

// other USART1 bit definitions
#define	_RXC1                   ((volatile BYTE_STRUCT*)&UCSR1A)->bit7
#define	_TXC1                   ((volatile BYTE_STRUCT*)&UCSR1A)->bit6
#define	_UDRE1                  ((volatile BYTE_STRUCT*)&UCSR1A)->bit5
#define	_FE1                    ((volatile BYTE_STRUCT*)&UCSR1A)->bit4
#define	_OR1                    ((volatile BYTE_STRUCT*)&UCSR1A)->bit3
#define	_RXB81                  ((volatile BYTE_STRUCT*)&UCSR1B)->bit1
#define	_TXB81                  ((volatile BYTE_STRUCT*)&UCSR1B)->bit0
#define	_UBRRHI10               ((volatile BYTE_STRUCT*)&UBRRHI)->bit4
#define	_UBRRHI11               ((volatile BYTE_STRUCT*)&UBRRHI)->bit5
#define	_UBRRHI12               ((volatile BYTE_STRUCT*)&UBRRHI)->bit6
#define	_UBRRHI13               ((volatile BYTE_STRUCT*)&UBRRHI)->bit7

//
// WATCHDOG variable definitions
//
// Prescaler - WDP_WdtPrescale_ENUM - [bit field "WDP" WDTCR.(WDP0 | WDP1 | WDP2)] Sets the watchdog timeout period. Values are typical at 5v.
typedef enum
{
	WDP_WdtPrescale_WDTO_16MS,          	// Typical Time-out 16 ms
	WDP_WdtPrescale_WDTO_32MS,          	// Typical Time-out 32 ms
	WDP_WdtPrescale_WDTO_64MS,          	// Typical Time-out 64 ms
	WDP_WdtPrescale_WDTO_125MS,         	// Typical Time-out 125 ms
	WDP_WdtPrescale_WDTO_250MS,         	// Typical Time-out 250 ms
	WDP_WdtPrescale_WDTO_500MS,         	// Typical Time-out 500 ms
	WDP_WdtPrescale_WDTO_1S,            	// Typical Time-out 1 sec
	WDP_WdtPrescale_WDTO_2S,            	// Typical Time-out 2 sec
} WDP_WdtPrescale_ENUM;

typedef struct
{
	unsigned char	__WDP             : 3;
} WDP_STRUCT;

#define	_WDP                    ((volatile WDP_STRUCT*)&WDTCR)->__WDP
// Enable - Enabling_ENUM - [bit WDTCR.WDE] Enables the watchdog timer.
#define	_WDE                    ((volatile BYTE_STRUCT*)&WDTCR)->bit3

// other WATCHDOG bit definitions
#define	_WDTOE                  ((volatile BYTE_STRUCT*)&WDTCR)->bit4
#define	_WDP2                   ((volatile BYTE_STRUCT*)&WDTCR)->bit2
#define	_WDP1                   ((volatile BYTE_STRUCT*)&WDTCR)->bit1
#define	_WDP0                   ((volatile BYTE_STRUCT*)&WDTCR)->bit0

#define _AID_ATmega161_DEFINED_
#endif /* _AID_ATmega161_DEFINED_ */
