#ifndef _AID_ATmega162_DEFINED_

typedef enum
{
	Disabling_Enabled,                  	// Enabled
	Disabling_Disabled,                 	// Disabled
} Disabling_ENUM;

typedef enum
{
	Enabling_Disabled,                  	// Disabled
	Enabling_Enabled,                   	// Enabled
} Enabling_ENUM;

typedef enum
{
	ACIntModeSelect_OutputToggle,       	// Comparator Interrupt on Output Toggle
	ACIntModeSelect_Reserved,           	// Reserved
	ACIntModeSelect_FallingOutputEdge,  	// Comparator Interrupt on Falling Output Edge
	ACIntModeSelect_RisingOutputEdge,   	// Comparator Interrupt on Rising Output Edge
} ACIntModeSelect_ENUM;

typedef enum
{
	ACBandgapSelect_NoBandgap,          	// Use AIN0 as positive input
	ACBandgapSelect_Bandgap,            	// Use fixed bandgap reference voltage as positive input
} ACBandgapSelect_ENUM;

typedef enum
{
	SenseA_LowLevel,                    	// Low Level Generates Interrupt
	SenseA_AnyChange,                   	// Any Change Generates Interrupt
	SenseA_FallingEdge,                 	// Falling Edge Generates Interrupt
	SenseA_RisingEdge,                  	// Rising Edge Generates Interrupt
} SenseA_ENUM;

typedef enum
{
	SPIMaster_Slave,                    	// Slave Mode
	SPIMaster_Master,                   	// Master Mode
} SPIMaster_ENUM;

typedef enum
{
	SPR_DIV_4,                          	// clk / 4
	SPR_DIV_16,                         	// clk / 16
	SPR_DIV_64,                         	// clk / 64
	SPR_DIV_128,                        	// clk / 128
	SPR_DIV_2,                          	// clk / 2
	SPR_DIV_8,                          	// clk / 8
	SPR_DIV_32,                         	// clk / 32
	SPR_DIV_64b,                        	// clk / 64
} SPR_ENUM;

typedef enum
{
	SPIMode_Mode0,                      	// 0 - Leading (Rising) Edge Sample, Trailing (Falling) Edge Setup
	SPIMode_Mode1,                      	// 1 - Leading (Rising) Edge Setup, Trailing (Falling) Edge Sample
	SPIMode_Mode2,                      	// 2 - Leading (Falling) Edge Sample, Trailing (Rising) Edge Setup
	SPIMode_Mode3,                      	// 3 - Leading (Falling) Edge Setup, Trailing (Rising) Edge Sample
} SPIMode_ENUM;

typedef enum
{
	SPIDataOrder_MSBFirst,              	// Most Significant Bit First
	SPIDataOrder_LSBFirst,              	// Least Significant Bit First
} SPIDataOrder_ENUM;

typedef enum
{
	Trigger_Falling,                    	// Falling Edge Trigger
	Trigger_Rising,                     	// Rising Edge Trigger
} Trigger_ENUM;

typedef enum
{
	UsartCharacterSize_FiveBits,        	// 5 bits
	UsartCharacterSize_SixBits,         	// 6 bits
	UsartCharacterSize_SevenBits,       	// 7 bits
	UsartCharacterSize_EightBits,       	// 8 bits
	UsartCharacterSize_Reserved,        	// Reserved
	UsartCharacterSize_Reserved2,       	// Reserved
	UsartCharacterSize_Reserved3,       	// Reserved
	UsartCharacterSize_NineBits,        	// 9 bits
} UsartCharacterSize_ENUM;

typedef enum
{
	UsartStopBitSelect_OneStopBit,      	// 1 stop bit
	UsartStopBitSelect_TwoStopBits,     	// 2 stop bits
} UsartStopBitSelect_ENUM;

typedef enum
{
	UsartParityMode_Disabled,           	// Disabled
	UsartParityMode_Reserved,           	// Reserved
	UsartParityMode_EvenParity,         	// Even Parity
	UsartParityMode_OddParity,          	// Odd Parity
} UsartParityMode_ENUM;

typedef enum
{
	UsartClockPolarity_Normal,          	// TX Changed on Rising Edge, RX Sampled on Falling Edge
	UsartClockPolarity_Inverted,        	// TX Changed on Falling Edge, RX Sampled on Rising Edge
} UsartClockPolarity_ENUM;

//
// ANALOG_COMPARATOR variable definitions
//
// Analog Comparator Disable - Disabling_ENUM - [bit ACSR.ACD] Disables the Analog Comparator.
#define	_ACD                    ((volatile BYTE_STRUCT*)&ACSR)->bit7
// Interrupt Enable - Enabling_ENUM - [bit ACSR.ACIE] When enabled and the I-bit in the Status Register is set, the Analog Comparator interrupt is activated.
#define	_ACIE                   ((volatile BYTE_STRUCT*)&ACSR)->bit3
// Interrupt Mode Select - ACIntModeSelect_ENUM - [bit field "ACIS" ACSR.(ACIS0 | ACIS1)] Determine which comparator events trigger the Analog Comparator interrupt.

typedef struct
{
	unsigned char	__ACIS            : 2;
} ACIS_STRUCT;

#define	_ACIS                   ((volatile ACIS_STRUCT*)&ACSR)->__ACIS
// Input Capture Enable - Enabling_ENUM - [bit ACSR.ACIC] Enables the input capture function in Timer/Counter1 to be triggered by the Analog Comparator.
#define	_ACIC                   ((volatile BYTE_STRUCT*)&ACSR)->bit2
// Bandgap Select - ACBandgapSelect_ENUM - [bit ACSR.ACBG] Selects a bandgap reference voltage as the positive input.
#define	_ACBG                   ((volatile BYTE_STRUCT*)&ACSR)->bit6

// other ANALOG_COMPARATOR bit definitions
#define	_ACO                    ((volatile BYTE_STRUCT*)&ACSR)->bit5
#define	_ACI                    ((volatile BYTE_STRUCT*)&ACSR)->bit4
#define	_ACIS1                  ((volatile BYTE_STRUCT*)&ACSR)->bit1
#define	_ACIS0                  ((volatile BYTE_STRUCT*)&ACSR)->bit0

//
// BOOT_LOAD variable definitions
//
#define	_SPMIE                  ((volatile BYTE_STRUCT*)&SPMCR)->bit7
#define	_RWWSB                  ((volatile BYTE_STRUCT*)&SPMCR)->bit6
#define	_RWWSRE                 ((volatile BYTE_STRUCT*)&SPMCR)->bit4
#define	_BLBSET                 ((volatile BYTE_STRUCT*)&SPMCR)->bit3
#define	_PGWRT                  ((volatile BYTE_STRUCT*)&SPMCR)->bit2
#define	_PGERS                  ((volatile BYTE_STRUCT*)&SPMCR)->bit1
#define	_SPMEN                  ((volatile BYTE_STRUCT*)&SPMCR)->bit0

//
// CPU variable definitions
//
#define	_SRE                    ((volatile BYTE_STRUCT*)&MCUCR)->bit7
#define	_SRW10                  ((volatile BYTE_STRUCT*)&MCUCR)->bit6
#define	_SE                     ((volatile BYTE_STRUCT*)&MCUCR)->bit5
#define	_SM1                    ((volatile BYTE_STRUCT*)&MCUCR)->bit4
#define	_ISC11                  ((volatile BYTE_STRUCT*)&MCUCR)->bit3
#define	_ISC10                  ((volatile BYTE_STRUCT*)&MCUCR)->bit2
#define	_ISC01                  ((volatile BYTE_STRUCT*)&MCUCR)->bit1
#define	_ISC00                  ((volatile BYTE_STRUCT*)&MCUCR)->bit0
#define	_JTD                    ((volatile BYTE_STRUCT*)&MCUCSR)->bit7
#define	_SM2                    ((volatile BYTE_STRUCT*)&MCUCSR)->bit5
#define	_JTRF                   ((volatile BYTE_STRUCT*)&MCUCSR)->bit4
#define	_WDRF                   ((volatile BYTE_STRUCT*)&MCUCSR)->bit3
#define	_BORF                   ((volatile BYTE_STRUCT*)&MCUCSR)->bit2
#define	_EXTRF                  ((volatile BYTE_STRUCT*)&MCUCSR)->bit1
#define	_PORF                   ((volatile BYTE_STRUCT*)&MCUCSR)->bit0
#define	_SM0                    ((volatile BYTE_STRUCT*)&EMCUCR)->bit7
#define	_SRL2                   ((volatile BYTE_STRUCT*)&EMCUCR)->bit6
#define	_SRL1                   ((volatile BYTE_STRUCT*)&EMCUCR)->bit5
#define	_SRL0                   ((volatile BYTE_STRUCT*)&EMCUCR)->bit4
#define	_SRW01                  ((volatile BYTE_STRUCT*)&EMCUCR)->bit3
#define	_SRW00                  ((volatile BYTE_STRUCT*)&EMCUCR)->bit2
#define	_SRW11                  ((volatile BYTE_STRUCT*)&EMCUCR)->bit1
#define	_ISC2                   ((volatile BYTE_STRUCT*)&EMCUCR)->bit0
#define	_CLKPCE                 ((volatile BYTE_STRUCT*)&CLKPR)->bit7
#define	_CLKPS3                 ((volatile BYTE_STRUCT*)&CLKPR)->bit3
#define	_CLKPS2                 ((volatile BYTE_STRUCT*)&CLKPR)->bit2
#define	_CLKPS1                 ((volatile BYTE_STRUCT*)&CLKPR)->bit1
#define	_CLKPS0                 ((volatile BYTE_STRUCT*)&CLKPR)->bit0
#define	_TSM                    ((volatile BYTE_STRUCT*)&SFIOR)->bit7
#define	_XMBK                   ((volatile BYTE_STRUCT*)&SFIOR)->bit6
#define	_XMM2                   ((volatile BYTE_STRUCT*)&SFIOR)->bit5
#define	_XMM1                   ((volatile BYTE_STRUCT*)&SFIOR)->bit4
#define	_XMM0                   ((volatile BYTE_STRUCT*)&SFIOR)->bit3
#define	_PUD                    ((volatile BYTE_STRUCT*)&SFIOR)->bit2
#define	_PSR2                   ((volatile BYTE_STRUCT*)&SFIOR)->bit1
#define	_PSR310                 ((volatile BYTE_STRUCT*)&SFIOR)->bit0

//
// EEPROM variable definitions
//
#define	_EERIE                  ((volatile BYTE_STRUCT*)&EECR)->bit3
#define	_EEMWE                  ((volatile BYTE_STRUCT*)&EECR)->bit2
#define	_EEWE                   ((volatile BYTE_STRUCT*)&EECR)->bit1
#define	_EERE                   ((volatile BYTE_STRUCT*)&EECR)->bit0

//
// EXTERNAL_INTERRUPT variable definitions
//
// INT0 Interrupt Enable - Enabling_ENUM - [bit GICR.INT0] Enables the interrupt on the INT pin
#define	_INT0                   ((volatile BYTE_STRUCT*)&GICR)->bit6
// INT0 Interrupt Sense Control - SenseA_ENUM - [bit field "ISC0" MCUCR.(ISC00 | ISC01)] Specifies the type of signal that will generate an interrupt

typedef struct
{
	unsigned char	__ISC0            : 2;
} ISC0_STRUCT;

#define	_ISC0                   ((volatile ISC0_STRUCT*)&MCUCR)->__ISC0
// INT1 Interrupt Enable - Enabling_ENUM - [bit GICR.INT1] Enables the interrupt on the INT pin
#define	_INT1                   ((volatile BYTE_STRUCT*)&GICR)->bit7
// INT1 Interrupt Sense Control - SenseA_ENUM - [bit field "ISC1" MCUCR.(ISC10 | ISC11)] Specifies the type of signal that will generate an interrupt

typedef struct
{
	unsigned char	__Reserved        : 2;
	unsigned char	__ISC1            : 2;
} ISC1_STRUCT;

#define	_ISC1                   ((volatile ISC1_STRUCT*)&MCUCR)->__ISC1
// INT2 Interrupt Enable - Enabling_ENUM - [bit GICR.INT2] Enables the interrupt on the INT pin
#define	_INT2                   ((volatile BYTE_STRUCT*)&GICR)->bit5
// INT2 Interrupt Sense Control - ISC2_SenseA_ENUM - [bit EMCUCR.ISC2] Specifies the type of signal that will generate an interrupt
typedef enum
{
	ISC2_SenseA_FallingEdge,            	// Falling Edge Generates Interrupt
	ISC2_SenseA_RisingEdge,             	// Rising Edge Generates Interrupt
} ISC2_SenseA_ENUM;
// PCINT0 Interrupt Enable - Enabling_ENUM - [bit PCMSK0.PCINT0] Enables interrupts on PCINT0
#define	_PCINT0                 ((volatile BYTE_STRUCT*)&PCMSK0)->bit0
// PCINT1 Interrupt Enable - Enabling_ENUM - [bit PCMSK0.PCINT1] Enables interrupts on PCINT1
#define	_PCINT1                 ((volatile BYTE_STRUCT*)&PCMSK0)->bit1
// PCINT2 Interrupt Enable - Enabling_ENUM - [bit PCMSK0.PCINT2] Enables interrupts on PCINT2
#define	_PCINT2                 ((volatile BYTE_STRUCT*)&PCMSK0)->bit2
// PCINT3 Interrupt Enable - Enabling_ENUM - [bit PCMSK0.PCINT3] Enables interrupts on PCINT3
#define	_PCINT3                 ((volatile BYTE_STRUCT*)&PCMSK0)->bit3
// PCINT4 Interrupt Enable - Enabling_ENUM - [bit PCMSK0.PCINT4] Enables interrupts on PCINT4
#define	_PCINT4                 ((volatile BYTE_STRUCT*)&PCMSK0)->bit4
// PCINT5 Interrupt Enable - Enabling_ENUM - [bit PCMSK0.PCINT5] Enables interrupts on PCINT5
#define	_PCINT5                 ((volatile BYTE_STRUCT*)&PCMSK0)->bit5
// PCINT6 Interrupt Enable - Enabling_ENUM - [bit PCMSK0.PCINT6] Enables interrupts on PCINT6
#define	_PCINT6                 ((volatile BYTE_STRUCT*)&PCMSK0)->bit6
// PCINT7 Interrupt Enable - Enabling_ENUM - [bit PCMSK0.PCINT7] Enables interrupts on PCINT7
#define	_PCINT7                 ((volatile BYTE_STRUCT*)&PCMSK0)->bit7
// PCINT8 Interrupt Enable - Enabling_ENUM - [bit PCMSK1.PCINT8] Enables interrupts on PCINT8
#define	_PCINT8                 ((volatile BYTE_STRUCT*)&PCMSK1)->bit0
// PCINT9 Interrupt Enable - Enabling_ENUM - [bit PCMSK1.PCINT9] Enables interrupts on PCINT9
#define	_PCINT9                 ((volatile BYTE_STRUCT*)&PCMSK1)->bit1
// PCINT10 Interrupt Enable - Enabling_ENUM - [bit PCMSK1.PCINT10] Enables interrupts on PCINT10
#define	_PCINT10                ((volatile BYTE_STRUCT*)&PCMSK1)->bit2
// PCINT11 Interrupt Enable - Enabling_ENUM - [bit PCMSK1.PCINT11] Enables interrupts on PCINT11
#define	_PCINT11                ((volatile BYTE_STRUCT*)&PCMSK1)->bit3
// PCINT12 Interrupt Enable - Enabling_ENUM - [bit PCMSK1.PCINT12] Enables interrupts on PCINT12
#define	_PCINT12                ((volatile BYTE_STRUCT*)&PCMSK1)->bit4
// PCINT13 Interrupt Enable - Enabling_ENUM - [bit PCMSK1.PCINT13] Enables interrupts on PCINT13
#define	_PCINT13                ((volatile BYTE_STRUCT*)&PCMSK1)->bit5
// PCINT14 Interrupt Enable - Enabling_ENUM - [bit PCMSK1.PCINT14] Enables interrupts on PCINT14
#define	_PCINT14                ((volatile BYTE_STRUCT*)&PCMSK1)->bit6
// PCINT15 Interrupt Enable - Enabling_ENUM - [bit PCMSK1.PCINT15] Enables interrupts on PCINT15
#define	_PCINT15                ((volatile BYTE_STRUCT*)&PCMSK1)->bit7

// other EXTERNAL_INTERRUPT bit definitions
#define	_PCIE1                  ((volatile BYTE_STRUCT*)&GICR)->bit4
#define	_PCIE0                  ((volatile BYTE_STRUCT*)&GICR)->bit3
#define	_IVSEL                  ((volatile BYTE_STRUCT*)&GICR)->bit1
#define	_IVCE                   ((volatile BYTE_STRUCT*)&GICR)->bit0
#define	_INTF1                  ((volatile BYTE_STRUCT*)&GIFR)->bit7
#define	_INTF0                  ((volatile BYTE_STRUCT*)&GIFR)->bit6
#define	_INTF2                  ((volatile BYTE_STRUCT*)&GIFR)->bit5
#define	_PCIF1                  ((volatile BYTE_STRUCT*)&GIFR)->bit4
#define	_PCIF0                  ((volatile BYTE_STRUCT*)&GIFR)->bit3

//
// JTAG variable definitions
//
// JTAG Disable - Disabling_ENUM - [bit MCUCSR.JTD] Disables JTAG operation.

// other JTAG bit definitions

//
// SPI variable definitions
//
// SPI Enable - Enabling_ENUM - [bit SPCR.SPE]
#define	_SPE                    ((volatile BYTE_STRUCT*)&SPCR)->bit6
// Master/Slave Mode - SPIMaster_ENUM - [bit SPCR.MSTR]
#define	_MSTR                   ((volatile BYTE_STRUCT*)&SPCR)->bit4
// Clock Rate Select - SPR_ENUM - [bit aggregate (SPCR.SPR0 | SPCR.SPR1 | SPSR.SPI2X)] Controls the SCK rate of the device configured as a Master.
#define	_SPR0                   ((volatile BYTE_STRUCT*)&SPCR)->bit0
#define	_SPR1                   ((volatile BYTE_STRUCT*)&SPCR)->bit1
#define	_SPI2X                  ((volatile BYTE_STRUCT*)&SPSR)->bit0
inline SPR_ENUM get_SPR(){ return (SPR_ENUM)(_SPR0|(_SPR1 << 1)|(_SPI2X << 2)); }
inline void set_SPR(SPR_ENUM v){ _SPR0 = v; _SPR1 = v >> 1; _SPI2X = v >> 2; }
// SPI Mode - SPIMode_ENUM - [bit field "MODE" SPCR.(CPHA | CPOL)] Sets the relationship between data output change and data input sample, and the synchronous clock (SCK).

typedef struct
{
	unsigned char	__Reserved        : 2;
	unsigned char	__MODE            : 2;
} MODE_STRUCT;

#define	_MODE                   ((volatile MODE_STRUCT*)&SPCR)->__MODE
// Data Order - SPIDataOrder_ENUM - [bit SPCR.DORD] Sets the order in which bits are transmitted.
#define	_DORD                   ((volatile BYTE_STRUCT*)&SPCR)->bit5
// SPI Interrupt Enable - Enabling_ENUM - [bit SPCR.SPIE]
#define	_SPIE                   ((volatile BYTE_STRUCT*)&SPCR)->bit7

// other SPI bit definitions
#define	_SPIF                   ((volatile BYTE_STRUCT*)&SPSR)->bit7
#define	_WCOL                   ((volatile BYTE_STRUCT*)&SPSR)->bit6
#define	_CPOL                   ((volatile BYTE_STRUCT*)&SPCR)->bit3
#define	_CPHA                   ((volatile BYTE_STRUCT*)&SPCR)->bit2

//
// TIMER_COUNTER_0 variable definitions
//
// Waveform Generation Mode - WGM0_WGM_ENUM - [bit aggregate (TCCR0.WGM00 | TCCR0.WGM01)] Controls how the counter will cycle.
typedef enum
{
	WGM0_WGM_Normal,                    	// Normal
	WGM0_WGM_PWMPhaseCorrect8bit,       	// PWM Phase Correct, 8-bit TOP=0xFF
	WGM0_WGM_CTC_OCR,                   	// Clear Timer on Compare Match TOP=OCRA
	WGM0_WGM_FastPWM8bit,               	// Fast PWM, 8-bit TOP=0xFF
} WGM0_WGM_ENUM;
#define	_WGM00                  ((volatile BYTE_STRUCT*)&TCCR0)->bit6
#define	_WGM01                  ((volatile BYTE_STRUCT*)&TCCR0)->bit3
inline WGM0_WGM_ENUM get_WGM0(){ return (WGM0_WGM_ENUM)(_WGM00|(_WGM01 << 1)); }
inline void set_WGM0(WGM0_WGM_ENUM v){ _WGM00 = v; _WGM01 = v >> 1; }
// Clock Select - CS0_CS_ENUM - [bit field "CS0" TCCR0.(CS00 | CS01 | CS02)] Selects the clock divisor or the external clock source.
typedef enum
{
	CS0_CS_None,                        	// No clock source (Timer/Counter stopped)
	CS0_CS_DIV_1,                       	// clk (No prescaling)
	CS0_CS_DIV_8,                       	// clk / 8 (From prescaler)
	CS0_CS_DIV_64,                      	// clk / 64 (From prescaler)
	CS0_CS_DIV_256,                     	// clk / 256 (From prescaler)
	CS0_CS_DIV_1024,                    	// clk / 1024 (From prescaler)
	CS0_CS_External_Falling,            	// External clock source, Clock on falling edge
	CS0_CS_External_Rising,             	// External clock source, Clock on rising edge
} CS0_CS_ENUM;

typedef struct
{
	unsigned char	__CS0             : 3;
} CS0_STRUCT;

#define	_CS0                    ((volatile CS0_STRUCT*)&TCCR0)->__CS0
// Timer Overflow Interrupt Enable - Enabling_ENUM - [bit TIMSK.TOIE0]
#define	_TOIE0                  ((volatile BYTE_STRUCT*)&TIMSK)->bit1
// Compare Output Mode - _ENUM - [bit field "COMA0" TCCR0.(COM00 | COM01)] Controls the Output Compare pin (OCnA) behavior.

typedef struct
{
	unsigned char	__Reserved        : 4;
	unsigned char	__COMA0           : 2;
} COMA0_STRUCT;

#define	_COMA0                  ((volatile COMA0_STRUCT*)&TCCR0)->__COMA0
// Output Compare Match Interrupt Enable - Enabling_ENUM - [bit TIMSK.OCIE0]
#define	_OCIE0                  ((volatile BYTE_STRUCT*)&TIMSK)->bit0

// other TIMER_COUNTER_0 bit definitions
#define	_FOC0                   ((volatile BYTE_STRUCT*)&TCCR0)->bit7
#define	_COM01                  ((volatile BYTE_STRUCT*)&TCCR0)->bit5
#define	_COM00                  ((volatile BYTE_STRUCT*)&TCCR0)->bit4
#define	_CS02                   ((volatile BYTE_STRUCT*)&TCCR0)->bit2
#define	_CS01                   ((volatile BYTE_STRUCT*)&TCCR0)->bit1
#define	_CS00                   ((volatile BYTE_STRUCT*)&TCCR0)->bit0
#define	_TOV0                   ((volatile BYTE_STRUCT*)&TIFR)->bit1
#define	_OCF0                   ((volatile BYTE_STRUCT*)&TIFR)->bit0

//
// TIMER_COUNTER_1 variable definitions
//
// Waveform Generation Mode - WGM1_WGM_ENUM - [bit aggregate (TCCR1A.WGM10 | TCCR1A.WGM11 | TCCR1B.WGM12 | TCCR1B.WGM13)] Controls how the counter will cycle.
typedef enum
{
	WGM1_WGM_Normal,                    	// Normal
	WGM1_WGM_PWMPhaseCorrect8bit,       	// PWM Phase Correct, 8-bit TOP=0xFF
	WGM1_WGM_PWMPhaseCorrect9bit,       	// PWM Phase Correct, 9-bit TOP=0x1FF
	WGM1_WGM_PWMPhaseCorrect10bit,      	// PWM Phase Correct, 10-bit TOP=0x3FF
	WGM1_WGM_CTC_OCR,                   	// Clear Timer on Compare Match TOP=OCRA
	WGM1_WGM_FastPWM8bit,               	// Fast PWM, 8-bit TOP=0xFF
	WGM1_WGM_FastPWM9bit,               	// Fast PWM, 9-bit TOP=0x1FF
	WGM1_WGM_FastPWM10bit,              	// Fast PWM, 10-bit TOP=0x3FF
	WGM1_WGM_PWMPhaseFreqCorrect_ICR,   	// PWM Phase and Freq Correct, TOP=ICR
	WGM1_WGM_PWMPhaseFreqCorrect_OCR,   	// PWM Phase and Freq Correct, TOP=OCRA
	WGM1_WGM_PWMPhaseCorrect_ICR,       	// PWM Phase Correct, TOP=ICR
	WGM1_WGM_PWMPhaseCorrect_OCR,       	// PWM Phase Correct, TOP=OCRA
	WGM1_WGM_CTC_ICR,                   	// Clear Timer on Compare Match TOP=ICR
	WGM1_WGM_Reserved,                  	// Reserved
	WGM1_WGM_FastPWM_ICR,               	// Fast PWM TOP=ICR
	WGM1_WGM_FastPWM_OCR,               	// Fast PWM TOP=OCRA
} WGM1_WGM_ENUM;
#define	_WGM10                  ((volatile BYTE_STRUCT*)&TCCR1A)->bit0
#define	_WGM11                  ((volatile BYTE_STRUCT*)&TCCR1A)->bit1
#define	_WGM12                  ((volatile BYTE_STRUCT*)&TCCR1B)->bit3
#define	_WGM13                  ((volatile BYTE_STRUCT*)&TCCR1B)->bit4
inline WGM1_WGM_ENUM get_WGM1(){ return (WGM1_WGM_ENUM)(_WGM10|(_WGM11 << 1)|(_WGM12 << 2)|(_WGM13 << 3)); }
inline void set_WGM1(WGM1_WGM_ENUM v){ _WGM10 = v; _WGM11 = v >> 1; _WGM12 = v >> 2; _WGM13 = v >> 3; }
// Clock Select - CS1_CS_ENUM - [bit field "CS1" TCCR1B.(CS10 | CS11 | CS12)] Selects the clock divisor or the external clock source.
typedef enum
{
	CS1_CS_None,                        	// No clock source (Timer/Counter stopped)
	CS1_CS_DIV_1,                       	// clk (No prescaling)
	CS1_CS_DIV_8,                       	// clk / 8 (From prescaler)
	CS1_CS_DIV_64,                      	// clk / 64 (From prescaler)
	CS1_CS_DIV_256,                     	// clk / 256 (From prescaler)
	CS1_CS_DIV_1024,                    	// clk / 1024 (From prescaler)
	CS1_CS_External_Falling,            	// External clock source, Clock on falling edge
	CS1_CS_External_Rising,             	// External clock source, Clock on rising edge
} CS1_CS_ENUM;

typedef struct
{
	unsigned char	__CS1             : 3;
} CS1_STRUCT;

#define	_CS1                    ((volatile CS1_STRUCT*)&TCCR1B)->__CS1
// Timer Overflow Interrupt Enable - Enabling_ENUM - [bit TIMSK.TOIE1]
#define	_TOIE1                  ((volatile BYTE_STRUCT*)&TIMSK)->bit7
// Input Capture Noise Cancel - Enabling_ENUM - [bit TCCR1B.ICNC1]
#define	_ICNC1                  ((volatile BYTE_STRUCT*)&TCCR1B)->bit7
// Input Capture Edge Select - Trigger_ENUM - [bit TCCR1B.ICES1]
#define	_ICES1                  ((volatile BYTE_STRUCT*)&TCCR1B)->bit6
// Input Capture Interrupt Enable - Enabling_ENUM - [bit TIMSK.TICIE1]
#define	_TICIE1                 ((volatile BYTE_STRUCT*)&TIMSK)->bit3
// Compare Output Mode A - _ENUM - [bit field "COMA1" TCCR1A.(COM1A0 | COM1A1)] Controls the Output Compare pin (OCnA) behavior.

typedef struct
{
	unsigned char	__Reserved        : 6;
	unsigned char	__COMA1           : 2;
} COMA1_STRUCT;

#define	_COMA1                  ((volatile COMA1_STRUCT*)&TCCR1A)->__COMA1
// Output Compare Match Interrupt Enable A - Enabling_ENUM - [bit TIMSK.OCIE1A]
#define	_OCIE1A                 ((volatile BYTE_STRUCT*)&TIMSK)->bit6
// Compare Output Mode B - _ENUM - [bit field "COMB1" TCCR1A.(COM1B0 | COM1B1)] Controls the Output Compare pin (OCnB) behavior.

typedef struct
{
	unsigned char	__Reserved        : 4;
	unsigned char	__COMB1           : 2;
} COMB1_STRUCT;

#define	_COMB1                  ((volatile COMB1_STRUCT*)&TCCR1A)->__COMB1
// Output Compare Match Interrupt Enable B - Enabling_ENUM - [bit TIMSK.OCIE1B]
#define	_OCIE1B                 ((volatile BYTE_STRUCT*)&TIMSK)->bit5

// other TIMER_COUNTER_1 bit definitions
#define	_TOV1                   ((volatile BYTE_STRUCT*)&TIFR)->bit7
#define	_OCF1A                  ((volatile BYTE_STRUCT*)&TIFR)->bit6
#define	_OCF1B                  ((volatile BYTE_STRUCT*)&TIFR)->bit5
#define	_ICF1                   ((volatile BYTE_STRUCT*)&TIFR)->bit3
#define	_COM1A1                 ((volatile BYTE_STRUCT*)&TCCR1A)->bit7
#define	_COM1A0                 ((volatile BYTE_STRUCT*)&TCCR1A)->bit6
#define	_COM1B1                 ((volatile BYTE_STRUCT*)&TCCR1A)->bit5
#define	_COM1B0                 ((volatile BYTE_STRUCT*)&TCCR1A)->bit4
#define	_FOC1A                  ((volatile BYTE_STRUCT*)&TCCR1A)->bit3
#define	_FOC1B                  ((volatile BYTE_STRUCT*)&TCCR1A)->bit2
#define	_CS12                   ((volatile BYTE_STRUCT*)&TCCR1B)->bit2
#define	_CS11                   ((volatile BYTE_STRUCT*)&TCCR1B)->bit1
#define	_CS10                   ((volatile BYTE_STRUCT*)&TCCR1B)->bit0

//
// TIMER_COUNTER_2 variable definitions
//
// Waveform Generation Mode - WGM2_WGM_ENUM - [bit aggregate (TCCR2.WGM20 | TCCR2.WGM21)] Controls how the counter will cycle.
typedef enum
{
	WGM2_WGM_Normal,                    	// Normal
	WGM2_WGM_PWMPhaseCorrect8bit,       	// PWM Phase Correct, 8-bit TOP=0xFF
	WGM2_WGM_CTC_OCR,                   	// Clear Timer on Compare Match TOP=OCRA
	WGM2_WGM_FastPWM8bit,               	// Fast PWM, 8-bit TOP=0xFF
} WGM2_WGM_ENUM;
#define	_WGM20                  ((volatile BYTE_STRUCT*)&TCCR2)->bit6
#define	_WGM21                  ((volatile BYTE_STRUCT*)&TCCR2)->bit3
inline WGM2_WGM_ENUM get_WGM2(){ return (WGM2_WGM_ENUM)(_WGM20|(_WGM21 << 1)); }
inline void set_WGM2(WGM2_WGM_ENUM v){ _WGM20 = v; _WGM21 = v >> 1; }
// Clock Select - CS2_CS_ENUM - [bit field "CS2" TCCR2.(CS20 | CS21 | CS22)] Selects the clock divisor.
typedef enum
{
	CS2_CS_None,                        	// No clock source (Timer/Counter stopped)
	CS2_CS_DIV_1,                       	// clk (No prescaling)
	CS2_CS_DIV_8,                       	// clk / 8 (From prescaler)
	CS2_CS_DIV_32,                      	// clk / 32 (From prescaler)
	CS2_CS_DIV_64,                      	// clk / 64 (From prescaler)
	CS2_CS_DIV_128,                     	// clk / 128 (From prescaler)
	CS2_CS_DIV_256,                     	// clk / 256 (From prescaler)
	CS2_CS_DIV_1024,                    	// clk / 1024 (From prescaler)
} CS2_CS_ENUM;

typedef struct
{
	unsigned char	__CS2             : 3;
} CS2_STRUCT;

#define	_CS2                    ((volatile CS2_STRUCT*)&TCCR2)->__CS2
// Timer Overflow Interrupt Enable - Enabling_ENUM - [bit TIMSK.TOIE2]
#define	_TOIE2                  ((volatile BYTE_STRUCT*)&TIMSK)->bit2
// Compare Output Mode - _ENUM - [bit field "COMA2" TCCR2.(COM20 | COM21)] Controls the Output Compare pin (OCnA) behavior.

typedef struct
{
	unsigned char	__Reserved        : 4;
	unsigned char	__COMA2           : 2;
} COMA2_STRUCT;

#define	_COMA2                  ((volatile COMA2_STRUCT*)&TCCR2)->__COMA2
// Output Compare Match Interrupt Enable - Enabling_ENUM - [bit TIMSK.OCIE2]
#define	_OCIE2                  ((volatile BYTE_STRUCT*)&TIMSK)->bit4

// other TIMER_COUNTER_2 bit definitions
#define	_FOC2                   ((volatile BYTE_STRUCT*)&TCCR2)->bit7
#define	_COM21                  ((volatile BYTE_STRUCT*)&TCCR2)->bit5
#define	_COM20                  ((volatile BYTE_STRUCT*)&TCCR2)->bit4
#define	_CS22                   ((volatile BYTE_STRUCT*)&TCCR2)->bit2
#define	_CS21                   ((volatile BYTE_STRUCT*)&TCCR2)->bit1
#define	_CS20                   ((volatile BYTE_STRUCT*)&TCCR2)->bit0
#define	_OCF2                   ((volatile BYTE_STRUCT*)&TIFR)->bit4
#define	_TOV2                   ((volatile BYTE_STRUCT*)&TIFR)->bit2
#define	_AS2                    ((volatile BYTE_STRUCT*)&ASSR)->bit3
#define	_TCN2UB                 ((volatile BYTE_STRUCT*)&ASSR)->bit2
#define	_OCR2UB                 ((volatile BYTE_STRUCT*)&ASSR)->bit1
#define	_TCR2UB                 ((volatile BYTE_STRUCT*)&ASSR)->bit0

//
// TIMER_COUNTER_3 variable definitions
//
// Waveform Generation Mode - WGM3_WGM_ENUM - [bit aggregate (TCCR3A.WGM30 | TCCR3A.WGM31 | TCCR3B.WGM32 | TCCR3B.WGM33)] Controls how the counter will cycle.
typedef enum
{
	WGM3_WGM_Normal,                    	// Normal
	WGM3_WGM_PWMPhaseCorrect8bit,       	// PWM Phase Correct, 8-bit TOP=0xFF
	WGM3_WGM_PWMPhaseCorrect9bit,       	// PWM Phase Correct, 9-bit TOP=0x1FF
	WGM3_WGM_PWMPhaseCorrect10bit,      	// PWM Phase Correct, 10-bit TOP=0x3FF
	WGM3_WGM_CTC_OCR,                   	// Clear Timer on Compare Match TOP=OCRA
	WGM3_WGM_FastPWM8bit,               	// Fast PWM, 8-bit TOP=0xFF
	WGM3_WGM_FastPWM9bit,               	// Fast PWM, 9-bit TOP=0x1FF
	WGM3_WGM_FastPWM10bit,              	// Fast PWM, 10-bit TOP=0x3FF
	WGM3_WGM_PWMPhaseFreqCorrect_ICR,   	// PWM Phase and Freq Correct, TOP=ICR
	WGM3_WGM_PWMPhaseFreqCorrect_OCR,   	// PWM Phase and Freq Correct, TOP=OCRA
	WGM3_WGM_PWMPhaseCorrect_ICR,       	// PWM Phase Correct, TOP=ICR
	WGM3_WGM_PWMPhaseCorrect_OCR,       	// PWM Phase Correct, TOP=OCRA
	WGM3_WGM_CTC_ICR,                   	// Clear Timer on Compare Match TOP=ICR
	WGM3_WGM_Reserved,                  	// Reserved
	WGM3_WGM_FastPWM_ICR,               	// Fast PWM TOP=ICR
	WGM3_WGM_FastPWM_OCR,               	// Fast PWM TOP=OCRA
} WGM3_WGM_ENUM;
#define	_WGM30                  ((volatile BYTE_STRUCT*)&TCCR3A)->bit0
#define	_WGM31                  ((volatile BYTE_STRUCT*)&TCCR3A)->bit1
#define	_WGM32                  ((volatile BYTE_STRUCT*)&TCCR3B)->bit3
#define	_WGM33                  ((volatile BYTE_STRUCT*)&TCCR3B)->bit4
inline WGM3_WGM_ENUM get_WGM3(){ return (WGM3_WGM_ENUM)(_WGM30|(_WGM31 << 1)|(_WGM32 << 2)|(_WGM33 << 3)); }
inline void set_WGM3(WGM3_WGM_ENUM v){ _WGM30 = v; _WGM31 = v >> 1; _WGM32 = v >> 2; _WGM33 = v >> 3; }
// Clock Select - CS3_CS_ENUM - [bit field "CS3" TCCR3B.(CS30 | CS31 | CS32)] Selects the clock divisor or the external clock source.
typedef enum
{
	CS3_CS_None,                        	// No clock source (Timer/Counter stopped)
	CS3_CS_DIV_1,                       	// clk (No prescaling)
	CS3_CS_DIV_8,                       	// clk / 8 (From prescaler)
	CS3_CS_DIV_64,                      	// clk / 64 (From prescaler)
	CS3_CS_DIV_256,                     	// clk / 256 (From prescaler)
	CS3_CS_DIV_1024,                    	// clk / 1024 (From prescaler)
	CS3_CS_External_Falling,            	// External clock source, Clock on falling edge
	CS3_CS_External_Rising,             	// External clock source, Clock on rising edge
} CS3_CS_ENUM;

typedef struct
{
	unsigned char	__CS3             : 3;
} CS3_STRUCT;

#define	_CS3                    ((volatile CS3_STRUCT*)&TCCR3B)->__CS3
// Timer Overflow Interrupt Enable - Enabling_ENUM - [bit ETIMSK.TOIE3]
#define	_TOIE3                  ((volatile BYTE_STRUCT*)&ETIMSK)->bit2
// Input Capture Noise Cancel - Enabling_ENUM - [bit TCCR3B.ICNC3]
#define	_ICNC3                  ((volatile BYTE_STRUCT*)&TCCR3B)->bit7
// Input Capture Edge Select - Trigger_ENUM - [bit TCCR3B.ICES3]
#define	_ICES3                  ((volatile BYTE_STRUCT*)&TCCR3B)->bit6
// Input Capture Interrupt Enable - Enabling_ENUM - [bit ETIMSK.TICIE3]
#define	_TICIE3                 ((volatile BYTE_STRUCT*)&ETIMSK)->bit5
// Compare Output Mode A - _ENUM - [bit field "COMA3" TCCR3A.(COM3A0 | COM3A1)] Controls the Output Compare pin (OCnA) behavior.

typedef struct
{
	unsigned char	__Reserved        : 6;
	unsigned char	__COMA3           : 2;
} COMA3_STRUCT;

#define	_COMA3                  ((volatile COMA3_STRUCT*)&TCCR3A)->__COMA3
// Output Compare Match Interrupt Enable A - Enabling_ENUM - [bit ETIMSK.OCIE3A]
#define	_OCIE3A                 ((volatile BYTE_STRUCT*)&ETIMSK)->bit4
// Compare Output Mode B - _ENUM - [bit field "COMB3" TCCR3A.(COM3B0 | COM3B1)] Controls the Output Compare pin (OCnB) behavior.

typedef struct
{
	unsigned char	__Reserved        : 4;
	unsigned char	__COMB3           : 2;
} COMB3_STRUCT;

#define	_COMB3                  ((volatile COMB3_STRUCT*)&TCCR3A)->__COMB3
// Output Compare Match Interrupt Enable B - Enabling_ENUM - [bit ETIMSK.OCIE3B]
#define	_OCIE3B                 ((volatile BYTE_STRUCT*)&ETIMSK)->bit3

// other TIMER_COUNTER_3 bit definitions
#define	_ICF3                   ((volatile BYTE_STRUCT*)&ETIFR)->bit5
#define	_OCF3A                  ((volatile BYTE_STRUCT*)&ETIFR)->bit4
#define	_OCF3B                  ((volatile BYTE_STRUCT*)&ETIFR)->bit3
#define	_TOV3                   ((volatile BYTE_STRUCT*)&ETIFR)->bit2
#define	_COM3A1                 ((volatile BYTE_STRUCT*)&TCCR3A)->bit7
#define	_COM3A0                 ((volatile BYTE_STRUCT*)&TCCR3A)->bit6
#define	_COM3B1                 ((volatile BYTE_STRUCT*)&TCCR3A)->bit5
#define	_COM3B0                 ((volatile BYTE_STRUCT*)&TCCR3A)->bit4
#define	_FOC3A                  ((volatile BYTE_STRUCT*)&TCCR3A)->bit3
#define	_FOC3B                  ((volatile BYTE_STRUCT*)&TCCR3A)->bit2
#define	_CS32                   ((volatile BYTE_STRUCT*)&TCCR3B)->bit2
#define	_CS31                   ((volatile BYTE_STRUCT*)&TCCR3B)->bit1
#define	_CS30                   ((volatile BYTE_STRUCT*)&TCCR3B)->bit0

//
// USART0 variable definitions
//
// Receiver Enable - Enabling_ENUM - [bit UCSR0B.RXEN0]
#define	_RXEN0                  ((volatile BYTE_STRUCT*)&UCSR0B)->bit4
// Transmitter Enable - Enabling_ENUM - [bit UCSR0B.TXEN0]
#define	_TXEN0                  ((volatile BYTE_STRUCT*)&UCSR0B)->bit3
// Mode Select - UMSEL0_UsartModeSelect_ENUM - [bit UCSR0C.UMSEL0] Select between Asynchronous and Synchronous mode of operation.
typedef enum
{
	UMSEL0_UsartModeSelect_Async,       	// Asynchronous Operation
	UMSEL0_UsartModeSelect_Sync,        	// Synchronous Operation
} UMSEL0_UsartModeSelect_ENUM;
// Stop Bit Select - UsartStopBitSelect_ENUM - [bit UCSR0C.USBS0] Selects the number of Stop Bits to be inserted by the Transmitter. The Receiver ignores this setting.
// Parity Mode - UsartParityMode_ENUM - [bit field "UPM0" UCSR0C.(UPM00 | UPM01)] Enable and set type of parity generation and check.

typedef struct
{
	unsigned char	__Reserved        : 4;
	unsigned char	__UPM0            : 2;
} UPM0_STRUCT;

#define	_UPM0                   ((volatile UPM0_STRUCT*)&UCSR0C)->__UPM0
// Double Transmission Speed - Enabling_ENUM - [bit UCSR0A.U2X0]
#define	_U2X0                   ((volatile BYTE_STRUCT*)&UCSR0A)->bit1
// Clock Polarity - UsartClockPolarity_ENUM - [bit UCSR0C.UCPOL0] Sets the relationship between data output change and data input sample, and the synchronous clock (XCK).
// Multi-processor Communication Mode - Enabling_ENUM - [bit UCSR0A.MPCM0]
#define	_MPCM0                  ((volatile BYTE_STRUCT*)&UCSR0A)->bit0
// RX Complete Interrupt Enable - Enabling_ENUM - [bit UCSR0B.RXCIE0]
#define	_RXCIE0                 ((volatile BYTE_STRUCT*)&UCSR0B)->bit7
// TX Complete Interrupt Enable - Enabling_ENUM - [bit UCSR0B.TXCIE0]
#define	_TXCIE0                 ((volatile BYTE_STRUCT*)&UCSR0B)->bit6
// Data Register Empty Interrupt Enable - Enabling_ENUM - [bit UCSR0B.UDRIE0] Enable an interrupt when the transmit buffer (UDR) is ready to receive new data.
#define	_UDRIE0                 ((volatile BYTE_STRUCT*)&UCSR0B)->bit5

// other USART0 bit definitions
#define	_RXC0                   ((volatile BYTE_STRUCT*)&UCSR0A)->bit7
#define	_TXC0                   ((volatile BYTE_STRUCT*)&UCSR0A)->bit6
#define	_UDRE0                  ((volatile BYTE_STRUCT*)&UCSR0A)->bit5
#define	_FE0                    ((volatile BYTE_STRUCT*)&UCSR0A)->bit4
#define	_DOR0                   ((volatile BYTE_STRUCT*)&UCSR0A)->bit3
#define	_UPE0                   ((volatile BYTE_STRUCT*)&UCSR0A)->bit2
#define	_UCSZ02                 ((volatile BYTE_STRUCT*)&UCSR0B)->bit2
#define	_RXB80                  ((volatile BYTE_STRUCT*)&UCSR0B)->bit1
#define	_TXB80                  ((volatile BYTE_STRUCT*)&UCSR0B)->bit0

//
// USART1 variable definitions
//
// Receiver Enable - Enabling_ENUM - [bit UCSR1B.RXEN1]
#define	_RXEN1                  ((volatile BYTE_STRUCT*)&UCSR1B)->bit4
// Transmitter Enable - Enabling_ENUM - [bit UCSR1B.TXEN1]
#define	_TXEN1                  ((volatile BYTE_STRUCT*)&UCSR1B)->bit3
// Mode Select - UMSEL1_UsartModeSelect_ENUM - [bit UCSR1C.UMSEL1] Select between Asynchronous and Synchronous mode of operation.
typedef enum
{
	UMSEL1_UsartModeSelect_Async,       	// Asynchronous Operation
	UMSEL1_UsartModeSelect_Sync,        	// Synchronous Operation
} UMSEL1_UsartModeSelect_ENUM;
// Stop Bit Select - UsartStopBitSelect_ENUM - [bit UCSR1C.USBS1] Selects the number of Stop Bits to be inserted by the Transmitter. The Receiver ignores this setting.
// Parity Mode - UsartParityMode_ENUM - [bit field "UPM1" UCSR1C.(UPM10 | UPM11)] Enable and set type of parity generation and check.

typedef struct
{
	unsigned char	__Reserved        : 4;
	unsigned char	__UPM1            : 2;
} UPM1_STRUCT;

#define	_UPM1                   ((volatile UPM1_STRUCT*)&UCSR1C)->__UPM1
// Double Transmission Speed - Enabling_ENUM - [bit UCSR1A.U2X1]
#define	_U2X1                   ((volatile BYTE_STRUCT*)&UCSR1A)->bit1
// Clock Polarity - UsartClockPolarity_ENUM - [bit UCSR1C.UCPOL1] Sets the relationship between data output change and data input sample, and the synchronous clock (XCK).
// Multi-processor Communication Mode - Enabling_ENUM - [bit UCSR1A.MPCM1]
#define	_MPCM1                  ((volatile BYTE_STRUCT*)&UCSR1A)->bit0
// RX Complete Interrupt Enable - Enabling_ENUM - [bit UCSR1B.RXCIE1]
#define	_RXCIE1                 ((volatile BYTE_STRUCT*)&UCSR1B)->bit7
// TX Complete Interrupt Enable - Enabling_ENUM - [bit UCSR1B.TXCIE1]
#define	_TXCIE1                 ((volatile BYTE_STRUCT*)&UCSR1B)->bit6
// Data Register Empty Interrupt Enable - Enabling_ENUM - [bit UCSR1B.UDRIE1] Enable an interrupt when the transmit buffer (UDR) is ready to receive new data.
#define	_UDRIE1                 ((volatile BYTE_STRUCT*)&UCSR1B)->bit5

// other USART1 bit definitions
#define	_RXC1                   ((volatile BYTE_STRUCT*)&UCSR1A)->bit7
#define	_TXC1                   ((volatile BYTE_STRUCT*)&UCSR1A)->bit6
#define	_UDRE1                  ((volatile BYTE_STRUCT*)&UCSR1A)->bit5
#define	_FE1                    ((volatile BYTE_STRUCT*)&UCSR1A)->bit4
#define	_DOR1                   ((volatile BYTE_STRUCT*)&UCSR1A)->bit3
#define	_UPE1                   ((volatile BYTE_STRUCT*)&UCSR1A)->bit2
#define	_UCSZ12                 ((volatile BYTE_STRUCT*)&UCSR1B)->bit2
#define	_RXB81                  ((volatile BYTE_STRUCT*)&UCSR1B)->bit1
#define	_TXB81                  ((volatile BYTE_STRUCT*)&UCSR1B)->bit0

//
// WATCHDOG variable definitions
//
// Prescaler - WDP_WdtPrescale_ENUM - [bit field "WDP" WDTCR.(WDP0 | WDP1 | WDP2)] Sets the watchdog timeout period. Values are typical at 5v.
typedef enum
{
	WDP_WdtPrescale_WDTO_16MS,          	// Typical Time-out 16 ms
	WDP_WdtPrescale_WDTO_32MS,          	// Typical Time-out 32 ms
	WDP_WdtPrescale_WDTO_64MS,          	// Typical Time-out 64 ms
	WDP_WdtPrescale_WDTO_125MS,         	// Typical Time-out 125 ms
	WDP_WdtPrescale_WDTO_250MS,         	// Typical Time-out 250 ms
	WDP_WdtPrescale_WDTO_500MS,         	// Typical Time-out 500 ms
	WDP_WdtPrescale_WDTO_1S,            	// Typical Time-out 1 sec
	WDP_WdtPrescale_WDTO_2S,            	// Typical Time-out 2 sec
} WDP_WdtPrescale_ENUM;

typedef struct
{
	unsigned char	__WDP             : 3;
} WDP_STRUCT;

#define	_WDP                    ((volatile WDP_STRUCT*)&WDTCR)->__WDP
// Enable - Enabling_ENUM - [bit WDTCR.WDE] Enables the watchdog timer.
#define	_WDE                    ((volatile BYTE_STRUCT*)&WDTCR)->bit3

// other WATCHDOG bit definitions
#define	_WDCE                   ((volatile BYTE_STRUCT*)&WDTCR)->bit4
#define	_WDP2                   ((volatile BYTE_STRUCT*)&WDTCR)->bit2
#define	_WDP1                   ((volatile BYTE_STRUCT*)&WDTCR)->bit1
#define	_WDP0                   ((volatile BYTE_STRUCT*)&WDTCR)->bit0

#define _AID_ATmega162_DEFINED_
#endif /* _AID_ATmega162_DEFINED_ */
