#ifndef _AID_ATmega163_DEFINED_

typedef enum
{
	Disabling_Enabled,                  	// Enabled
	Disabling_Disabled,                 	// Disabled
} Disabling_ENUM;

typedef enum
{
	Enabling_Disabled,                  	// Disabled
	Enabling_Enabled,                   	// Enabled
} Enabling_ENUM;

typedef enum
{
	ACIntModeSelect_OutputToggle,       	// Comparator Interrupt on Output Toggle
	ACIntModeSelect_Reserved,           	// Reserved
	ACIntModeSelect_FallingOutputEdge,  	// Comparator Interrupt on Falling Output Edge
	ACIntModeSelect_RisingOutputEdge,   	// Comparator Interrupt on Rising Output Edge
} ACIntModeSelect_ENUM;

typedef enum
{
	ACBandgapSelect_NoBandgap,          	// Use AIN0 as positive input
	ACBandgapSelect_Bandgap,            	// Use fixed bandgap reference voltage as positive input
} ACBandgapSelect_ENUM;

typedef enum
{
	SenseA_LowLevel,                    	// Low Level Generates Interrupt
	SenseA_AnyChange,                   	// Any Change Generates Interrupt
	SenseA_FallingEdge,                 	// Falling Edge Generates Interrupt
	SenseA_RisingEdge,                  	// Rising Edge Generates Interrupt
} SenseA_ENUM;

typedef enum
{
	SPIMaster_Slave,                    	// Slave Mode
	SPIMaster_Master,                   	// Master Mode
} SPIMaster_ENUM;

typedef enum
{
	SPR_DIV_4,                          	// clk / 4
	SPR_DIV_16,                         	// clk / 16
	SPR_DIV_64,                         	// clk / 64
	SPR_DIV_128,                        	// clk / 128
	SPR_DIV_2,                          	// clk / 2
	SPR_DIV_8,                          	// clk / 8
	SPR_DIV_32,                         	// clk / 32
	SPR_DIV_64b,                        	// clk / 64
} SPR_ENUM;

typedef enum
{
	SPIMode_Mode0,                      	// 0 - Leading (Rising) Edge Sample, Trailing (Falling) Edge Setup
	SPIMode_Mode1,                      	// 1 - Leading (Rising) Edge Setup, Trailing (Falling) Edge Sample
	SPIMode_Mode2,                      	// 2 - Leading (Falling) Edge Sample, Trailing (Rising) Edge Setup
	SPIMode_Mode3,                      	// 3 - Leading (Falling) Edge Setup, Trailing (Rising) Edge Sample
} SPIMode_ENUM;

typedef enum
{
	SPIDataOrder_MSBFirst,              	// Most Significant Bit First
	SPIDataOrder_LSBFirst,              	// Least Significant Bit First
} SPIDataOrder_ENUM;

typedef enum
{
	NumBits_Bits8,                      	// 8 Bits
	NumBits_Bits9,                      	// 9 Bits
} NumBits_ENUM;

//
// AD_CONVERTER variable definitions
//
#define	_REFS1                  ((volatile BYTE_STRUCT*)&ADMUX)->bit7
#define	_REFS0                  ((volatile BYTE_STRUCT*)&ADMUX)->bit6
#define	_ADLAR                  ((volatile BYTE_STRUCT*)&ADMUX)->bit5
#define	_MUX4                   ((volatile BYTE_STRUCT*)&ADMUX)->bit4
#define	_MUX3                   ((volatile BYTE_STRUCT*)&ADMUX)->bit3
#define	_MUX2                   ((volatile BYTE_STRUCT*)&ADMUX)->bit2
#define	_MUX1                   ((volatile BYTE_STRUCT*)&ADMUX)->bit1
#define	_MUX0                   ((volatile BYTE_STRUCT*)&ADMUX)->bit0
#define	_ADEN                   ((volatile BYTE_STRUCT*)&ADCSR)->bit7
#define	_ADSC                   ((volatile BYTE_STRUCT*)&ADCSR)->bit6
#define	_ADFR                   ((volatile BYTE_STRUCT*)&ADCSR)->bit5
#define	_ADIF                   ((volatile BYTE_STRUCT*)&ADCSR)->bit4
#define	_ADIE                   ((volatile BYTE_STRUCT*)&ADCSR)->bit3
#define	_ADPS2                  ((volatile BYTE_STRUCT*)&ADCSR)->bit2
#define	_ADPS1                  ((volatile BYTE_STRUCT*)&ADCSR)->bit1
#define	_ADPS0                  ((volatile BYTE_STRUCT*)&ADCSR)->bit0

//
// ANALOG_COMPARATOR variable definitions
//
// Analog Comparator Disable - Disabling_ENUM - [bit ACSR.ACD] Disables the Analog Comparator.
#define	_ACD                    ((volatile BYTE_STRUCT*)&ACSR)->bit7
// Interrupt Enable - Enabling_ENUM - [bit ACSR.ACIE] When enabled and the I-bit in the Status Register is set, the Analog Comparator interrupt is activated.
#define	_ACIE                   ((volatile BYTE_STRUCT*)&ACSR)->bit3
// Interrupt Mode Select - ACIntModeSelect_ENUM - [bit field "ACIS" ACSR.(ACIS0 | ACIS1)] Determine which comparator events trigger the Analog Comparator interrupt.

typedef struct
{
	unsigned char	__ACIS            : 2;
} ACIS_STRUCT;

#define	_ACIS                   ((volatile ACIS_STRUCT*)&ACSR)->__ACIS
// Input Capture Enable - Enabling_ENUM - [bit ACSR.ACIC] Enables the input capture function in Timer/Counter1 to be triggered by the Analog Comparator.
#define	_ACIC                   ((volatile BYTE_STRUCT*)&ACSR)->bit2
// Bandgap Select - ACBandgapSelect_ENUM - [bit ACSR.ACBG] Selects a bandgap reference voltage as the positive input.
#define	_ACBG                   ((volatile BYTE_STRUCT*)&ACSR)->bit6
// Multiplexer Enable - Enabling_ENUM - [bit SFIOR.ACME] When enabled and the ADC is switched off, the ADC multiplexer selects the negative input to the Analog Comparator. When disabled, AIN1 is applied to the negative input of the Analog Comparator.
#define	_ACME                   ((volatile BYTE_STRUCT*)&SFIOR)->bit3

// other ANALOG_COMPARATOR bit definitions
#define	_ACO                    ((volatile BYTE_STRUCT*)&ACSR)->bit5
#define	_ACI                    ((volatile BYTE_STRUCT*)&ACSR)->bit4
#define	_ACIS1                  ((volatile BYTE_STRUCT*)&ACSR)->bit1
#define	_ACIS0                  ((volatile BYTE_STRUCT*)&ACSR)->bit0

//
// BOOT_LOAD variable definitions
//
#define	_ASB                    ((volatile BYTE_STRUCT*)&SPMCR)->bit6
#define	_ASRE                   ((volatile BYTE_STRUCT*)&SPMCR)->bit4
#define	_BLBSET                 ((volatile BYTE_STRUCT*)&SPMCR)->bit3
#define	_PGWRT                  ((volatile BYTE_STRUCT*)&SPMCR)->bit2
#define	_PGERS                  ((volatile BYTE_STRUCT*)&SPMCR)->bit1
#define	_SPMEN                  ((volatile BYTE_STRUCT*)&SPMCR)->bit0

//
// CPU variable definitions
//
#define	_SE                     ((volatile BYTE_STRUCT*)&MCUCR)->bit6
#define	_SM1                    ((volatile BYTE_STRUCT*)&MCUCR)->bit5
#define	_SM0                    ((volatile BYTE_STRUCT*)&MCUCR)->bit4
#define	_ISC11                  ((volatile BYTE_STRUCT*)&MCUCR)->bit3
#define	_ISC10                  ((volatile BYTE_STRUCT*)&MCUCR)->bit2
#define	_ISC01                  ((volatile BYTE_STRUCT*)&MCUCR)->bit1
#define	_ISC00                  ((volatile BYTE_STRUCT*)&MCUCR)->bit0
#define	_WDRF                   ((volatile BYTE_STRUCT*)&MCUSR)->bit3
#define	_BORF                   ((volatile BYTE_STRUCT*)&MCUSR)->bit2
#define	_EXTRF                  ((volatile BYTE_STRUCT*)&MCUSR)->bit1
#define	_PORF                   ((volatile BYTE_STRUCT*)&MCUSR)->bit0
#define	_PUD                    ((volatile BYTE_STRUCT*)&SFIOR)->bit2
#define	_PSR2                   ((volatile BYTE_STRUCT*)&SFIOR)->bit1
#define	_PSR10                  ((volatile BYTE_STRUCT*)&SFIOR)->bit0

//
// EEPROM variable definitions
//
#define	_EERIE                  ((volatile BYTE_STRUCT*)&EECR)->bit3
#define	_EEMWE                  ((volatile BYTE_STRUCT*)&EECR)->bit2
#define	_EEWE                   ((volatile BYTE_STRUCT*)&EECR)->bit1
#define	_EERE                   ((volatile BYTE_STRUCT*)&EECR)->bit0

//
// EXTERNAL_INTERRUPT variable definitions
//
// INT0 Interrupt Enable - Enabling_ENUM - [bit GIMSK.INT0] Enables the interrupt on the INT pin
#define	_INT0                   ((volatile BYTE_STRUCT*)&GIMSK)->bit6
// INT0 Interrupt Sense Control - SenseA_ENUM - [bit field "ISC0" MCUCR.(ISC00 | ISC01)] Specifies the type of signal that will generate an interrupt

typedef struct
{
	unsigned char	__ISC0            : 2;
} ISC0_STRUCT;

#define	_ISC0                   ((volatile ISC0_STRUCT*)&MCUCR)->__ISC0
// INT1 Interrupt Enable - Enabling_ENUM - [bit GIMSK.INT1] Enables the interrupt on the INT pin
#define	_INT1                   ((volatile BYTE_STRUCT*)&GIMSK)->bit7
// INT1 Interrupt Sense Control - SenseA_ENUM - [bit field "ISC1" MCUCR.(ISC10 | ISC11)] Specifies the type of signal that will generate an interrupt

typedef struct
{
	unsigned char	__Reserved        : 2;
	unsigned char	__ISC1            : 2;
} ISC1_STRUCT;

#define	_ISC1                   ((volatile ISC1_STRUCT*)&MCUCR)->__ISC1

// other EXTERNAL_INTERRUPT bit definitions
#define	_INTF1                  ((volatile BYTE_STRUCT*)&GIFR)->bit7
#define	_INTF0                  ((volatile BYTE_STRUCT*)&GIFR)->bit6

//
// SPI variable definitions
//
// SPI Enable - Enabling_ENUM - [bit SPCR.SPE]
#define	_SPE                    ((volatile BYTE_STRUCT*)&SPCR)->bit6
// Master/Slave Mode - SPIMaster_ENUM - [bit SPCR.MSTR]
#define	_MSTR                   ((volatile BYTE_STRUCT*)&SPCR)->bit4
// Clock Rate Select - SPR_ENUM - [bit aggregate (SPCR.SPR0 | SPCR.SPR1 | SPSR.SPI2X)] Controls the SCK rate of the device configured as a Master.
#define	_SPR0                   ((volatile BYTE_STRUCT*)&SPCR)->bit0
#define	_SPR1                   ((volatile BYTE_STRUCT*)&SPCR)->bit1
#define	_SPI2X                  ((volatile BYTE_STRUCT*)&SPSR)->bit0
inline SPR_ENUM get_SPR(){ return (SPR_ENUM)(_SPR0|(_SPR1 << 1)|(_SPI2X << 2)); }
inline void set_SPR(SPR_ENUM v){ _SPR0 = v; _SPR1 = v >> 1; _SPI2X = v >> 2; }
// SPI Mode - SPIMode_ENUM - [bit field "MODE" SPCR.(CPHA | CPOL)] Sets the relationship between data output change and data input sample, and the synchronous clock (SCK).

typedef struct
{
	unsigned char	__Reserved        : 2;
	unsigned char	__MODE            : 2;
} MODE_STRUCT;

#define	_MODE                   ((volatile MODE_STRUCT*)&SPCR)->__MODE
// Data Order - SPIDataOrder_ENUM - [bit SPCR.DORD] Sets the order in which bits are transmitted.
#define	_DORD                   ((volatile BYTE_STRUCT*)&SPCR)->bit5
// SPI Interrupt Enable - Enabling_ENUM - [bit SPCR.SPIE]
#define	_SPIE                   ((volatile BYTE_STRUCT*)&SPCR)->bit7

// other SPI bit definitions
#define	_SPIF                   ((volatile BYTE_STRUCT*)&SPSR)->bit7
#define	_WCOL                   ((volatile BYTE_STRUCT*)&SPSR)->bit6
#define	_CPOL                   ((volatile BYTE_STRUCT*)&SPCR)->bit3
#define	_CPHA                   ((volatile BYTE_STRUCT*)&SPCR)->bit2

//
// TIMER_COUNTER_0 variable definitions
//
// Clock Select - CS0_CS_ENUM - [bit field "CS0" TCCR0.(CS00 | CS01 | CS02)] Selects the clock divisor or the external clock source.
typedef enum
{
	CS0_CS_None,                        	// No clock source (Timer/Counter stopped)
	CS0_CS_DIV_1,                       	// clk (No prescaling)
	CS0_CS_DIV_8,                       	// clk / 8 (From prescaler)
	CS0_CS_DIV_64,                      	// clk / 64 (From prescaler)
	CS0_CS_DIV_256,                     	// clk / 256 (From prescaler)
	CS0_CS_DIV_1024,                    	// clk / 1024 (From prescaler)
	CS0_CS_External_Falling,            	// External clock source, Clock on falling edge
	CS0_CS_External_Rising,             	// External clock source, Clock on rising edge
} CS0_CS_ENUM;

typedef struct
{
	unsigned char	__CS0             : 3;
} CS0_STRUCT;

#define	_CS0                    ((volatile CS0_STRUCT*)&TCCR0)->__CS0
// Timer Overflow Interrupt Enable - Enabling_ENUM - [bit TIMSK.TOIE0]
#define	_TOIE0                  ((volatile BYTE_STRUCT*)&TIMSK)->bit0

// other TIMER_COUNTER_0 bit definitions
#define	_TOV0                   ((volatile BYTE_STRUCT*)&TIFR)->bit0
#define	_CS02                   ((volatile BYTE_STRUCT*)&TCCR0)->bit2
#define	_CS01                   ((volatile BYTE_STRUCT*)&TCCR0)->bit1
#define	_CS00                   ((volatile BYTE_STRUCT*)&TCCR0)->bit0

//
// TIMER_COUNTER_1 variable definitions
//
#define	_TICIE1                 ((volatile BYTE_STRUCT*)&TIMSK)->bit5
#define	_OCIE1A                 ((volatile BYTE_STRUCT*)&TIMSK)->bit4
#define	_OCIE1B                 ((volatile BYTE_STRUCT*)&TIMSK)->bit3
#define	_TOIE1                  ((volatile BYTE_STRUCT*)&TIMSK)->bit2
#define	_ICF1                   ((volatile BYTE_STRUCT*)&TIFR)->bit5
#define	_OCF1A                  ((volatile BYTE_STRUCT*)&TIFR)->bit4
#define	_OCF1B                  ((volatile BYTE_STRUCT*)&TIFR)->bit3
#define	_TOV1                   ((volatile BYTE_STRUCT*)&TIFR)->bit2
#define	_COM1A1                 ((volatile BYTE_STRUCT*)&TCCR1A)->bit7
#define	_COM1A0                 ((volatile BYTE_STRUCT*)&TCCR1A)->bit6
#define	_COM1B1                 ((volatile BYTE_STRUCT*)&TCCR1A)->bit5
#define	_COM1B0                 ((volatile BYTE_STRUCT*)&TCCR1A)->bit4
#define	_FOC1A                  ((volatile BYTE_STRUCT*)&TCCR1A)->bit3
#define	_FOC1B                  ((volatile BYTE_STRUCT*)&TCCR1A)->bit2
#define	_PWM11                  ((volatile BYTE_STRUCT*)&TCCR1A)->bit1
#define	_PWM10                  ((volatile BYTE_STRUCT*)&TCCR1A)->bit0
#define	_ICNC1                  ((volatile BYTE_STRUCT*)&TCCR1B)->bit7
#define	_ICES1                  ((volatile BYTE_STRUCT*)&TCCR1B)->bit6
#define	_CTC1                   ((volatile BYTE_STRUCT*)&TCCR1B)->bit3
#define	_CS12                   ((volatile BYTE_STRUCT*)&TCCR1B)->bit2
#define	_CS11                   ((volatile BYTE_STRUCT*)&TCCR1B)->bit1
#define	_CS10                   ((volatile BYTE_STRUCT*)&TCCR1B)->bit0

//
// TIMER_COUNTER_2 variable definitions
//
#define	_OCIE2                  ((volatile BYTE_STRUCT*)&TIMSK)->bit7
#define	_TOIE2                  ((volatile BYTE_STRUCT*)&TIMSK)->bit6
#define	_OCF2                   ((volatile BYTE_STRUCT*)&TIFR)->bit7
#define	_TOV2                   ((volatile BYTE_STRUCT*)&TIFR)->bit6
#define	_FOC2                   ((volatile BYTE_STRUCT*)&TCCR2)->bit7
#define	_WGM20                  ((volatile BYTE_STRUCT*)&TCCR2)->bit6
#define	_COM21                  ((volatile BYTE_STRUCT*)&TCCR2)->bit5
#define	_COM20                  ((volatile BYTE_STRUCT*)&TCCR2)->bit4
#define	_WGM21                  ((volatile BYTE_STRUCT*)&TCCR2)->bit3
#define	_CS22                   ((volatile BYTE_STRUCT*)&TCCR2)->bit2
#define	_CS21                   ((volatile BYTE_STRUCT*)&TCCR2)->bit1
#define	_CS20                   ((volatile BYTE_STRUCT*)&TCCR2)->bit0
#define	_AS2                    ((volatile BYTE_STRUCT*)&ASSR)->bit3
#define	_TCN2UB                 ((volatile BYTE_STRUCT*)&ASSR)->bit2
#define	_OCR2UB                 ((volatile BYTE_STRUCT*)&ASSR)->bit1
#define	_TCR2UB                 ((volatile BYTE_STRUCT*)&ASSR)->bit0

//
// TWI variable definitions
//
// TWI Enable - Enabling_ENUM - [bit TWCR.TWEN] Enables TWI operation and activates the TWI interface.
#define	_TWEN                   ((volatile BYTE_STRUCT*)&TWCR)->bit2
// Address Register - _ENUM - [bit field "TWAR" TWAR.(TWA0 | TWA1 | TWA2 | TWA3 | TWA4 | TWA5 | TWA6)] Address to which the TWI will respond.

typedef struct
{
	unsigned char	__Reserved        : 1;
	unsigned char	__TWAR            : 7;
} TWAR_STRUCT;

#define	_TWAR                   ((volatile TWAR_STRUCT*)&TWAR)->__TWAR
// General Call Recognition Enable - Enabling_ENUM - [bit TWAR.TWGCE] Enables the recognition of a General Call.
#define	_TWGCE                  ((volatile BYTE_STRUCT*)&TWAR)->bit0
// Enable Acknowledge - Enabling_ENUM - [bit TWCR.TWEA] Controls the generation of the acknowledge pulse.
#define	_TWEA                   ((volatile BYTE_STRUCT*)&TWCR)->bit6
// Interrupt Enable - Enabling_ENUM - [bit TWCR.TWIE] Enables the TWI interrupt.
#define	_TWIE                   ((volatile BYTE_STRUCT*)&TWCR)->bit0

// other TWI bit definitions
#define	_TWINT                  ((volatile BYTE_STRUCT*)&TWCR)->bit7
#define	_TWSTA                  ((volatile BYTE_STRUCT*)&TWCR)->bit5
#define	_TWSTO                  ((volatile BYTE_STRUCT*)&TWCR)->bit4
#define	_TWWC                   ((volatile BYTE_STRUCT*)&TWCR)->bit3
#define	_TWS7                   ((volatile BYTE_STRUCT*)&TWSR)->bit7
#define	_TWS6                   ((volatile BYTE_STRUCT*)&TWSR)->bit6
#define	_TWS5                   ((volatile BYTE_STRUCT*)&TWSR)->bit5
#define	_TWS4                   ((volatile BYTE_STRUCT*)&TWSR)->bit4
#define	_TWS3                   ((volatile BYTE_STRUCT*)&TWSR)->bit3
#define	_TWA0                   ((volatile BYTE_STRUCT*)&TWAR)->bit1
#define	_TWA1                   ((volatile BYTE_STRUCT*)&TWAR)->bit2
#define	_TWA2                   ((volatile BYTE_STRUCT*)&TWAR)->bit3
#define	_TWA3                   ((volatile BYTE_STRUCT*)&TWAR)->bit4
#define	_TWA4                   ((volatile BYTE_STRUCT*)&TWAR)->bit5
#define	_TWA5                   ((volatile BYTE_STRUCT*)&TWAR)->bit6
#define	_TWA6                   ((volatile BYTE_STRUCT*)&TWAR)->bit7

//
// UART variable definitions
//
// Receiver Enable - Enabling_ENUM - [bit UCSRB.RXEN]
#define	_RXEN                   ((volatile BYTE_STRUCT*)&UCSRB)->bit4
// Transmitter Enable - Enabling_ENUM - [bit UCSRB.TXEN]
#define	_TXEN                   ((volatile BYTE_STRUCT*)&UCSRB)->bit3
// 9 Bit Characters - NumBits_ENUM - [bit UCSRB.CHR9] Set the number of data bits to 9.
#define	_CHR9                   ((volatile BYTE_STRUCT*)&UCSRB)->bit2
// Double Transmission Speed - Enabling_ENUM - [bit UCSRA.U2X]
#define	_U2X                    ((volatile BYTE_STRUCT*)&UCSRA)->bit1
// Multi-processor Communication Mode - Enabling_ENUM - [bit UCSRA.MPCM]
#define	_MPCM                   ((volatile BYTE_STRUCT*)&UCSRA)->bit0
// RX Complete Interrupt Enable - Enabling_ENUM - [bit UCSRB.RXCIE]
#define	_RXCIE                  ((volatile BYTE_STRUCT*)&UCSRB)->bit7
// TX Complete Interrupt Enable - Enabling_ENUM - [bit UCSRB.TXCIE]
#define	_TXCIE                  ((volatile BYTE_STRUCT*)&UCSRB)->bit6
// Data Register Empty Interrupt Enable - Enabling_ENUM - [bit UCSRB.UDRIE] Enable an interrupt when the transmit buffer (UDR) is ready to receive new data.
#define	_UDRIE                  ((volatile BYTE_STRUCT*)&UCSRB)->bit5

// other UART bit definitions
#define	_RXC                    ((volatile BYTE_STRUCT*)&UCSRA)->bit7
#define	_TXC                    ((volatile BYTE_STRUCT*)&UCSRA)->bit6
#define	_UDRE                   ((volatile BYTE_STRUCT*)&UCSRA)->bit5
#define	_FE                     ((volatile BYTE_STRUCT*)&UCSRA)->bit4
#define	_OR                     ((volatile BYTE_STRUCT*)&UCSRA)->bit3
#define	_RXB8                   ((volatile BYTE_STRUCT*)&UCSRB)->bit1
#define	_TXB8                   ((volatile BYTE_STRUCT*)&UCSRB)->bit0
#define	_UBRRHI0                ((volatile BYTE_STRUCT*)&UBRRHI)->bit0
#define	_UBRRHI1                ((volatile BYTE_STRUCT*)&UBRRHI)->bit1
#define	_UBRRHI2                ((volatile BYTE_STRUCT*)&UBRRHI)->bit2
#define	_UBRRHI3                ((volatile BYTE_STRUCT*)&UBRRHI)->bit3

//
// WATCHDOG variable definitions
//
// Prescaler - WDP_WdtPrescale_ENUM - [bit field "WDP" WDTCR.(WDP0 | WDP1 | WDP2)] Sets the watchdog timeout period. Values are typical at 5v.
typedef enum
{
	WDP_WdtPrescale_WDTO_16MS,          	// Typical Time-out 16 ms
	WDP_WdtPrescale_WDTO_32MS,          	// Typical Time-out 32 ms
	WDP_WdtPrescale_WDTO_64MS,          	// Typical Time-out 64 ms
	WDP_WdtPrescale_WDTO_125MS,         	// Typical Time-out 125 ms
	WDP_WdtPrescale_WDTO_250MS,         	// Typical Time-out 250 ms
	WDP_WdtPrescale_WDTO_500MS,         	// Typical Time-out 500 ms
	WDP_WdtPrescale_WDTO_1S,            	// Typical Time-out 1 sec
	WDP_WdtPrescale_WDTO_2S,            	// Typical Time-out 2 sec
} WDP_WdtPrescale_ENUM;

typedef struct
{
	unsigned char	__WDP             : 3;
} WDP_STRUCT;

#define	_WDP                    ((volatile WDP_STRUCT*)&WDTCR)->__WDP
// Enable - Enabling_ENUM - [bit WDTCR.WDE] Enables the watchdog timer.
#define	_WDE                    ((volatile BYTE_STRUCT*)&WDTCR)->bit3

// other WATCHDOG bit definitions
#define	_WDTOE                  ((volatile BYTE_STRUCT*)&WDTCR)->bit4
#define	_WDP2                   ((volatile BYTE_STRUCT*)&WDTCR)->bit2
#define	_WDP1                   ((volatile BYTE_STRUCT*)&WDTCR)->bit1
#define	_WDP0                   ((volatile BYTE_STRUCT*)&WDTCR)->bit0

#define _AID_ATmega163_DEFINED_
#endif /* _AID_ATmega163_DEFINED_ */
