#ifndef _AID_ATtiny13_DEFINED_

typedef enum
{
	Disabling_Enabled,                  	// Enabled
	Disabling_Disabled,                 	// Disabled
} Disabling_ENUM;

typedef enum
{
	Enabling_Disabled,                  	// Disabled
	Enabling_Enabled,                   	// Enabled
} Enabling_ENUM;

typedef enum
{
	ACIntModeSelect_OutputToggle,       	// Comparator Interrupt on Output Toggle
	ACIntModeSelect_Reserved,           	// Reserved
	ACIntModeSelect_FallingOutputEdge,  	// Comparator Interrupt on Falling Output Edge
	ACIntModeSelect_RisingOutputEdge,   	// Comparator Interrupt on Rising Output Edge
} ACIntModeSelect_ENUM;

typedef enum
{
	ACBandgapSelect_NoBandgap,          	// Use AIN0 as positive input
	ACBandgapSelect_Bandgap,            	// Use fixed bandgap reference voltage as positive input
} ACBandgapSelect_ENUM;

typedef enum
{
	SenseA_LowLevel,                    	// Low Level Generates Interrupt
	SenseA_AnyChange,                   	// Any Change Generates Interrupt
	SenseA_FallingEdge,                 	// Falling Edge Generates Interrupt
	SenseA_RisingEdge,                  	// Rising Edge Generates Interrupt
} SenseA_ENUM;

typedef enum
{
	WdtPrescale_WDTO_16MS,              	// Typical Time-out 16 ms
	WdtPrescale_WDTO_32MS,              	// Typical Time-out 32 ms
	WdtPrescale_WDTO_64MS,              	// Typical Time-out 64 ms
	WdtPrescale_WDTO_125MS,             	// Typical Time-out 125 ms
	WdtPrescale_WDTO_250MS,             	// Typical Time-out 250 ms
	WdtPrescale_WDTO_500MS,             	// Typical Time-out 500 ms
	WdtPrescale_WDTO_1S,                	// Typical Time-out 1 sec
	WdtPrescale_WDTO_2S,                	// Typical Time-out 2 sec
	WdtPrescale_WDTO_4S,                	// Typical Time-out 4 sec
	WdtPrescale_WDTO_8S,                	// Typical Time-out 8 sec
	WdtPrescale_WDTO_Invalid1,          	// Invalid
	WdtPrescale_WDTO_Invalid2,          	// Invalid
	WdtPrescale_WDTO_Invalid3,          	// Invalid
	WdtPrescale_WDTO_Invalid4,          	// Invalid
	WdtPrescale_WDTO_Invalid5,          	// Invalid
	WdtPrescale_WDTO_Invalid6,          	// Invalid
} WdtPrescale_ENUM;

typedef enum
{
	WdtMode_Disabled,                   	// Disabled
	WdtMode_Interrupt,                  	// Interrupt on timeout
	WdtMode_SystemReset,                	// System reset on timeout
	WdtMode_InterruptAndSystemReset,    	// Interrupt on first timeout, system reset on next
} WdtMode_ENUM;

//
// AD_CONVERTER variable definitions
//
#define	_REFS0                  ((volatile BYTE_STRUCT*)&ADMUX)->bit6
#define	_ADLAR                  ((volatile BYTE_STRUCT*)&ADMUX)->bit5
#define	_MUX1                   ((volatile BYTE_STRUCT*)&ADMUX)->bit1
#define	_MUX0                   ((volatile BYTE_STRUCT*)&ADMUX)->bit0
#define	_ADEN                   ((volatile BYTE_STRUCT*)&ADCSRA)->bit7
#define	_ADSC                   ((volatile BYTE_STRUCT*)&ADCSRA)->bit6
#define	_ADATE                  ((volatile BYTE_STRUCT*)&ADCSRA)->bit5
#define	_ADIF                   ((volatile BYTE_STRUCT*)&ADCSRA)->bit4
#define	_ADIE                   ((volatile BYTE_STRUCT*)&ADCSRA)->bit3
#define	_ADPS2                  ((volatile BYTE_STRUCT*)&ADCSRA)->bit2
#define	_ADPS1                  ((volatile BYTE_STRUCT*)&ADCSRA)->bit1
#define	_ADPS0                  ((volatile BYTE_STRUCT*)&ADCSRA)->bit0
#define	_ADTS2                  ((volatile BYTE_STRUCT*)&ADCSRB)->bit2
#define	_ADTS1                  ((volatile BYTE_STRUCT*)&ADCSRB)->bit1
#define	_ADTS0                  ((volatile BYTE_STRUCT*)&ADCSRB)->bit0
#define	_ADC0D                  ((volatile BYTE_STRUCT*)&DIDR0)->bit5
#define	_ADC2D                  ((volatile BYTE_STRUCT*)&DIDR0)->bit4
#define	_ADC3D                  ((volatile BYTE_STRUCT*)&DIDR0)->bit3
#define	_ADC1D                  ((volatile BYTE_STRUCT*)&DIDR0)->bit2

//
// ANALOG_COMPARATOR variable definitions
//
// Analog Comparator Disable - Disabling_ENUM - [bit ACSR.ACD] Disables the Analog Comparator.
#define	_ACD                    ((volatile BYTE_STRUCT*)&ACSR)->bit7
// Interrupt Enable - Enabling_ENUM - [bit ACSR.ACIE] When enabled and the I-bit in the Status Register is set, the Analog Comparator interrupt is activated.
#define	_ACIE                   ((volatile BYTE_STRUCT*)&ACSR)->bit3
// Interrupt Mode Select - ACIntModeSelect_ENUM - [bit field "ACIS" ACSR.(ACIS0 | ACIS1)] Determine which comparator events trigger the Analog Comparator interrupt.

typedef struct
{
	unsigned char	__ACIS            : 2;
} ACIS_STRUCT;

#define	_ACIS                   ((volatile ACIS_STRUCT*)&ACSR)->__ACIS
// Bandgap Select - ACBandgapSelect_ENUM - [bit ACSR.ACBG] Selects a bandgap reference voltage as the positive input.
#define	_ACBG                   ((volatile BYTE_STRUCT*)&ACSR)->bit6
// Multiplexer Enable - Enabling_ENUM - [bit ADCSRB.ACME] When enabled and the ADC is switched off, the ADC multiplexer selects the negative input to the Analog Comparator. When disabled, AIN1 is applied to the negative input of the Analog Comparator.
#define	_ACME                   ((volatile BYTE_STRUCT*)&ADCSRB)->bit6
// Digital Input 0 Disable - Disabling_ENUM - [bit DIDR0.AIN0D] When disabled, the digital input buffer on the AIN0 pin is disabled.
#define	_AIN0D                  ((volatile BYTE_STRUCT*)&DIDR0)->bit0
// Digital Input 1 Disable - Disabling_ENUM - [bit DIDR0.AIN1D] When disabled, the digital input buffer on the AIN1 pin is disabled.
#define	_AIN1D                  ((volatile BYTE_STRUCT*)&DIDR0)->bit1

// other ANALOG_COMPARATOR bit definitions
#define	_ACO                    ((volatile BYTE_STRUCT*)&ACSR)->bit5
#define	_ACI                    ((volatile BYTE_STRUCT*)&ACSR)->bit4
#define	_ACIS1                  ((volatile BYTE_STRUCT*)&ACSR)->bit1
#define	_ACIS0                  ((volatile BYTE_STRUCT*)&ACSR)->bit0

//
// CPU variable definitions
//
#define	_PUD                    ((volatile BYTE_STRUCT*)&MCUCR)->bit6
#define	_SE                     ((volatile BYTE_STRUCT*)&MCUCR)->bit5
#define	_SM1                    ((volatile BYTE_STRUCT*)&MCUCR)->bit4
#define	_SM0                    ((volatile BYTE_STRUCT*)&MCUCR)->bit3
#define	_ISC01                  ((volatile BYTE_STRUCT*)&MCUCR)->bit1
#define	_ISC00                  ((volatile BYTE_STRUCT*)&MCUCR)->bit0
#define	_WDRF                   ((volatile BYTE_STRUCT*)&MCUSR)->bit3
#define	_BORF                   ((volatile BYTE_STRUCT*)&MCUSR)->bit2
#define	_EXTRF                  ((volatile BYTE_STRUCT*)&MCUSR)->bit1
#define	_PORF                   ((volatile BYTE_STRUCT*)&MCUSR)->bit0
#define	_CLKPCE                 ((volatile BYTE_STRUCT*)&CLKPR)->bit7
#define	_CLKPS3                 ((volatile BYTE_STRUCT*)&CLKPR)->bit3
#define	_CLKPS2                 ((volatile BYTE_STRUCT*)&CLKPR)->bit2
#define	_CLKPS1                 ((volatile BYTE_STRUCT*)&CLKPR)->bit1
#define	_CLKPS0                 ((volatile BYTE_STRUCT*)&CLKPR)->bit0
#define	_CTPB                   ((volatile BYTE_STRUCT*)&SPMCSR)->bit4
#define	_RFLB                   ((volatile BYTE_STRUCT*)&SPMCSR)->bit3
#define	_PGWRT                  ((volatile BYTE_STRUCT*)&SPMCSR)->bit2
#define	_PGERS                  ((volatile BYTE_STRUCT*)&SPMCSR)->bit1
#define	_SPMEN                  ((volatile BYTE_STRUCT*)&SPMCSR)->bit0

//
// EEPROM variable definitions
//
#define	_EEPM1                  ((volatile BYTE_STRUCT*)&EECR)->bit5
#define	_EEPM0                  ((volatile BYTE_STRUCT*)&EECR)->bit4
#define	_EERIE                  ((volatile BYTE_STRUCT*)&EECR)->bit3
#define	_EEMWE                  ((volatile BYTE_STRUCT*)&EECR)->bit2
#define	_EEWE                   ((volatile BYTE_STRUCT*)&EECR)->bit1
#define	_EERE                   ((volatile BYTE_STRUCT*)&EECR)->bit0

//
// EXTERNAL_INTERRUPT variable definitions
//
// INT0 Interrupt Enable - Enabling_ENUM - [bit GIMSK.INT0] Enables the interrupt on the INT pin
#define	_INT0                   ((volatile BYTE_STRUCT*)&GIMSK)->bit6
// INT0 Interrupt Sense Control - SenseA_ENUM - [bit field "ISC0" MCUCR.(ISC00 | ISC01)] Specifies the type of signal that will generate an interrupt

typedef struct
{
	unsigned char	__ISC0            : 2;
} ISC0_STRUCT;

#define	_ISC0                   ((volatile ISC0_STRUCT*)&MCUCR)->__ISC0
// PCINT0 Interrupt Enable - Enabling_ENUM - [bit PCMSK.PCINT0] Enables interrupts on PCINT0
#define	_PCINT0                 ((volatile BYTE_STRUCT*)&PCMSK)->bit0
// PCINT1 Interrupt Enable - Enabling_ENUM - [bit PCMSK.PCINT1] Enables interrupts on PCINT1
#define	_PCINT1                 ((volatile BYTE_STRUCT*)&PCMSK)->bit1
// PCINT2 Interrupt Enable - Enabling_ENUM - [bit PCMSK.PCINT2] Enables interrupts on PCINT2
#define	_PCINT2                 ((volatile BYTE_STRUCT*)&PCMSK)->bit2
// PCINT3 Interrupt Enable - Enabling_ENUM - [bit PCMSK.PCINT3] Enables interrupts on PCINT3
#define	_PCINT3                 ((volatile BYTE_STRUCT*)&PCMSK)->bit3
// PCINT4 Interrupt Enable - Enabling_ENUM - [bit PCMSK.PCINT4] Enables interrupts on PCINT4
#define	_PCINT4                 ((volatile BYTE_STRUCT*)&PCMSK)->bit4
// PCINT5 Interrupt Enable - Enabling_ENUM - [bit PCMSK.PCINT5] Enables interrupts on PCINT5
#define	_PCINT5                 ((volatile BYTE_STRUCT*)&PCMSK)->bit5
// PCIE Interrupt Enable - Enabling_ENUM - [bit GIMSK.PCIE] Enables interrupts for PCINT7..0
#define	_PCIE                   ((volatile BYTE_STRUCT*)&GIMSK)->bit5

// other EXTERNAL_INTERRUPT bit definitions
#define	_INTF0                  ((volatile BYTE_STRUCT*)&GIFR)->bit6
#define	_PCIF                   ((volatile BYTE_STRUCT*)&GIFR)->bit5

//
// TIMER_COUNTER_0 variable definitions
//
// Waveform Generation Mode - WGM0_WGM_ENUM - [bit aggregate (TCCR0A.WGM00 | TCCR0A.WGM01 | TCCR0B.WGM02)] Controls how the counter will cycle.
typedef enum
{
	WGM0_WGM_Normal,                    	// Normal
	WGM0_WGM_PWMPhaseCorrect8bit,       	// PWM Phase Correct, 8-bit TOP=0xFF
	WGM0_WGM_CTC_OCR,                   	// Clear Timer on Compare Match TOP=OCRA
	WGM0_WGM_FastPWM8bit,               	// Fast PWM, 8-bit TOP=0xFF
	WGM0_WGM_Reserved,                  	// Reserved
	WGM0_WGM_PWMPhaseCorrect_OCR,       	// PWM Phase Correct, TOP=OCRA
	WGM0_WGM_Reserved2,                 	// Reserved
	WGM0_WGM_FastPWM_OCR,               	// Fast PWM TOP=OCRA
} WGM0_WGM_ENUM;
#define	_WGM00                  ((volatile BYTE_STRUCT*)&TCCR0A)->bit0
#define	_WGM01                  ((volatile BYTE_STRUCT*)&TCCR0A)->bit1
#define	_WGM02                  ((volatile BYTE_STRUCT*)&TCCR0B)->bit3
inline WGM0_WGM_ENUM get_WGM0(){ return (WGM0_WGM_ENUM)(_WGM00|(_WGM01 << 1)|(_WGM02 << 2)); }
inline void set_WGM0(WGM0_WGM_ENUM v){ _WGM00 = v; _WGM01 = v >> 1; _WGM02 = v >> 2; }
// Clock Select - CS0_CS_ENUM - [bit field "CS0" TCCR0B.(CS00 | CS01 | CS02)] Selects the clock divisor or the external clock source.
typedef enum
{
	CS0_CS_None,                        	// No clock source (Timer/Counter stopped)
	CS0_CS_DIV_1,                       	// clk (No prescaling)
	CS0_CS_DIV_8,                       	// clk / 8 (From prescaler)
	CS0_CS_DIV_64,                      	// clk / 64 (From prescaler)
	CS0_CS_DIV_256,                     	// clk / 256 (From prescaler)
	CS0_CS_DIV_1024,                    	// clk / 1024 (From prescaler)
	CS0_CS_External_Falling,            	// External clock source, Clock on falling edge
	CS0_CS_External_Rising,             	// External clock source, Clock on rising edge
} CS0_CS_ENUM;

typedef struct
{
	unsigned char	__CS0             : 3;
} CS0_STRUCT;

#define	_CS0                    ((volatile CS0_STRUCT*)&TCCR0B)->__CS0
// Timer Overflow Interrupt Enable - Enabling_ENUM - [bit TIMSK0.TOIE0]
#define	_TOIE0                  ((volatile BYTE_STRUCT*)&TIMSK0)->bit1
// Compare Output Mode A - _ENUM - [bit field "COMA0" TCCR0A.(COM0A0 | COM0A1)] Controls the Output Compare pin (OCnA) behavior.

typedef struct
{
	unsigned char	__Reserved        : 6;
	unsigned char	__COMA0           : 2;
} COMA0_STRUCT;

#define	_COMA0                  ((volatile COMA0_STRUCT*)&TCCR0A)->__COMA0
// Output Compare Match Interrupt Enable A - Enabling_ENUM - [bit TIMSK0.OCIE0A]
#define	_OCIE0A                 ((volatile BYTE_STRUCT*)&TIMSK0)->bit2
// Compare Output Mode B - _ENUM - [bit field "COMB0" TCCR0A.(COM0B0 | COM0B1)] Controls the Output Compare pin (OCnB) behavior.

typedef struct
{
	unsigned char	__Reserved        : 4;
	unsigned char	__COMB0           : 2;
} COMB0_STRUCT;

#define	_COMB0                  ((volatile COMB0_STRUCT*)&TCCR0A)->__COMB0
// Output Compare Match Interrupt Enable B - Enabling_ENUM - [bit TIMSK0.OCIE0B]
#define	_OCIE0B                 ((volatile BYTE_STRUCT*)&TIMSK0)->bit3

// other TIMER_COUNTER_0 bit definitions
#define	_OCF0B                  ((volatile BYTE_STRUCT*)&TIFR0)->bit3
#define	_OCF0A                  ((volatile BYTE_STRUCT*)&TIFR0)->bit2
#define	_TOV0                   ((volatile BYTE_STRUCT*)&TIFR0)->bit1
#define	_COM0A1                 ((volatile BYTE_STRUCT*)&TCCR0A)->bit7
#define	_COM0A0                 ((volatile BYTE_STRUCT*)&TCCR0A)->bit6
#define	_COM0B1                 ((volatile BYTE_STRUCT*)&TCCR0A)->bit5
#define	_COM0B0                 ((volatile BYTE_STRUCT*)&TCCR0A)->bit4
#define	_FOC0A                  ((volatile BYTE_STRUCT*)&TCCR0B)->bit7
#define	_FOC0B                  ((volatile BYTE_STRUCT*)&TCCR0B)->bit6
#define	_CS02                   ((volatile BYTE_STRUCT*)&TCCR0B)->bit2
#define	_CS01                   ((volatile BYTE_STRUCT*)&TCCR0B)->bit1
#define	_CS00                   ((volatile BYTE_STRUCT*)&TCCR0B)->bit0
#define	_TSM                    ((volatile BYTE_STRUCT*)&GTCCR)->bit7
#define	_PSR10                  ((volatile BYTE_STRUCT*)&GTCCR)->bit0

//
// WATCHDOG variable definitions
//
// Prescaler - WdtPrescale_ENUM - [bit aggregate (WDTCR.WDP0 | WDTCR.WDP1 | WDTCR.WDP2 | WDTCR.WDP3)] Sets the watchdog timeout period. Values are typical at 5v.
#define	_WDP0                   ((volatile BYTE_STRUCT*)&WDTCR)->bit0
#define	_WDP1                   ((volatile BYTE_STRUCT*)&WDTCR)->bit1
#define	_WDP2                   ((volatile BYTE_STRUCT*)&WDTCR)->bit2
#define	_WDP3                   ((volatile BYTE_STRUCT*)&WDTCR)->bit5
inline WdtPrescale_ENUM get_WDP(){ return (WdtPrescale_ENUM)(_WDP0|(_WDP1 << 1)|(_WDP2 << 2)|(_WDP3 << 3)); }
inline void set_WDP(WdtPrescale_ENUM v){ _WDP0 = v; _WDP1 = v >> 1; _WDP2 = v >> 2; _WDP3 = v >> 3; }
// Configuration - WdtMode_ENUM - [bit aggregate (WDTCR.WDTIE | WDTCR.WDE)] Determines the action taken when a watchdog timeout occurs.
#define	_WDTIE                  ((volatile BYTE_STRUCT*)&WDTCR)->bit6
#define	_WDE                    ((volatile BYTE_STRUCT*)&WDTCR)->bit3
inline WdtMode_ENUM get_Mode(){ return (WdtMode_ENUM)(_WDTIE|(_WDE << 1)); }
inline void set_Mode(WdtMode_ENUM v){ _WDTIE = v; _WDE = v >> 1; }

// other WATCHDOG bit definitions
#define	_WDTIF                  ((volatile BYTE_STRUCT*)&WDTCR)->bit7
#define	_WDCE                   ((volatile BYTE_STRUCT*)&WDTCR)->bit4

#define _AID_ATtiny13_DEFINED_
#endif /* _AID_ATtiny13_DEFINED_ */
