#ifndef _AID_ATtiny22_DEFINED_

typedef enum
{
	Enabling_Disabled,                  	// Disabled
	Enabling_Enabled,                   	// Enabled
} Enabling_ENUM;

//
// CPU variable definitions
//
#define	_SE                     ((volatile BYTE_STRUCT*)&MCUCR)->bit5
#define	_SM                     ((volatile BYTE_STRUCT*)&MCUCR)->bit4
#define	_ISC01                  ((volatile BYTE_STRUCT*)&MCUCR)->bit1
#define	_ISC00                  ((volatile BYTE_STRUCT*)&MCUCR)->bit0
#define	_EXTRF                  ((volatile BYTE_STRUCT*)&MCUSR)->bit1
#define	_PORF                   ((volatile BYTE_STRUCT*)&MCUSR)->bit0

//
// EEPROM variable definitions
//
#define	_EEMWE                  ((volatile BYTE_STRUCT*)&EECR)->bit2
#define	_EEWE                   ((volatile BYTE_STRUCT*)&EECR)->bit1
#define	_EERE                   ((volatile BYTE_STRUCT*)&EECR)->bit0

//
// TIMER_COUNTER_0 variable definitions
//
// Clock Select - CS0_CS_ENUM - [bit field "CS0" TCCR0.(CS00 | CS01 | CS02)] Selects the clock divisor or the external clock source.
typedef enum
{
	CS0_CS_None,                        	// No clock source (Timer/Counter stopped)
	CS0_CS_DIV_1,                       	// clk (No prescaling)
	CS0_CS_DIV_8,                       	// clk / 8 (From prescaler)
	CS0_CS_DIV_64,                      	// clk / 64 (From prescaler)
	CS0_CS_DIV_256,                     	// clk / 256 (From prescaler)
	CS0_CS_DIV_1024,                    	// clk / 1024 (From prescaler)
	CS0_CS_External_Falling,            	// External clock source, Clock on falling edge
	CS0_CS_External_Rising,             	// External clock source, Clock on rising edge
} CS0_CS_ENUM;

typedef struct
{
	unsigned char	__CS0             : 3;
} CS0_STRUCT;

#define	_CS0                    ((volatile CS0_STRUCT*)&TCCR0)->__CS0
// Timer Overflow Interrupt Enable - Enabling_ENUM - [bit TIMSK.TOIE0]
#define	_TOIE0                  ((volatile BYTE_STRUCT*)&TIMSK)->bit1

// other TIMER_COUNTER_0 bit definitions
#define	_TOV0                   ((volatile BYTE_STRUCT*)&TIFR)->bit1
#define	_CS02                   ((volatile BYTE_STRUCT*)&TCCR0)->bit2
#define	_CS01                   ((volatile BYTE_STRUCT*)&TCCR0)->bit1
#define	_CS00                   ((volatile BYTE_STRUCT*)&TCCR0)->bit0

//
// WATCHDOG variable definitions
//
// Prescaler - WDP_WdtPrescale_ENUM - [bit field "WDP" WDTCR.(WDP0 | WDP1 | WDP2)] Sets the watchdog timeout period. Values are typical at 5v.
typedef enum
{
	WDP_WdtPrescale_WDTO_16MS,          	// Typical Time-out 16 ms
	WDP_WdtPrescale_WDTO_32MS,          	// Typical Time-out 32 ms
	WDP_WdtPrescale_WDTO_64MS,          	// Typical Time-out 64 ms
	WDP_WdtPrescale_WDTO_125MS,         	// Typical Time-out 125 ms
	WDP_WdtPrescale_WDTO_250MS,         	// Typical Time-out 250 ms
	WDP_WdtPrescale_WDTO_500MS,         	// Typical Time-out 500 ms
	WDP_WdtPrescale_WDTO_1S,            	// Typical Time-out 1 sec
	WDP_WdtPrescale_WDTO_2S,            	// Typical Time-out 2 sec
} WDP_WdtPrescale_ENUM;

typedef struct
{
	unsigned char	__WDP             : 3;
} WDP_STRUCT;

#define	_WDP                    ((volatile WDP_STRUCT*)&WDTCR)->__WDP
// Enable - Enabling_ENUM - [bit WDTCR.WDE] Enables the watchdog timer.
#define	_WDE                    ((volatile BYTE_STRUCT*)&WDTCR)->bit3

// other WATCHDOG bit definitions
#define	_WDTOE                  ((volatile BYTE_STRUCT*)&WDTCR)->bit4
#define	_WDP2                   ((volatile BYTE_STRUCT*)&WDTCR)->bit2
#define	_WDP1                   ((volatile BYTE_STRUCT*)&WDTCR)->bit1
#define	_WDP0                   ((volatile BYTE_STRUCT*)&WDTCR)->bit0

#define _AID_ATtiny22_DEFINED_
#endif /* _AID_ATtiny22_DEFINED_ */
