#ifndef _AID_ATtiny2313_DEFINED_

typedef enum
{
	Disabling_Enabled,                  	// Enabled
	Disabling_Disabled,                 	// Disabled
} Disabling_ENUM;

typedef enum
{
	Enabling_Disabled,                  	// Disabled
	Enabling_Enabled,                   	// Enabled
} Enabling_ENUM;

typedef enum
{
	ACIntModeSelect_OutputToggle,       	// Comparator Interrupt on Output Toggle
	ACIntModeSelect_Reserved,           	// Reserved
	ACIntModeSelect_FallingOutputEdge,  	// Comparator Interrupt on Falling Output Edge
	ACIntModeSelect_RisingOutputEdge,   	// Comparator Interrupt on Rising Output Edge
} ACIntModeSelect_ENUM;

typedef enum
{
	ACBandgapSelect_NoBandgap,          	// Use AIN0 as positive input
	ACBandgapSelect_Bandgap,            	// Use fixed bandgap reference voltage as positive input
} ACBandgapSelect_ENUM;

typedef enum
{
	SenseA_LowLevel,                    	// Low Level Generates Interrupt
	SenseA_AnyChange,                   	// Any Change Generates Interrupt
	SenseA_FallingEdge,                 	// Falling Edge Generates Interrupt
	SenseA_RisingEdge,                  	// Rising Edge Generates Interrupt
} SenseA_ENUM;

typedef enum
{
	Trigger_Falling,                    	// Falling Edge Trigger
	Trigger_Rising,                     	// Rising Edge Trigger
} Trigger_ENUM;

typedef enum
{
	UsartCharacterSize_FiveBits,        	// 5 bits
	UsartCharacterSize_SixBits,         	// 6 bits
	UsartCharacterSize_SevenBits,       	// 7 bits
	UsartCharacterSize_EightBits,       	// 8 bits
	UsartCharacterSize_Reserved,        	// Reserved
	UsartCharacterSize_Reserved2,       	// Reserved
	UsartCharacterSize_Reserved3,       	// Reserved
	UsartCharacterSize_NineBits,        	// 9 bits
} UsartCharacterSize_ENUM;

typedef enum
{
	UsartStopBitSelect_OneStopBit,      	// 1 stop bit
	UsartStopBitSelect_TwoStopBits,     	// 2 stop bits
} UsartStopBitSelect_ENUM;

typedef enum
{
	UsartParityMode_Disabled,           	// Disabled
	UsartParityMode_Reserved,           	// Reserved
	UsartParityMode_EvenParity,         	// Even Parity
	UsartParityMode_OddParity,          	// Odd Parity
} UsartParityMode_ENUM;

typedef enum
{
	UsartClockPolarity_Normal,          	// TX Changed on Rising Edge, RX Sampled on Falling Edge
	UsartClockPolarity_Inverted,        	// TX Changed on Falling Edge, RX Sampled on Rising Edge
} UsartClockPolarity_ENUM;

typedef enum
{
	WdtPrescale_WDTO_16MS,              	// Typical Time-out 16 ms
	WdtPrescale_WDTO_32MS,              	// Typical Time-out 32 ms
	WdtPrescale_WDTO_64MS,              	// Typical Time-out 64 ms
	WdtPrescale_WDTO_125MS,             	// Typical Time-out 125 ms
	WdtPrescale_WDTO_250MS,             	// Typical Time-out 250 ms
	WdtPrescale_WDTO_500MS,             	// Typical Time-out 500 ms
	WdtPrescale_WDTO_1S,                	// Typical Time-out 1 sec
	WdtPrescale_WDTO_2S,                	// Typical Time-out 2 sec
	WdtPrescale_WDTO_4S,                	// Typical Time-out 4 sec
	WdtPrescale_WDTO_8S,                	// Typical Time-out 8 sec
	WdtPrescale_WDTO_Invalid1,          	// Invalid
	WdtPrescale_WDTO_Invalid2,          	// Invalid
	WdtPrescale_WDTO_Invalid3,          	// Invalid
	WdtPrescale_WDTO_Invalid4,          	// Invalid
	WdtPrescale_WDTO_Invalid5,          	// Invalid
	WdtPrescale_WDTO_Invalid6,          	// Invalid
} WdtPrescale_ENUM;

typedef enum
{
	WdtMode_Disabled,                   	// Disabled
	WdtMode_Interrupt,                  	// Interrupt on timeout
	WdtMode_SystemReset,                	// System reset on timeout
	WdtMode_InterruptAndSystemReset,    	// Interrupt on first timeout, system reset on next
} WdtMode_ENUM;

//
// ANALOG_COMPARATOR variable definitions
//
// Analog Comparator Disable - Disabling_ENUM - [bit ACSR.ACD] Disables the Analog Comparator.
#define	_ACD                    ((volatile BYTE_STRUCT*)&ACSR)->bit7
// Interrupt Enable - Enabling_ENUM - [bit ACSR.ACIE] When enabled and the I-bit in the Status Register is set, the Analog Comparator interrupt is activated.
#define	_ACIE                   ((volatile BYTE_STRUCT*)&ACSR)->bit3
// Interrupt Mode Select - ACIntModeSelect_ENUM - [bit field "ACIS" ACSR.(ACIS0 | ACIS1)] Determine which comparator events trigger the Analog Comparator interrupt.

typedef struct
{
	unsigned char	__ACIS            : 2;
} ACIS_STRUCT;

#define	_ACIS                   ((volatile ACIS_STRUCT*)&ACSR)->__ACIS
// Input Capture Enable - Enabling_ENUM - [bit ACSR.ACIC] Enables the input capture function in Timer/Counter1 to be triggered by the Analog Comparator.
#define	_ACIC                   ((volatile BYTE_STRUCT*)&ACSR)->bit2
// Bandgap Select - ACBandgapSelect_ENUM - [bit ACSR.ACBG] Selects a bandgap reference voltage as the positive input.
#define	_ACBG                   ((volatile BYTE_STRUCT*)&ACSR)->bit6
// Digital Input 0 Disable - Disabling_ENUM - [bit DIDR.AIN0D] When disabled, the digital input buffer on the AIN0 pin is disabled.
#define	_AIN0D                  ((volatile BYTE_STRUCT*)&DIDR)->bit0
// Digital Input 1 Disable - Disabling_ENUM - [bit DIDR.AIN1D] When disabled, the digital input buffer on the AIN1 pin is disabled.
#define	_AIN1D                  ((volatile BYTE_STRUCT*)&DIDR)->bit1

// other ANALOG_COMPARATOR bit definitions
#define	_ACO                    ((volatile BYTE_STRUCT*)&ACSR)->bit5
#define	_ACI                    ((volatile BYTE_STRUCT*)&ACSR)->bit4
#define	_ACIS1                  ((volatile BYTE_STRUCT*)&ACSR)->bit1
#define	_ACIS0                  ((volatile BYTE_STRUCT*)&ACSR)->bit0

//
// CPU variable definitions
//
#define	_CTPB                   ((volatile BYTE_STRUCT*)&SPMCSR)->bit4
#define	_RFLB                   ((volatile BYTE_STRUCT*)&SPMCSR)->bit3
#define	_PGWRT                  ((volatile BYTE_STRUCT*)&SPMCSR)->bit2
#define	_PGERS                  ((volatile BYTE_STRUCT*)&SPMCSR)->bit1
#define	_SPMEN                  ((volatile BYTE_STRUCT*)&SPMCSR)->bit0
#define	_PUD                    ((volatile BYTE_STRUCT*)&MCUCR)->bit7
#define	_SM1                    ((volatile BYTE_STRUCT*)&MCUCR)->bit6
#define	_SE                     ((volatile BYTE_STRUCT*)&MCUCR)->bit5
#define	_SM0                    ((volatile BYTE_STRUCT*)&MCUCR)->bit4
#define	_ISC11                  ((volatile BYTE_STRUCT*)&MCUCR)->bit3
#define	_ISC10                  ((volatile BYTE_STRUCT*)&MCUCR)->bit2
#define	_ISC01                  ((volatile BYTE_STRUCT*)&MCUCR)->bit1
#define	_ISC00                  ((volatile BYTE_STRUCT*)&MCUCR)->bit0
#define	_CLKPCE                 ((volatile BYTE_STRUCT*)&CLKPR)->bit7
#define	_CLKPS3                 ((volatile BYTE_STRUCT*)&CLKPR)->bit3
#define	_CLKPS2                 ((volatile BYTE_STRUCT*)&CLKPR)->bit2
#define	_CLKPS1                 ((volatile BYTE_STRUCT*)&CLKPR)->bit1
#define	_CLKPS0                 ((volatile BYTE_STRUCT*)&CLKPR)->bit0
#define	_WDRF                   ((volatile BYTE_STRUCT*)&MCUSR)->bit3
#define	_BORF                   ((volatile BYTE_STRUCT*)&MCUSR)->bit2
#define	_EXTRF                  ((volatile BYTE_STRUCT*)&MCUSR)->bit1
#define	_PORF                   ((volatile BYTE_STRUCT*)&MCUSR)->bit0
#define	_PSR10                  ((volatile BYTE_STRUCT*)&GTCCR)->bit0
#define	_PCINT0                 ((volatile BYTE_STRUCT*)&PCMSK)->bit0
#define	_PCINT1                 ((volatile BYTE_STRUCT*)&PCMSK)->bit1
#define	_PCINT2                 ((volatile BYTE_STRUCT*)&PCMSK)->bit2
#define	_PCINT3                 ((volatile BYTE_STRUCT*)&PCMSK)->bit3
#define	_PCINT4                 ((volatile BYTE_STRUCT*)&PCMSK)->bit4
#define	_PCINT5                 ((volatile BYTE_STRUCT*)&PCMSK)->bit5
#define	_PCINT6                 ((volatile BYTE_STRUCT*)&PCMSK)->bit6
#define	_PCINT7                 ((volatile BYTE_STRUCT*)&PCMSK)->bit7

//
// EEPROM variable definitions
//
#define	_EEPM1                  ((volatile BYTE_STRUCT*)&EECR)->bit5
#define	_EEPM0                  ((volatile BYTE_STRUCT*)&EECR)->bit4
#define	_EERIE                  ((volatile BYTE_STRUCT*)&EECR)->bit3
#define	_EEMPE                  ((volatile BYTE_STRUCT*)&EECR)->bit2
#define	_EEPE                   ((volatile BYTE_STRUCT*)&EECR)->bit1
#define	_EERE                   ((volatile BYTE_STRUCT*)&EECR)->bit0

//
// EXTERNAL_INTERRUPT variable definitions
//
// INT0 Interrupt Enable - Enabling_ENUM - [bit GIMSK.INT0] Enables the interrupt on the INT pin
#define	_INT0                   ((volatile BYTE_STRUCT*)&GIMSK)->bit6
// INT0 Interrupt Sense Control - SenseA_ENUM - [bit field "ISC0" MCUCR.(ISC00 | ISC01)] Specifies the type of signal that will generate an interrupt

typedef struct
{
	unsigned char	__ISC0            : 2;
} ISC0_STRUCT;

#define	_ISC0                   ((volatile ISC0_STRUCT*)&MCUCR)->__ISC0
// INT1 Interrupt Enable - Enabling_ENUM - [bit GIMSK.INT1] Enables the interrupt on the INT pin
#define	_INT1                   ((volatile BYTE_STRUCT*)&GIMSK)->bit7
// INT1 Interrupt Sense Control - SenseA_ENUM - [bit field "ISC1" MCUCR.(ISC10 | ISC11)] Specifies the type of signal that will generate an interrupt

typedef struct
{
	unsigned char	__Reserved        : 2;
	unsigned char	__ISC1            : 2;
} ISC1_STRUCT;

#define	_ISC1                   ((volatile ISC1_STRUCT*)&MCUCR)->__ISC1
// PCINT0 Interrupt Enable - Enabling_ENUM - [bit PCMSK.PCINT0] Enables interrupts on PCINT0
// PCINT1 Interrupt Enable - Enabling_ENUM - [bit PCMSK.PCINT1] Enables interrupts on PCINT1
// PCINT2 Interrupt Enable - Enabling_ENUM - [bit PCMSK.PCINT2] Enables interrupts on PCINT2
// PCINT3 Interrupt Enable - Enabling_ENUM - [bit PCMSK.PCINT3] Enables interrupts on PCINT3
// PCINT4 Interrupt Enable - Enabling_ENUM - [bit PCMSK.PCINT4] Enables interrupts on PCINT4
// PCINT5 Interrupt Enable - Enabling_ENUM - [bit PCMSK.PCINT5] Enables interrupts on PCINT5
// PCINT6 Interrupt Enable - Enabling_ENUM - [bit PCMSK.PCINT6] Enables interrupts on PCINT6
// PCINT7 Interrupt Enable - Enabling_ENUM - [bit PCMSK.PCINT7] Enables interrupts on PCINT7
// PCIE Interrupt Enable - Enabling_ENUM - [bit GIMSK.PCIE] Enables interrupts for PCINT7..0
#define	_PCIE                   ((volatile BYTE_STRUCT*)&GIMSK)->bit5

// other EXTERNAL_INTERRUPT bit definitions
#define	_INTF1                  ((volatile BYTE_STRUCT*)&EIFR)->bit7
#define	_INTF0                  ((volatile BYTE_STRUCT*)&EIFR)->bit6
#define	_PCIF                   ((volatile BYTE_STRUCT*)&EIFR)->bit5

//
// TIMER_COUNTER_0 variable definitions
//
// Waveform Generation Mode - WGM0_WGM_ENUM - [bit aggregate (TCCR0A.WGM00 | TCCR0A.WGM01 | TCCR0B.WGM02)] Controls how the counter will cycle.
typedef enum
{
	WGM0_WGM_Normal,                    	// Normal
	WGM0_WGM_PWMPhaseCorrect8bit,       	// PWM Phase Correct, 8-bit TOP=0xFF
	WGM0_WGM_CTC_OCR,                   	// Clear Timer on Compare Match TOP=OCRA
	WGM0_WGM_FastPWM8bit,               	// Fast PWM, 8-bit TOP=0xFF
	WGM0_WGM_Reserved,                  	// Reserved
	WGM0_WGM_PWMPhaseCorrect_OCR,       	// PWM Phase Correct, TOP=OCRA
	WGM0_WGM_Reserved2,                 	// Reserved
	WGM0_WGM_FastPWM_OCR,               	// Fast PWM TOP=OCRA
} WGM0_WGM_ENUM;
#define	_WGM00                  ((volatile BYTE_STRUCT*)&TCCR0A)->bit0
#define	_WGM01                  ((volatile BYTE_STRUCT*)&TCCR0A)->bit1
#define	_WGM02                  ((volatile BYTE_STRUCT*)&TCCR0B)->bit3
inline WGM0_WGM_ENUM get_WGM0(){ return (WGM0_WGM_ENUM)(_WGM00|(_WGM01 << 1)|(_WGM02 << 2)); }
inline void set_WGM0(WGM0_WGM_ENUM v){ _WGM00 = v; _WGM01 = v >> 1; _WGM02 = v >> 2; }
// Clock Select - CS0_CS_ENUM - [bit field "CS0" TCCR0B.(CS00 | CS01 | CS02)] Selects the clock divisor or the external clock source.
typedef enum
{
	CS0_CS_None,                        	// No clock source (Timer/Counter stopped)
	CS0_CS_DIV_1,                       	// clk (No prescaling)
	CS0_CS_DIV_8,                       	// clk / 8 (From prescaler)
	CS0_CS_DIV_64,                      	// clk / 64 (From prescaler)
	CS0_CS_DIV_256,                     	// clk / 256 (From prescaler)
	CS0_CS_DIV_1024,                    	// clk / 1024 (From prescaler)
	CS0_CS_External_Falling,            	// External clock source, Clock on falling edge
	CS0_CS_External_Rising,             	// External clock source, Clock on rising edge
} CS0_CS_ENUM;

typedef struct
{
	unsigned char	__CS0             : 3;
} CS0_STRUCT;

#define	_CS0                    ((volatile CS0_STRUCT*)&TCCR0B)->__CS0
// Timer Overflow Interrupt Enable - Enabling_ENUM - [bit TIMSK.TOIE0]
#define	_TOIE0                  ((volatile BYTE_STRUCT*)&TIMSK)->bit1
// Compare Output Mode A - _ENUM - [bit field "COMA0" TCCR0A.(COM0A0 | COM0A1)] Controls the Output Compare pin (OCnA) behavior.

typedef struct
{
	unsigned char	__Reserved        : 6;
	unsigned char	__COMA0           : 2;
} COMA0_STRUCT;

#define	_COMA0                  ((volatile COMA0_STRUCT*)&TCCR0A)->__COMA0
// Output Compare Match Interrupt Enable A - Enabling_ENUM - [bit TIMSK.OCIE0A]
#define	_OCIE0A                 ((volatile BYTE_STRUCT*)&TIMSK)->bit0
// Compare Output Mode B - _ENUM - [bit field "COMB0" TCCR0A.(COM0B0 | COM0B1)] Controls the Output Compare pin (OCnB) behavior.

typedef struct
{
	unsigned char	__Reserved        : 4;
	unsigned char	__COMB0           : 2;
} COMB0_STRUCT;

#define	_COMB0                  ((volatile COMB0_STRUCT*)&TCCR0A)->__COMB0
// Output Compare Match Interrupt Enable B - Enabling_ENUM - [bit TIMSK.OCIE0B]
#define	_OCIE0B                 ((volatile BYTE_STRUCT*)&TIMSK)->bit2

// other TIMER_COUNTER_0 bit definitions
#define	_OCF0B                  ((volatile BYTE_STRUCT*)&TIFR)->bit2
#define	_TOV0                   ((volatile BYTE_STRUCT*)&TIFR)->bit1
#define	_OCF0A                  ((volatile BYTE_STRUCT*)&TIFR)->bit0
#define	_COM0A1                 ((volatile BYTE_STRUCT*)&TCCR0A)->bit7
#define	_COM0A0                 ((volatile BYTE_STRUCT*)&TCCR0A)->bit6
#define	_COM0B1                 ((volatile BYTE_STRUCT*)&TCCR0A)->bit5
#define	_COM0B0                 ((volatile BYTE_STRUCT*)&TCCR0A)->bit4
#define	_FOC0A                  ((volatile BYTE_STRUCT*)&TCCR0B)->bit7
#define	_FOC0B                  ((volatile BYTE_STRUCT*)&TCCR0B)->bit6
#define	_CS02                   ((volatile BYTE_STRUCT*)&TCCR0B)->bit2
#define	_CS01                   ((volatile BYTE_STRUCT*)&TCCR0B)->bit1
#define	_CS00                   ((volatile BYTE_STRUCT*)&TCCR0B)->bit0

//
// TIMER_COUNTER_1 variable definitions
//
// Waveform Generation Mode - WGM1_WGM_ENUM - [bit aggregate (TCCR1A.WGM10 | TCCR1A.WGM11 | TCCR1B.WGM12 | TCCR1B.WGM13)] Controls how the counter will cycle.
typedef enum
{
	WGM1_WGM_Normal,                    	// Normal
	WGM1_WGM_PWMPhaseCorrect8bit,       	// PWM Phase Correct, 8-bit TOP=0xFF
	WGM1_WGM_PWMPhaseCorrect9bit,       	// PWM Phase Correct, 9-bit TOP=0x1FF
	WGM1_WGM_PWMPhaseCorrect10bit,      	// PWM Phase Correct, 10-bit TOP=0x3FF
	WGM1_WGM_CTC_OCR,                   	// Clear Timer on Compare Match TOP=OCRA
	WGM1_WGM_FastPWM8bit,               	// Fast PWM, 8-bit TOP=0xFF
	WGM1_WGM_FastPWM9bit,               	// Fast PWM, 9-bit TOP=0x1FF
	WGM1_WGM_FastPWM10bit,              	// Fast PWM, 10-bit TOP=0x3FF
	WGM1_WGM_PWMPhaseFreqCorrect_ICR,   	// PWM Phase and Freq Correct, TOP=ICR
	WGM1_WGM_PWMPhaseFreqCorrect_OCR,   	// PWM Phase and Freq Correct, TOP=OCRA
	WGM1_WGM_PWMPhaseCorrect_ICR,       	// PWM Phase Correct, TOP=ICR
	WGM1_WGM_PWMPhaseCorrect_OCR,       	// PWM Phase Correct, TOP=OCRA
	WGM1_WGM_CTC_ICR,                   	// Clear Timer on Compare Match TOP=ICR
	WGM1_WGM_Reserved,                  	// Reserved
	WGM1_WGM_FastPWM_ICR,               	// Fast PWM TOP=ICR
	WGM1_WGM_FastPWM_OCR,               	// Fast PWM TOP=OCRA
} WGM1_WGM_ENUM;
#define	_WGM10                  ((volatile BYTE_STRUCT*)&TCCR1A)->bit0
#define	_WGM11                  ((volatile BYTE_STRUCT*)&TCCR1A)->bit1
#define	_WGM12                  ((volatile BYTE_STRUCT*)&TCCR1B)->bit3
#define	_WGM13                  ((volatile BYTE_STRUCT*)&TCCR1B)->bit4
inline WGM1_WGM_ENUM get_WGM1(){ return (WGM1_WGM_ENUM)(_WGM10|(_WGM11 << 1)|(_WGM12 << 2)|(_WGM13 << 3)); }
inline void set_WGM1(WGM1_WGM_ENUM v){ _WGM10 = v; _WGM11 = v >> 1; _WGM12 = v >> 2; _WGM13 = v >> 3; }
// Clock Select - CS1_CS_ENUM - [bit field "CS1" TCCR1B.(CS10 | CS11 | CS12)] Selects the clock divisor or the external clock source.
typedef enum
{
	CS1_CS_None,                        	// No clock source (Timer/Counter stopped)
	CS1_CS_DIV_1,                       	// clk (No prescaling)
	CS1_CS_DIV_8,                       	// clk / 8 (From prescaler)
	CS1_CS_DIV_64,                      	// clk / 64 (From prescaler)
	CS1_CS_DIV_256,                     	// clk / 256 (From prescaler)
	CS1_CS_DIV_1024,                    	// clk / 1024 (From prescaler)
	CS1_CS_External_Falling,            	// External clock source, Clock on falling edge
	CS1_CS_External_Rising,             	// External clock source, Clock on rising edge
} CS1_CS_ENUM;

typedef struct
{
	unsigned char	__CS1             : 3;
} CS1_STRUCT;

#define	_CS1                    ((volatile CS1_STRUCT*)&TCCR1B)->__CS1
// Timer Overflow Interrupt Enable - Enabling_ENUM - [bit TIMSK.TOIE1]
#define	_TOIE1                  ((volatile BYTE_STRUCT*)&TIMSK)->bit7
// Input Capture Noise Cancel - Enabling_ENUM - [bit TCCR1B.ICNC1]
#define	_ICNC1                  ((volatile BYTE_STRUCT*)&TCCR1B)->bit7
// Input Capture Edge Select - Trigger_ENUM - [bit TCCR1B.ICES1]
#define	_ICES1                  ((volatile BYTE_STRUCT*)&TCCR1B)->bit6
// Input Capture Interrupt Enable - Enabling_ENUM - [bit TIMSK.ICIE1]
#define	_ICIE1                  ((volatile BYTE_STRUCT*)&TIMSK)->bit3
// Compare Output Mode A - _ENUM - [bit field "COMA1" TCCR1A.(COM1A0 | COM1A1)] Controls the Output Compare pin (OCnA) behavior.

typedef struct
{
	unsigned char	__Reserved        : 6;
	unsigned char	__COMA1           : 2;
} COMA1_STRUCT;

#define	_COMA1                  ((volatile COMA1_STRUCT*)&TCCR1A)->__COMA1
// Output Compare Match Interrupt Enable A - Enabling_ENUM - [bit TIMSK.OCIE1A]
#define	_OCIE1A                 ((volatile BYTE_STRUCT*)&TIMSK)->bit6
// Compare Output Mode B - _ENUM - [bit field "COMB1" TCCR1A.(COM1B0 | COM1B1)] Controls the Output Compare pin (OCnB) behavior.

typedef struct
{
	unsigned char	__Reserved        : 4;
	unsigned char	__COMB1           : 2;
} COMB1_STRUCT;

#define	_COMB1                  ((volatile COMB1_STRUCT*)&TCCR1A)->__COMB1
// Output Compare Match Interrupt Enable B - Enabling_ENUM - [bit TIMSK.OCIE1B]
#define	_OCIE1B                 ((volatile BYTE_STRUCT*)&TIMSK)->bit5

// other TIMER_COUNTER_1 bit definitions
#define	_TOV1                   ((volatile BYTE_STRUCT*)&TIFR)->bit7
#define	_OCF1A                  ((volatile BYTE_STRUCT*)&TIFR)->bit6
#define	_OCF1B                  ((volatile BYTE_STRUCT*)&TIFR)->bit5
#define	_ICF1                   ((volatile BYTE_STRUCT*)&TIFR)->bit3
#define	_COM1A1                 ((volatile BYTE_STRUCT*)&TCCR1A)->bit7
#define	_COM1A0                 ((volatile BYTE_STRUCT*)&TCCR1A)->bit6
#define	_COM1B1                 ((volatile BYTE_STRUCT*)&TCCR1A)->bit5
#define	_COM1B0                 ((volatile BYTE_STRUCT*)&TCCR1A)->bit4
#define	_CS12                   ((volatile BYTE_STRUCT*)&TCCR1B)->bit2
#define	_CS11                   ((volatile BYTE_STRUCT*)&TCCR1B)->bit1
#define	_CS10                   ((volatile BYTE_STRUCT*)&TCCR1B)->bit0
#define	_FOC1A                  ((volatile BYTE_STRUCT*)&TCCR1C)->bit7
#define	_FOC1B                  ((volatile BYTE_STRUCT*)&TCCR1C)->bit6

//
// USART variable definitions
//
// Receiver Enable - Enabling_ENUM - [bit UCSRB.RXEN]
#define	_RXEN                   ((volatile BYTE_STRUCT*)&UCSRB)->bit4
// Transmitter Enable - Enabling_ENUM - [bit UCSRB.TXEN]
#define	_TXEN                   ((volatile BYTE_STRUCT*)&UCSRB)->bit3
// Mode Select - UMSEL_UsartModeSelect_ENUM - [bit UCSRC.UMSEL] Select between Asynchronous and Synchronous mode of operation.
typedef enum
{
	UMSEL_UsartModeSelect_Async,        	// Asynchronous Operation
	UMSEL_UsartModeSelect_Sync,         	// Synchronous Operation
} UMSEL_UsartModeSelect_ENUM;
#define	_UMSEL                  ((volatile BYTE_STRUCT*)&UCSRC)->bit6
// Character Size - UsartCharacterSize_ENUM - [bit aggregate (UCSRC.UCSZ0 | UCSRC.UCSZ1 | UCSRB.UCSZ2)] Set the number of data bits in a frame the Receiver and Transmitter use.
#define	_UCSZ0                  ((volatile BYTE_STRUCT*)&UCSRC)->bit1
#define	_UCSZ1                  ((volatile BYTE_STRUCT*)&UCSRC)->bit2
#define	_UCSZ2                  ((volatile BYTE_STRUCT*)&UCSRB)->bit2
inline UsartCharacterSize_ENUM get_UCSZ(){ return (UsartCharacterSize_ENUM)(_UCSZ0|(_UCSZ1 << 1)|(_UCSZ2 << 2)); }
inline void set_UCSZ(UsartCharacterSize_ENUM v){ _UCSZ0 = v; _UCSZ1 = v >> 1; _UCSZ2 = v >> 2; }
// Stop Bit Select - UsartStopBitSelect_ENUM - [bit UCSRC.USBS] Selects the number of Stop Bits to be inserted by the Transmitter. The Receiver ignores this setting.
#define	_USBS                   ((volatile BYTE_STRUCT*)&UCSRC)->bit3
// Parity Mode - UsartParityMode_ENUM - [bit field "UPM" UCSRC.(UPM0 | UPM1)] Enable and set type of parity generation and check.

typedef struct
{
	unsigned char	__Reserved        : 4;
	unsigned char	__UPM             : 2;
} UPM_STRUCT;

#define	_UPM                    ((volatile UPM_STRUCT*)&UCSRC)->__UPM
// Double Transmission Speed - Enabling_ENUM - [bit UCSRA.U2X]
#define	_U2X                    ((volatile BYTE_STRUCT*)&UCSRA)->bit1
// Clock Polarity - UsartClockPolarity_ENUM - [bit UCSRC.UCPOL] Sets the relationship between data output change and data input sample, and the synchronous clock (XCK).
#define	_UCPOL                  ((volatile BYTE_STRUCT*)&UCSRC)->bit0
// Multi-processor Communication Mode - Enabling_ENUM - [bit UCSRA.MPCM]
#define	_MPCM                   ((volatile BYTE_STRUCT*)&UCSRA)->bit0
// RX Complete Interrupt Enable - Enabling_ENUM - [bit UCSRB.RXCIE]
#define	_RXCIE                  ((volatile BYTE_STRUCT*)&UCSRB)->bit7
// TX Complete Interrupt Enable - Enabling_ENUM - [bit UCSRB.TXCIE]
#define	_TXCIE                  ((volatile BYTE_STRUCT*)&UCSRB)->bit6
// Data Register Empty Interrupt Enable - Enabling_ENUM - [bit UCSRB.UDRIE] Enable an interrupt when the transmit buffer (UDR) is ready to receive new data.
#define	_UDRIE                  ((volatile BYTE_STRUCT*)&UCSRB)->bit5

// other USART bit definitions
#define	_RXC                    ((volatile BYTE_STRUCT*)&UCSRA)->bit7
#define	_TXC                    ((volatile BYTE_STRUCT*)&UCSRA)->bit6
#define	_UDRE                   ((volatile BYTE_STRUCT*)&UCSRA)->bit5
#define	_FE                     ((volatile BYTE_STRUCT*)&UCSRA)->bit4
#define	_DOR                    ((volatile BYTE_STRUCT*)&UCSRA)->bit3
#define	_UPE                    ((volatile BYTE_STRUCT*)&UCSRA)->bit2
#define	_RXB8                   ((volatile BYTE_STRUCT*)&UCSRB)->bit1
#define	_TXB8                   ((volatile BYTE_STRUCT*)&UCSRB)->bit0
#define	_UPM1                   ((volatile BYTE_STRUCT*)&UCSRC)->bit5
#define	_UPM0                   ((volatile BYTE_STRUCT*)&UCSRC)->bit4

//
// USI variable definitions
//
#define	_USISIF                 ((volatile BYTE_STRUCT*)&USISR)->bit7
#define	_USIOIF                 ((volatile BYTE_STRUCT*)&USISR)->bit6
#define	_USIPF                  ((volatile BYTE_STRUCT*)&USISR)->bit5
#define	_USIDC                  ((volatile BYTE_STRUCT*)&USISR)->bit4
#define	_USICNT3                ((volatile BYTE_STRUCT*)&USISR)->bit3
#define	_USICNT2                ((volatile BYTE_STRUCT*)&USISR)->bit2
#define	_USICNT1                ((volatile BYTE_STRUCT*)&USISR)->bit1
#define	_USICNT0                ((volatile BYTE_STRUCT*)&USISR)->bit0
#define	_USISIE                 ((volatile BYTE_STRUCT*)&USICR)->bit7
#define	_USIOIE                 ((volatile BYTE_STRUCT*)&USICR)->bit6
#define	_USIWM1                 ((volatile BYTE_STRUCT*)&USICR)->bit5
#define	_USIWM0                 ((volatile BYTE_STRUCT*)&USICR)->bit4
#define	_USICS1                 ((volatile BYTE_STRUCT*)&USICR)->bit3
#define	_USICS0                 ((volatile BYTE_STRUCT*)&USICR)->bit2
#define	_USICLK                 ((volatile BYTE_STRUCT*)&USICR)->bit1
#define	_USITC                  ((volatile BYTE_STRUCT*)&USICR)->bit0

//
// WATCHDOG variable definitions
//
// Prescaler - WdtPrescale_ENUM - [bit aggregate (WDTCSR.WDP0 | WDTCSR.WDP1 | WDTCSR.WDP2 | WDTCSR.WDP3)] Sets the watchdog timeout period. Values are typical at 5v.
#define	_WDP0                   ((volatile BYTE_STRUCT*)&WDTCSR)->bit0
#define	_WDP1                   ((volatile BYTE_STRUCT*)&WDTCSR)->bit1
#define	_WDP2                   ((volatile BYTE_STRUCT*)&WDTCSR)->bit2
#define	_WDP3                   ((volatile BYTE_STRUCT*)&WDTCSR)->bit5
inline WdtPrescale_ENUM get_WDP(){ return (WdtPrescale_ENUM)(_WDP0|(_WDP1 << 1)|(_WDP2 << 2)|(_WDP3 << 3)); }
inline void set_WDP(WdtPrescale_ENUM v){ _WDP0 = v; _WDP1 = v >> 1; _WDP2 = v >> 2; _WDP3 = v >> 3; }
// Configuration - WdtMode_ENUM - [bit aggregate (WDTCSR.WDIE | WDTCSR.WDE)] Determines the action taken when a watchdog timeout occurs.
#define	_WDIE                   ((volatile BYTE_STRUCT*)&WDTCSR)->bit6
#define	_WDE                    ((volatile BYTE_STRUCT*)&WDTCSR)->bit3
inline WdtMode_ENUM get_Mode(){ return (WdtMode_ENUM)(_WDIE|(_WDE << 1)); }
inline void set_Mode(WdtMode_ENUM v){ _WDIE = v; _WDE = v >> 1; }

// other WATCHDOG bit definitions
#define	_WDIF                   ((volatile BYTE_STRUCT*)&WDTCSR)->bit7
#define	_WDCE                   ((volatile BYTE_STRUCT*)&WDTCSR)->bit4

#define _AID_ATtiny2313_DEFINED_
#endif /* _AID_ATtiny2313_DEFINED_ */
