#ifndef _AID_ATtiny26_DEFINED_

typedef enum
{
	Disabling_Enabled,                  	// Enabled
	Disabling_Disabled,                 	// Disabled
} Disabling_ENUM;

typedef enum
{
	Enabling_Disabled,                  	// Disabled
	Enabling_Enabled,                   	// Enabled
} Enabling_ENUM;

typedef enum
{
	ACIntModeSelect_OutputToggle,       	// Comparator Interrupt on Output Toggle
	ACIntModeSelect_Reserved,           	// Reserved
	ACIntModeSelect_FallingOutputEdge,  	// Comparator Interrupt on Falling Output Edge
	ACIntModeSelect_RisingOutputEdge,   	// Comparator Interrupt on Rising Output Edge
} ACIntModeSelect_ENUM;

typedef enum
{
	ACBandgapSelect_NoBandgap,          	// Use AIN0 as positive input
	ACBandgapSelect_Bandgap,            	// Use fixed bandgap reference voltage as positive input
} ACBandgapSelect_ENUM;

typedef enum
{
	SenseA_LowLevel,                    	// Low Level Generates Interrupt
	SenseA_AnyChange,                   	// Any Change Generates Interrupt
	SenseA_FallingEdge,                 	// Falling Edge Generates Interrupt
	SenseA_RisingEdge,                  	// Rising Edge Generates Interrupt
} SenseA_ENUM;

//
// AD_CONVERTER variable definitions
//
#define	_REFS1                  ((volatile BYTE_STRUCT*)&ADMUX)->bit7
#define	_REFS0                  ((volatile BYTE_STRUCT*)&ADMUX)->bit6
#define	_ADLAR                  ((volatile BYTE_STRUCT*)&ADMUX)->bit5
#define	_MUX4                   ((volatile BYTE_STRUCT*)&ADMUX)->bit4
#define	_MUX3                   ((volatile BYTE_STRUCT*)&ADMUX)->bit3
#define	_MUX2                   ((volatile BYTE_STRUCT*)&ADMUX)->bit2
#define	_MUX1                   ((volatile BYTE_STRUCT*)&ADMUX)->bit1
#define	_MUX0                   ((volatile BYTE_STRUCT*)&ADMUX)->bit0
#define	_ADEN                   ((volatile BYTE_STRUCT*)&ADCSR)->bit7
#define	_ADSC                   ((volatile BYTE_STRUCT*)&ADCSR)->bit6
#define	_ADFR                   ((volatile BYTE_STRUCT*)&ADCSR)->bit5
#define	_ADIF                   ((volatile BYTE_STRUCT*)&ADCSR)->bit4
#define	_ADIE                   ((volatile BYTE_STRUCT*)&ADCSR)->bit3
#define	_ADPS2                  ((volatile BYTE_STRUCT*)&ADCSR)->bit2
#define	_ADPS1                  ((volatile BYTE_STRUCT*)&ADCSR)->bit1
#define	_ADPS0                  ((volatile BYTE_STRUCT*)&ADCSR)->bit0

//
// ANALOG_COMPARATOR variable definitions
//
// Analog Comparator Disable - Disabling_ENUM - [bit ACSR.ACD] Disables the Analog Comparator.
#define	_ACD                    ((volatile BYTE_STRUCT*)&ACSR)->bit7
// Interrupt Enable - Enabling_ENUM - [bit ACSR.ACIE] When enabled and the I-bit in the Status Register is set, the Analog Comparator interrupt is activated.
#define	_ACIE                   ((volatile BYTE_STRUCT*)&ACSR)->bit3
// Interrupt Mode Select - ACIntModeSelect_ENUM - [bit field "ACIS" ACSR.(ACIS0 | ACIS1)] Determine which comparator events trigger the Analog Comparator interrupt.

typedef struct
{
	unsigned char	__ACIS            : 2;
} ACIS_STRUCT;

#define	_ACIS                   ((volatile ACIS_STRUCT*)&ACSR)->__ACIS
// Bandgap Select - ACBandgapSelect_ENUM - [bit ACSR.ACBG] Selects a bandgap reference voltage as the positive input.
#define	_ACBG                   ((volatile BYTE_STRUCT*)&ACSR)->bit6
// Multiplexer Enable - Enabling_ENUM - [bit ACSR.ACME] When enabled and the ADC is switched off, the ADC multiplexer selects the negative input to the Analog Comparator. When disabled, AIN1 is applied to the negative input of the Analog Comparator.
#define	_ACME                   ((volatile BYTE_STRUCT*)&ACSR)->bit2

// other ANALOG_COMPARATOR bit definitions
#define	_ACO                    ((volatile BYTE_STRUCT*)&ACSR)->bit5
#define	_ACI                    ((volatile BYTE_STRUCT*)&ACSR)->bit4
#define	_ACIS1                  ((volatile BYTE_STRUCT*)&ACSR)->bit1
#define	_ACIS0                  ((volatile BYTE_STRUCT*)&ACSR)->bit0

//
// CPU variable definitions
//
#define	_PUD                    ((volatile BYTE_STRUCT*)&MCUCR)->bit6
#define	_SE                     ((volatile BYTE_STRUCT*)&MCUCR)->bit5
#define	_SM1                    ((volatile BYTE_STRUCT*)&MCUCR)->bit4
#define	_SM0                    ((volatile BYTE_STRUCT*)&MCUCR)->bit3
#define	_ISC01                  ((volatile BYTE_STRUCT*)&MCUCR)->bit1
#define	_ISC00                  ((volatile BYTE_STRUCT*)&MCUCR)->bit0
#define	_WDRF                   ((volatile BYTE_STRUCT*)&MCUSR)->bit3
#define	_BORF                   ((volatile BYTE_STRUCT*)&MCUSR)->bit2
#define	_EXTRF                  ((volatile BYTE_STRUCT*)&MCUSR)->bit1
#define	_PORF                   ((volatile BYTE_STRUCT*)&MCUSR)->bit0

//
// EEPROM variable definitions
//
#define	_EERIE                  ((volatile BYTE_STRUCT*)&EECR)->bit3
#define	_EEMWE                  ((volatile BYTE_STRUCT*)&EECR)->bit2
#define	_EEWE                   ((volatile BYTE_STRUCT*)&EECR)->bit1
#define	_EERE                   ((volatile BYTE_STRUCT*)&EECR)->bit0

//
// EXTERNAL_INTERRUPT variable definitions
//
// INT0 Interrupt Enable - Enabling_ENUM - [bit GIMSK.INT0] Enables the interrupt on the INT pin
#define	_INT0                   ((volatile BYTE_STRUCT*)&GIMSK)->bit6
// INT0 Interrupt Sense Control - SenseA_ENUM - [bit field "ISC0" MCUCR.(ISC00 | ISC01)] Specifies the type of signal that will generate an interrupt

typedef struct
{
	unsigned char	__ISC0            : 2;
} ISC0_STRUCT;

#define	_ISC0                   ((volatile ISC0_STRUCT*)&MCUCR)->__ISC0
// PCIE0 Interrupt Enable - Enabling_ENUM - [bit GIMSK.PCIE0] Enables interrupts for PCINT7..0
#define	_PCIE0                  ((volatile BYTE_STRUCT*)&GIMSK)->bit4
// PCIE1 Interrupt Enable - Enabling_ENUM - [bit GIMSK.PCIE1] Enables interrupts for PCINT15..8
#define	_PCIE1                  ((volatile BYTE_STRUCT*)&GIMSK)->bit5

// other EXTERNAL_INTERRUPT bit definitions
#define	_INTF0                  ((volatile BYTE_STRUCT*)&GIFR)->bit6
#define	_PCIF                   ((volatile BYTE_STRUCT*)&GIFR)->bit5

//
// TIMER_COUNTER_0 variable definitions
//
// Clock Select - CS0_CS_ENUM - [bit field "CS0" TCCR0.(CS00 | CS01 | CS02)] Selects the clock divisor or the external clock source.
typedef enum
{
	CS0_CS_None,                        	// No clock source (Timer/Counter stopped)
	CS0_CS_DIV_1,                       	// clk (No prescaling)
	CS0_CS_DIV_8,                       	// clk / 8 (From prescaler)
	CS0_CS_DIV_64,                      	// clk / 64 (From prescaler)
	CS0_CS_DIV_256,                     	// clk / 256 (From prescaler)
	CS0_CS_DIV_1024,                    	// clk / 1024 (From prescaler)
	CS0_CS_External_Falling,            	// External clock source, Clock on falling edge
	CS0_CS_External_Rising,             	// External clock source, Clock on rising edge
} CS0_CS_ENUM;

typedef struct
{
	unsigned char	__CS0             : 3;
} CS0_STRUCT;

#define	_CS0                    ((volatile CS0_STRUCT*)&TCCR0)->__CS0
// Timer Overflow Interrupt Enable - Enabling_ENUM - [bit TIMSK.TOIE0]
#define	_TOIE0                  ((volatile BYTE_STRUCT*)&TIMSK)->bit1

// other TIMER_COUNTER_0 bit definitions
#define	_TOV0                   ((volatile BYTE_STRUCT*)&TIFR)->bit1
#define	_PSR0                   ((volatile BYTE_STRUCT*)&TCCR0)->bit3
#define	_CS02                   ((volatile BYTE_STRUCT*)&TCCR0)->bit2
#define	_CS01                   ((volatile BYTE_STRUCT*)&TCCR0)->bit1
#define	_CS00                   ((volatile BYTE_STRUCT*)&TCCR0)->bit0

//
// TIMER_COUNTER_1 variable definitions
//
#define	_COM1A1                 ((volatile BYTE_STRUCT*)&TCCR1A)->bit7
#define	_COM1A0                 ((volatile BYTE_STRUCT*)&TCCR1A)->bit6
#define	_COM1B1                 ((volatile BYTE_STRUCT*)&TCCR1A)->bit5
#define	_COM1B0                 ((volatile BYTE_STRUCT*)&TCCR1A)->bit4
#define	_FOC1A                  ((volatile BYTE_STRUCT*)&TCCR1A)->bit3
#define	_FOC1B                  ((volatile BYTE_STRUCT*)&TCCR1A)->bit2
#define	_PWM1A                  ((volatile BYTE_STRUCT*)&TCCR1A)->bit1
#define	_PWM1B                  ((volatile BYTE_STRUCT*)&TCCR1A)->bit0
#define	_CTC1                   ((volatile BYTE_STRUCT*)&TCCR1B)->bit7
#define	_PSR1                   ((volatile BYTE_STRUCT*)&TCCR1B)->bit6
#define	_CS13                   ((volatile BYTE_STRUCT*)&TCCR1B)->bit3
#define	_CS12                   ((volatile BYTE_STRUCT*)&TCCR1B)->bit2
#define	_CS11                   ((volatile BYTE_STRUCT*)&TCCR1B)->bit1
#define	_CS10                   ((volatile BYTE_STRUCT*)&TCCR1B)->bit0
#define	_OCIE1A                 ((volatile BYTE_STRUCT*)&TIMSK)->bit6
#define	_OCIE1B                 ((volatile BYTE_STRUCT*)&TIMSK)->bit5
#define	_TOIE1                  ((volatile BYTE_STRUCT*)&TIMSK)->bit2
#define	_OCF1A                  ((volatile BYTE_STRUCT*)&TIFR)->bit6
#define	_OCF1B                  ((volatile BYTE_STRUCT*)&TIFR)->bit5
#define	_TOV1                   ((volatile BYTE_STRUCT*)&TIFR)->bit2
#define	_PCKE                   ((volatile BYTE_STRUCT*)&PLLCSR)->bit2
#define	_PLLE                   ((volatile BYTE_STRUCT*)&PLLCSR)->bit1
#define	_PLOCK                  ((volatile BYTE_STRUCT*)&PLLCSR)->bit0

//
// USI variable definitions
//
#define	_USISIF                 ((volatile BYTE_STRUCT*)&USISR)->bit7
#define	_USIOIF                 ((volatile BYTE_STRUCT*)&USISR)->bit6
#define	_USIPF                  ((volatile BYTE_STRUCT*)&USISR)->bit5
#define	_USIDC                  ((volatile BYTE_STRUCT*)&USISR)->bit4
#define	_USICNT3                ((volatile BYTE_STRUCT*)&USISR)->bit3
#define	_USICNT2                ((volatile BYTE_STRUCT*)&USISR)->bit2
#define	_USICNT1                ((volatile BYTE_STRUCT*)&USISR)->bit1
#define	_USICNT0                ((volatile BYTE_STRUCT*)&USISR)->bit0
#define	_USISIE                 ((volatile BYTE_STRUCT*)&USICR)->bit7
#define	_USIOIE                 ((volatile BYTE_STRUCT*)&USICR)->bit6
#define	_USIWM1                 ((volatile BYTE_STRUCT*)&USICR)->bit5
#define	_USIWM0                 ((volatile BYTE_STRUCT*)&USICR)->bit4
#define	_USICS1                 ((volatile BYTE_STRUCT*)&USICR)->bit3
#define	_USICS0                 ((volatile BYTE_STRUCT*)&USICR)->bit2
#define	_USICLK                 ((volatile BYTE_STRUCT*)&USICR)->bit1
#define	_USITC                  ((volatile BYTE_STRUCT*)&USICR)->bit0

//
// WATCHDOG variable definitions
//
// Prescaler - WDP_WdtPrescale_ENUM - [bit field "WDP" WDTCR.(WDP0 | WDP1 | WDP2)] Sets the watchdog timeout period. Values are typical at 5v.
typedef enum
{
	WDP_WdtPrescale_WDTO_16MS,          	// Typical Time-out 16 ms
	WDP_WdtPrescale_WDTO_32MS,          	// Typical Time-out 32 ms
	WDP_WdtPrescale_WDTO_64MS,          	// Typical Time-out 64 ms
	WDP_WdtPrescale_WDTO_125MS,         	// Typical Time-out 125 ms
	WDP_WdtPrescale_WDTO_250MS,         	// Typical Time-out 250 ms
	WDP_WdtPrescale_WDTO_500MS,         	// Typical Time-out 500 ms
	WDP_WdtPrescale_WDTO_1S,            	// Typical Time-out 1 sec
	WDP_WdtPrescale_WDTO_2S,            	// Typical Time-out 2 sec
} WDP_WdtPrescale_ENUM;

typedef struct
{
	unsigned char	__WDP             : 3;
} WDP_STRUCT;

#define	_WDP                    ((volatile WDP_STRUCT*)&WDTCR)->__WDP
// Enable - Enabling_ENUM - [bit WDTCR.WDE] Enables the watchdog timer.
#define	_WDE                    ((volatile BYTE_STRUCT*)&WDTCR)->bit3

// other WATCHDOG bit definitions
#define	_WDCE                   ((volatile BYTE_STRUCT*)&WDTCR)->bit4
#define	_WDP2                   ((volatile BYTE_STRUCT*)&WDTCR)->bit2
#define	_WDP1                   ((volatile BYTE_STRUCT*)&WDTCR)->bit1
#define	_WDP0                   ((volatile BYTE_STRUCT*)&WDTCR)->bit0

#define _AID_ATtiny26_DEFINED_
#endif /* _AID_ATtiny26_DEFINED_ */
