//****************************************************************************
// 
// standard.h
//
// Standard definitions and include files for all AVR projects.
//
//****************************************************************************
#pragma once

// Standard include files
#include <inttypes.h>
#include <stddef.h>
#include <stdlib.h>
#include <stdio.h>
#include <string.h>
#include <avr/io.h>
#include <avr/interrupt.h>
#include <avr/pgmspace.h>
#include <avr/wdt.h>

// Establish if this is ATxmega
#ifdef _WORDREGISTER
#define _XMEGA_
#else
#include <avr/eeprom.h>
#include <SuperHeaders\SuperHeader.h>
#endif

// Standard data types
typedef	uint8_t			BYTE;
typedef	uint16_t		WORD;
typedef	uint32_t		DWORD;
typedef	int8_t			SBYTE;
typedef	int16_t			SWORD;
typedef	int32_t			SDWORD;

// Common macros
#define FALSE			0
#define TRUE			1
#define	__cdecl
#ifndef _countof
#define _countof(array) (sizeof(array)/sizeof(array[0]))
#endif
#define STRLEN(str)	(sizeof str - 1)	// characters in string literal
//#define offsetof(s, m)	((int)&((s*)0)->m)
//#define offsetof(type, member) __builtin_offsetof (type, member)
#ifndef	CONSTPROG
#define CONSTPROG	
#undef PROGMEM
#define PROGMEM __attribute__((section(".progmem.data"))) 
#endif
#define PROGMEM_SECTION PROGMEM 
//#define PROGMEM_SECTION __attribute__((section(".progmem.data"))) 
//#undef PSTR
//#define PSTR(s) (__extension__({static char __c[] PROGMEM = (s); &__c[0];}))
#define ADDOFFSET(p, o)	(((BYTE *)(p)) + (o))
#define NOP()			asm volatile("nop")
#define DEBUG_BREAK()	asm volatile("break")
#define NO_INLINE_ATTR	__attribute__((noinline))
#define INLINE_ATTR		__attribute__((always_inline))
#define FORCE_INLINE(...) inline static __VA_ARGS__	INLINE_ATTR; inline static __VA_ARGS__
#define	printf_PGM(fmt, ...)	printf_P(PSTR(fmt), ##__VA_ARGS__)
#define puts_PGM(str)			puts_P(PSTR(str))
#undef pgm_read_ptr 
#define pgm_read_ptr(x)		((char *)pgm_read_word(x))
int main() __attribute__((OS_main));
extern div_t udiv(WORD __num, WORD __denom) __asm__("__udivmodhi4") __ATTR_CONST__;
extern ldiv_t uldiv(DWORD __num, DWORD __denom) __asm__("__udivmodsi4") __ATTR_CONST__;

#ifdef	_DEBUG
#define	DEBUG_PRINT	printf_PGM
#else
#define	DEBUG_PRINT(...)
#endif

//****************************************************************************
// 16-bit operations

typedef union
{
	WORD	w;
	struct
	{
		BYTE	bLo;
		BYTE	bHi;
	};
} WORD_BYTES;

#define LOBYTE(w)       ((BYTE)(WORD)(w))
#define HIBYTE(w)       ((BYTE)((WORD)(w) >> 8))
#define LOBYTEMEM(w)	(*(BYTE *)&(w))
#define HIBYTEMEM(w)	(*((BYTE *)&(w) + 1))
#define BYTESWAP(w)		MAKEWORD(HIBYTE(w), LOBYTE(w))
#define MAKEWORD(l, h)	((WORD)(LOBYTE(l) + ((WORD)LOBYTE(h) << 8)))

// These functions should be used only when the values
// are NOT known at compile time.
//
FORCE_INLINE( BYTE HiByte(WORD w) )
{
	WORD_BYTES	wb;
	wb.w = w;
	return wb.bHi;
}

// ByteSwap: swap the bytes within a word
FORCE_INLINE( WORD ByteSwap(WORD w) )
{
	WORD	retval;
	asm("mov %A0, %B1 \n\t"
		"mov %B0, %A1 \n\t"
		: "=&r" (retval) : "r" (w));
	return retval;
	//WORD_BYTES	retval;
	//WORD_BYTES	wb;
	//wb.w = w;
	//retval.bHi = wb.bLo;
	//retval.bLo = wb.bHi;
	//return retval.w;
}

// MakeWord: combine two bytes to make a word
FORCE_INLINE( WORD MakeWord(BYTE lo, BYTE hi) )
{
	//WORD	retval;
	//asm("mov %A0, %1 \n\t"
	//	"mov %B0, %2 \n\t"
	//	: "=&r" (retval) : "r" (lo), "r" (hi));
	//return retval;
	WORD_BYTES	retval;
	retval.bLo = lo;
	retval.bHi = hi;
	return retval.w;
}

//****************************************************************************
// 32-bit operations

typedef union
{
	DWORD	dw;
	SDWORD	l;
	float	flt;
	struct
	{
		WORD	wLo;
		WORD	wHi;
	};
	struct
	{
		BYTE	bLo;
		BYTE	bMidLo;
		BYTE	bMidHi;
		BYTE	bHi;
	};

#ifdef __cplusplus
	void Reverse()
	{
		BYTE	bTmp;

		bTmp = bLo;
		bLo = bHi;
		bHi = bTmp;
		bTmp = bMidLo;
		bMidLo = bMidHi;
		bMidHi = bTmp;
	};
#endif

} DWORD_BYTES;

#ifdef __cplusplus
class BigEnd32
{
protected:
	DWORD_BYTES	dwb;

public:
	BYTE bHi() {return dwb.bLo;}
	WORD wHi()
	{
		WORD_BYTES	wb;
		wb.bHi = dwb.bLo;
		wb.bLo = dwb.bMidLo;
		return wb.w;
	}

public:
	operator DWORD()
	{
		DWORD_BYTES	dwbTmp;
		dwbTmp.bLo = dwb.bHi;
		dwbTmp.bMidLo = dwb.bMidHi;
		dwbTmp.bMidHi = dwb.bMidLo;
		dwbTmp.bHi = dwb.bLo;
		return dwbTmp.dw;
	};

	void operator=(DWORD dw)
	{
		DWORD_BYTES	dwbTmp;
		dwbTmp.dw = dw;
		dwb.bLo = dwbTmp.bHi;
		dwb.bMidLo = dwbTmp.bMidHi;
		dwb.bMidHi = dwbTmp.bMidLo;
		dwb.bHi = dwbTmp.bLo;
	};
};

class BigEnd16
{
protected:
	WORD_BYTES	wb;

public:
	BYTE bHi() {return wb.bLo;}

public:
	operator WORD()
	{
		WORD_BYTES	wbTmp;
		wbTmp.bLo = wb.bHi;
		wbTmp.bHi = wb.bLo;
		return wbTmp.w;
	};

	void operator=(WORD w)
	{
		WORD_BYTES	wbTmp;
		wbTmp.w = w;
		wb.bLo = wbTmp.bHi;
		wb.bHi = wbTmp.bLo;
	};
};

#endif

//****************************************************************************
// Inline ASM functions should be used only when the values
// are NOT known at compile time.
//
// Mul8x8: Multiply two 8-bit values with 16-bit result
FORCE_INLINE( WORD Mul8x8(BYTE op1, BYTE op2) )
{
	WORD	retval;
	asm("mul  %2, %1 \n\t"
		"movw %0, r0 \n\t"
		"clr  r1     \n\t"
		: "=r" (retval) : "r" (op1), "r" (op2));
	return retval;
}

FORCE_INLINE( BYTE Swap(BYTE op) )
{
	asm volatile("swap %0" : "=r" (op) : "0" (op));
	return op;
}

//****************************************************************************
// SaveRetLoc() debugging helper.
//
// Saves the top of stack (the return address) into the specified
// 16-bit location. Can only work on functions that push no registers!
//
// Works on processors with more than 128K of program memory, but
// only keeps low 16 bits of return address.

#if FLASHEND < 0x20000

#define SaveRetLoc(pLoc)	\
	asm("pop	r19 \n\t"	\
		"pop	r18 \n\t"	\
		"push	r18 \n\t"	\
		"push	r19 \n\t"	\
		"sts	%0,r18\n\t" \
		"sts	%0+1,r19\n\t" \
		::"m" (pLoc));

#else

#define SaveRetLoc(pLoc)	\
	asm("pop	r0	\n\t"	\
		"pop	r19 \n\t"	\
		"pop	r18 \n\t"	\
		"push	r18 \n\t"	\
		"push	r19 \n\t"	\
		"push	r0	\n\t"	\
		"sts	%0,r18\n\t" \
		"sts	%0+1,r19\n\t" \
		::"m" (pLoc));

#endif

//****************************************************************************
// Math library function made smaller

FORCE_INLINE( bool isinfinite(double flt) )
{
    BYTE res;
    __asm__ (
	"mov	r0, %C1		\n\t"
	"lsl	r0			\n\t"
	"mov	%0, %D1		\n\t"
	"rol	%0			\n\t"
	"inc	%0			\n\t"
	"or		%0, r0		\n\t"
	"or		%0, %B1		\n\t"
	"or		%0, %A1		\n\t"
	: "=r" (res)
	: "r" (flt)	);
    return res == 0;
}

//****************************************************************************

#ifdef __cplusplus
// Fix the FDEV_SETUP_STREAM macro for C++
#undef FDEV_SETUP_STREAM
#define FDEV_SETUP_STREAM(p, g, f) { 0, 0, f, 0, 0, p, g, 0 }
#define EXTERN_C extern "C"
#else
#define EXTERN_C
#endif
#define FDEV_SETUP_STREAM_X(p, g, f, u) { 0, 0, f, 0, 0, p, g, u }

// Define bit fields using predefined bit numbers.
//
// Macro arguments are not expanded if they are token-pasted.
// Using a macro to call a macro will get our bit number argument
// expanded (to a digit for use in BYTE_STRUCT).
#define BITDEF1(port, bitnum)	((volatile BYTE_STRUCT*)&port)->bit##bitnum
#define BITDEF(port, bitnum)	BITDEF1(port, bitnum)
